/* 
AUTHORS:

Urska Pangerc <urska.pangerc@gmail.com>
Franc Jager <franc.jager@fri.uni-lj.si>

Laboratory for Biomedical Computer Systems and Imaging
Faculty of Computer and Information Science
University of Ljubljana
Ljubljana, Slovenia
*/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <wfdb/wfdb.h>
#include <wfdb/ecgmap.h>
#include <ctype.h>
#include <string.h>


#define MAX_LEADS 10
#define FILTMAX 500 
#define VELIKOST 100000
#define QT75 0.33 
#define RR75 0.8
#define OKNO_BP 0.3
#define OKNO_ECG_GL 0.22
#define OKNO_SUM_GL 0.3 
#define SIRINA 0.5
#define k14 1.4 
#define DOLZINAintervala 8 
#define PRAGzaUCENJE 0.382
#define PRAGzaUCENJE2 0.33
#define SPUSTIMmeje 0.05 
#define k08 0.8 
#define k12 1.2  
#define k07 0.7
#define k13 1.3  
#define KONST_NI_SIGNALA 20.0 
#define RRmax_uc 1.7
#define RRmin_uc 0.3 
#define oknoSrednjaV 4   
#define INTERVALzdruzitevNAUC_DET 0.2 
#define INTERVALzdruzitevNAUC 0.2
#define INTERVALzdruzitevDET 0.2

#define LUKNJA 1.6

#define PRAGnizkiUTRIPI 0.5
#define MEJA1 0.012//0.012
#define MEJA1BP 0.012
#define MEJA2 0.2
#define MEJA2BP 0.2
#define BXB 0.075

#define DEFAULT  0.14

//mediana
//#define BP  0.19//0.16
//#define ART  0.18
//#define PAP  0.14//0.15
//#define Pressure  0.12//0.18

#define BP  0.2//0.16
#define ART  0.16//0.18
#define PAP  0.13//0.15
#define Pressure  0.18


#define IDXuj 0.75


int imena = 0;//1; //0 - default

static WFDB_Siginfo s[MAX_LEADS];
long nrSamps;
int frekvenca; 

double *utripi;
double *ekg;
double *sum1;
double *sum2;
double *tmp;
double *fja_suma;
double *detekcijski_prag;
double *detekcijski_pragBP;
double *ekgh1;
double *ekgh2;
double *z;
double *det_fja_ekg;
double *tmp_ekg;
double *pritisk;
double *fpritisk;
double *tmp_pritisk;
double *tmp_bp;
double *zaINT;
double *zaINTnaucene;
double *RR_interpoliran;
double *RR_interpoliran_BP;
double *ekg0; 
double *ekg1; 
double *ekg2; 
double *bp0;
double *bp1;
double *bp2;
double *utripi_ekg;
double *utripi_bp;
double *utripi_ekg_bp;
double *utripi_ekg_nauceni;
double *utripi_bp_nauceni;
double *RR_i_vsi;
double *nauceniVSI;
double *utripi_ekg0;
double *utripi_ekg1;
double *utripi_ekg2;
double *utripi_skupni;
double *utripi0;
double *utripi1;
double *utripi2;
double *prag_ucenje;
double *prag_ucenje_BP;
double *d_prag0;
double *d_prag1;
double *d_prag2;
double *d_fja0;
double *d_fja1;
double *d_fja2;

double *sum1_bp;
double *fja_suma_bp;


double *MedianaEkg;
double *amplitudeBP;


double *utripi_bp0;
double *utripi_bp1;
double *utripi_bp2;

double *ekg_brisi;


double *RR_interpoliran_BP0;
double *RR_interpoliran_BP1;
double *RR_interpoliran_BP2;
double *fpritisk0;
double *fpritisk1;
double *fpritisk2;



double *ekg0_G; 
double *ekg1_G; 
double *ekg2_G; 
double *ekg_G;
int st_bp; 
int st_ekg; 
int interval = 0; 

int intervali[VELIKOST][2];
int sumI0[VELIKOST][2];
int sumI1[VELIKOST][2];
int sumI2[VELIKOST][2]; 
int NauceniInt[VELIKOST][2];
int NauceniIntBP[VELIKOST][2];
int PtoP[VELIKOST];


int inter = 0;
int interBP = 0;

double RRpovprUCENJE[VELIKOST]; 
int stejemRR = 0;
double RRpovprUCENJE_BP[VELIKOST]; 
int stejemRR_BP = 0;

int pricakovano_st_utripov = 0;
int pricakovano_st_utripov_BP = 1;

int openLeads;
long samples;
double normCnst = 32;

double odmikINrr[VELIKOST][2];
int st_odmikRR = 0;

int detEKG = 0;
int detBP = 0;

double koef = 0; 
double N = 0;

int Korak;

//double amplitudeBP[VELIKOST];
int amplitudeBP_st = 0;
double srednjiBP = 0;

int Korelacija = 1;

///
int ekg_index[3] = {-1,-1,-1}; 
int bp_indexi[3] = {-1,-1,-1}; 
int bp_indexi_imena[3] = {0,0,0}; 
///


int IMAM_PM = 0;
int IMAM_PM2 = 0;

typedef struct
{
	int zamik;
	int ojacanje;
	int b[FILTMAX];
	int bLen;
	int a[FILTMAX];
	int aLen;
}filt_param; 

filt_param bh1;
filt_param bh2;
filt_param glajenje;
filt_param bbp; 
filt_param sumfilter1;
filt_param sumfilter2;
filt_param sumfilterg; 

double rr_naucen_EKG = 0;
double rr_naucen_BP = 0;

int maksimum(double * signal, int dolzina, int index)
{
	int zacetek = index;
	int konec = dolzina;
	int i, id;
	double peak;
	peak = signal[zacetek];
	for(i=zacetek;i<konec;i++)
	{
		if(signal[i] >= peak){
			peak = signal[i];
			id = i;
		}
	}
	return id;
}

double maks(double a, double b)
{
	if(a > b) return a;
	else return b;
}

int minimum(double * signal, int dolzina, int index)
{
	int zacetek = index;
	int konec = dolzina;
	int i, id;
	double peak;
	peak = signal[zacetek];
	for(i=zacetek;i<konec;i++)
	{
		if(signal[i] <= peak){
			peak = signal[i];
			id = i;
		}
	}
	return id;
}

double aMean(double * array, int length)
{
	int i;
	double temp = 0.0;
	for (i = 0; i < length; i++)
		temp += array[i];
	return temp/((double) length);
}

double aMean2(double * array, int length, int index)
{
	int i;
	double temp = 0.0;
	for (i = index; i < (index + length); i++)
		temp += array[i];
	return temp/((double) length);
}

double aStd(double * array, int length)
{
	int i;
	double mean = aMean(array, length);
	double out = 0;
	
	for (i = 0; i < length; i++)
		out += powf(array[i] - mean, 2);

	out /= (length - 1);
	return powf(out, 0.5);
}

double l_intepolation(int x0, double y0, int x1, double y1, int x)
{	
	double y = (y0 + ((y1 - y0)*(x - x0)/(x1 - x0)));
	return y;
}

int cmpfunc (const void * a, const void * b)
{
   return ( *(double*)a - *(double*)b );
}

int openRecord(char *record)
{
  return (isigopen(record, s, MAX_LEADS));
}

void writeQRS(char *record, int chan)
{
  WFDB_Anninfo annIFO;
  WFDB_Annotation annot;
  int i;

  annIFO.name="qrs"; annIFO.stat = WFDB_WRITE;
  if (annopen(record, &annIFO, 1) < 0)
  {
    fprintf(stderr,"Error opening QRS file\n");
    return;
  }
    		
  annot.subtyp = annot.chan = annot.num = 0; annot.aux = NULL;
  for (i = 0; i < samples; i++)
  {
    if(utripi[i] != 0)
    {
      annot.anntyp = utripi[i];
      annot.time = i;
      if (putann(0, &annot) < 0) break;
    }
  }
}

int izracunaj_filter(int frekvenca)
{
	int i, k1, k2, g1, c1, c2, s1, sg;
	for(i = 0; i<FILTMAX; i++)
	{
		bh1.b[i] = 0;
		bh2.b[i] = 0;
		glajenje.b[i] = 0;
		bbp.b[i] = 0;
		sumfilter1.b[i] = 0;
		sumfilter2.b[i] = 0;
		sumfilterg.b[i] = 0;
	}

	k1 = (int)round(frekvenca/50.0);
	k2 = (int)round(frekvenca/35.0);
	bh1.b[0] = 1;
	bh1.b[k1] = -1;
	bh1.b[k2] = -1;
	bh1.b[k1+k2] = 1;
	bh1.zamik = (int)ceil((k1*0.5)+((k2-1)*0.5));
	bh1.ojacanje = 2*k2; 
	bh1.bLen = k1+k2+1;
		
	bh2.b[0] = 1;
	bh2.b[k1] = -2;
	bh2.b[k2] = -1;
	bh2.b[2*k1] = 1;
	bh2.b[k1+k2] = 2;
	bh2.b[2*k1+k2] = -1;
	bh2.zamik = (int)ceil((k1)+((k2-1)*0.5));
	bh2.ojacanje = 4*k2; 
	bh2.bLen = 2*k1+k2+1;
	
	g1 = (int)round(frekvenca/15.0);
	glajenje.b[0] = 1;
	glajenje.b[g1] = -1;
	glajenje.zamik = (int)ceil(g1/2.0);
	glajenje.ojacanje = g1;
	glajenje.bLen = g1+1;
	
//**********	
	c1 = (int)round(frekvenca/10.0);
	c2 = (int)round(frekvenca/5.0);
	bbp.b[0] = 1;
	bbp.b[c1] = -1;
	bbp.b[c2] = -1;
	bbp.b[c1+c2] = 1;
	bbp.zamik = (int)ceil((c1*0.5)+((c2-1)*0.5));
	bbp.ojacanje = 2*c2; 
	bbp.bLen = c1+c2+1;
	
//**************
	s1 = (int)round(frekvenca/80.0);
	sumfilter1.b[0] = 1;
	sumfilter1.b[s1] = -1;
	sumfilter1.zamik = (int)ceil(s1*0.5);
	sumfilter1.ojacanje = 2; 
	sumfilter1.bLen = s1+1;
	
	sumfilter2.b[0] = 1;
	sumfilter2.b[s1] = -2;
	sumfilter2.b[2*s1] = 1;
	sumfilter2.zamik = (int)ceil(s1);
	sumfilter2.ojacanje = 4; 
	sumfilter2.bLen = 2*s1+1;

	sg = (int)round(frekvenca/35.0);
	sumfilterg.b[0] = 1;
	sumfilterg.b[sg] = -1;
	sumfilterg.zamik = (int)ceil((sg-1)*0.5);
	sumfilterg.ojacanje = sg; 
	sumfilterg.bLen = sg+1;


	bh1.a[0] = 1;
	bh1.a[1] = -1;
	bh1.aLen = 2;

	bh2.a[0] = 1;
	bh2.a[1] = -1;
	bh2.aLen = 2;

	glajenje.a[0] = 1;
	glajenje.a[1] = -1;
	glajenje.aLen = 2;

	bbp.a[0] = 1;
	bbp.a[1] = -1;
	bbp.aLen = 2;
	
	sumfilter1.a[0] = 1;
	sumfilter1.aLen = 1;

	sumfilter2.a[0] = 1;
	sumfilter2.aLen = 1;

	sumfilterg.a[0] = 1;
	sumfilterg.a[1] = -1;
	sumfilterg.aLen = 2;

	return 1;
}

int filtriranje(filt_param flt, double* ecg,  double* ecgf, int ekgLen)
{
	int i,j,k;

	ecgf[0] = ecg[0];

	for(i=1; i<ekgLen; i++)
	{
		ecgf[i] = 0.0;
		
		for(j=0; j<(flt.bLen<i ? flt.bLen:i); j++)
		{
			ecgf[i] += flt.b[j]*ecg[i-j];
		}

		for(k=1; k<(flt.aLen<i ? flt.aLen:i); k++)
		{
			ecgf[i] -= flt.a[k]*ecgf[i-k];
		}
	}

	return i;
}

int naredi_fjo_suma(void)
{
	int i, j, maxZamik, dolzina;
	int okno;
	okno = (int)round(OKNO_SUM_GL*frekvenca);

	filtriranje(sumfilter1, ekg, sum1, nrSamps); 
	filtriranje(sumfilter2, ekg,  sum2, nrSamps); 
	
	if(sumfilter1.zamik > sumfilter2.zamik) maxZamik = sumfilter1.zamik;
	else maxZamik = sumfilter2.zamik;
	
	
	for(i=0; i<nrSamps-maxZamik; i++)
	{
		tmp[i] = (abs(sum1[sumfilter1.zamik+i]/sumfilter1.ojacanje) + abs(sum2[sumfilter2.zamik+i]/sumfilter2.ojacanje));
		tmp[i] *= tmp[i]; 
	} 

	
	
	
	filtriranje(sumfilterg, tmp,  fja_suma, nrSamps-maxZamik); 
	dolzina = nrSamps-maxZamik-sumfilterg.zamik;
	for(i = 0; i < dolzina; i++)
	{
		fja_suma[i] = fja_suma[i+sumfilterg.zamik]/(sumfilterg.ojacanje*2.5);
	}


	for(i = 0; i < dolzina; i++)
	{
		if((i+2*okno-2) < dolzina) sum1[(i+2*okno-2)] = fja_suma[i];
	}
		
	for(i = 0; i < (2*okno-2); i++)
	{
		sum1[i] = sum1[(2*okno)]; 
	}
	for(i = 0; i < dolzina; i++)
	{
		if((i+okno) > dolzina) sum1[i] = 0;
		else
		{
			j = maksimum(sum1, (i+okno), i);
			sum1[i] = sum1[j]; 
		}
	}	
	for(i = 0; i < dolzina; i++)
	{	
		if((i+okno) > dolzina) sum1[i] = 0;
		else
		{
			j = minimum(sum1, (i+okno), i);
			sum1[i] = sum1[j]; 
		}
	}	
	for(i = 0; i < dolzina; i++)
	{
		if((i+okno) > dolzina) sum1[i] = 0;
		else
		{
			j = minimum(sum1, (i+okno), i);
			sum1[i] = sum1[j]; 
		}
	}	
	for(i = 0; i < dolzina; i++)
	{	
		if((i+okno)>dolzina) sum1[i] = 0;
		else
		{
			j = maksimum(sum1, (i+okno), i);
			sum1[i] = sum1[j]; 
		}
	}
	
	return (dolzina);
}




void dolzinska_transformacija(double *sig, int dolzina, double *sig2)
{
  int i,j;
  double s = 0.0;
  double okno = 0.08;
  
  for(i = 0; i < dolzina-1; i++)
  {
    s = 0.0;
    if(i+okno*frekvenca < dolzina-1)
    {  
      for(j = i; j < i+okno*frekvenca; j++)
      {
	s = s + fabs(sig[j+1]-sig[j]);
      } 
      sig2[i] = s;
     }
    else sig2[i] = 0.;
  } 
}


void MAV(double *sig, int dolzina, double *sig2)
{
  int i,j;
  double s = 0.0;
  double okno = 0.1;
  
  for(i = 0; i < dolzina-1; i++)
  {
    s = 0.0;
    if(i+okno*frekvenca < dolzina-1)
    {  
      for(j = i; j < i+okno*frekvenca; j++)
      {
	s = s + sig[j];
      } 
      sig2[i] = s/(okno*frekvenca);
     }
    else sig2[i] = 0.;
  } 
}




int naredi_ECG_det_fjo(void)
{
	int i, j,maxZamik, dolzina_det_fje;
	int oknoGL = OKNO_ECG_GL*frekvenca;

int zac = 0;
int kon = 0;
double tmp_rr = 0.0;	
int tmp_st = 0;	
int tmp_zadnji = 0;
double rr1 = 0.0;
double rr2 = 0.0;
int predpr_idx[VELIKOST];
int predpr_stevec = 0;
int manjsi = 0;
int vecji = 0;
double rr_tmp = 0.0;
double odst = 0.0;
int m = 0;


int okno;
int u = 0;
int k_ucenje = 1;
double s = 0.0;
int tempPeakStart = 0;
int tempPeakStart_sum = 0;
int konec = 0;
int k = 1;
int meja2 = 0.19*frekvenca;


/*
dolzinska_transformacija(ekg_G,nrSamps,ekg_brisi);	

tmp_st = 0;
i = 0;  
while(i < nrSamps)
{
  if(ekg_brisi[i] >= 1.0)
  {
    zac = i;
    tempPeakStart = i;
    while(ekg_brisi[i] >= 1.0)
    {
     	if(ekg_brisi[i] >= ekg_brisi[tempPeakStart]) {tempPeakStart = i;}
	i++;
	if(i >= nrSamps) break;
    }
    
  if(tmp_st == 0) {tmp_zadnji = tempPeakStart; tmp_st++;}
  else
  { 
    if(((double)(tempPeakStart - tmp_zadnji)/frekvenca < RRmax_uc) && ((double)(tempPeakStart - tmp_zadnji)/frekvenca >= 0.15))
    {	  	
      tmp_rr = tmp_rr + (tempPeakStart - tmp_zadnji);
      tmp_st++;
      if(predpr_stevec == 0) 
      {
	 predpr_idx[predpr_stevec] = tmp_zadnji; predpr_stevec++; 
	  predpr_idx[predpr_stevec] = tempPeakStart; predpr_stevec++;
      }
      else
      {
	  if(predpr_idx[predpr_stevec-1] == tmp_zadnji) 
	  {
	    predpr_idx[predpr_stevec] = tempPeakStart; predpr_stevec++; 
	    if(predpr_stevec >= VELIKOST) predpr_stevec = VELIKOST -1;
	  }
	  else if(predpr_idx[predpr_stevec-1] != tmp_zadnji)
	  {
		      predpr_idx[predpr_stevec] = tempPeakStart; predpr_stevec++;
		      if(predpr_stevec >= VELIKOST) predpr_stevec = VELIKOST -1;
	  }
      }
    }	
      tmp_zadnji = tempPeakStart;

    
  }    
  }  
  i++;
}  

if(tmp_st > 2)
{
  rr1 = (tmp_rr/(tmp_st-1))/frekvenca;	
}
else rr1 = 1.0;

if((rr1 < 0.41) && (fabs(1.0 - tmp_st/(nrSamps/(tmp_rr/(tmp_st-1)))) < 0.25))
{
  for(i = 0; i < predpr_stevec-1; i++)
  {
    rr_tmp = (double)(predpr_idx[i+1] - predpr_idx[i])/frekvenca;
    if(rr_tmp < 0.95*rr1 &&  rr_tmp > 0.15)
    {
      manjsi++;
    }  
    if(rr_tmp > 1.05*rr1 && rr_tmp < RRmax_uc)
    {
      vecji++;
      
    }
  } 

if((manjsi > 0) && (vecji > 0) && (fabs(1.0 - (double)(manjsi+vecji)/tmp_st) < 0.25)) 
  odst = fabs(1.0 - (double)manjsi/vecji); 
else odst = 20;


if(odst < 0.25)
{
  
  for(i = 0; i < predpr_stevec-1; i++)
  {
    rr_tmp = (double)(predpr_idx[i+1] - predpr_idx[i])/frekvenca;
    if(((rr_tmp/rr1-1.0) < 0.0) && ((rr_tmp/rr1-1.0) > -0.5))
    {
	kon = predpr_idx[i] + round(0.1*frekvenca);
	if(kon >= nrSamps) kon = nrSamps - 1;
	zac = predpr_idx[i] - round(0.1*frekvenca);
	if(zac < 0) zac = 0;
      	for(j = zac; j < kon; j++)
	{
	  ekg[j] = l_intepolation(zac, ekg[zac], kon, ekg[kon], j);
	}
    }
  }
  
  
}  
}
*/
	filtriranje(bh1, ekg, ekgh1, nrSamps); 
	filtriranje(bh2, ekg,  ekgh2, nrSamps); 

	


	if(bh1.zamik > bh2.zamik) maxZamik = bh1.zamik;
	else maxZamik = bh2.zamik;
	
	for(i=0; i<nrSamps-maxZamik; i++)
	{
		z[i] = (abs(ekgh1[bh1.zamik+i]/bh1.ojacanje) + abs(ekgh2[bh2.zamik+i]/bh2.ojacanje));
		z[i] *= z[i]; 
	} 

	filtriranje(glajenje, z,  det_fja_ekg, nrSamps-maxZamik); 

	dolzina_det_fje = nrSamps-maxZamik-glajenje.zamik;
	for(i = 0; i < dolzina_det_fje; i++)
	{
		det_fja_ekg[i] = det_fja_ekg[i+glajenje.zamik]/glajenje.ojacanje;
	}

	
  for(i = 0; i < frekvenca/6; i++)
  {
    det_fja_ekg[i] = 0;
  }

///  
	
okno = oknoSrednjaV*frekvenca;
u = 0;
for(i = 0; i < (dolzina_det_fje - okno); i++) 
{
	s = k_ucenje*aMean2(det_fja_ekg, okno, i);
	if(s <= KONST_NI_SIGNALA) s = k_ucenje*KONST_NI_SIGNALA;
	prag_ucenje[(i+frekvenca)] = s;
	MedianaEkg[u] = s;
	u++;
	//if(u >=9*VELIKOST) u = (9*VELIKOST) - 1;
	if(u >= dolzina_det_fje) u = (dolzina_det_fje) - 1;
}

	qsort(MedianaEkg, u, sizeof(double), cmpfunc);
	if(u % 2 == 1) s = MedianaEkg[((u+1)/2)];
	else s = (MedianaEkg[u/2]+MedianaEkg[(u/2)+1])/2;	
	
for(i = 0; i < dolzina_det_fje; i++) 
{
	prag_ucenje[i] = s;
}  
  

///
///******************++
/*

	okno = oknoSrednjaV*frekvenca;
	for(i = 0; i < (dolzina_det_fje - okno); i++) 
	{
		s = k_ucenje*aMean2(det_fja_ekg, okno, i);
		if(s <= KONST_NI_SIGNALA) s = k_ucenje*KONST_NI_SIGNALA;
		prag_ucenje[(i+frekvenca)] = s;
	}
	for(i = 0; i < frekvenca; i++) 
	{
		prag_ucenje[i] = prag_ucenje[frekvenca];
	}
	for(i = (dolzina_det_fje - okno); i < dolzina_det_fje; i++) 
	{
		prag_ucenje[i] = prag_ucenje[(dolzina_det_fje - okno-1)];
	}

*/
//export(det_fja_ekg,dolzina_det_fje,"AAdet_prej.txt");  
//export(ekg,dolzina_det_fje,"AAor.txt");  

//export(det_fja_ekg,dolzina_det_fje,"aa_d1.txt");



 
tmp_st = 0;
i = 0;  
while(i < dolzina_det_fje)
{
  if(det_fja_ekg[i] >= prag_ucenje[i])
  {
    zac = i;
    tempPeakStart = i;
    tempPeakStart_sum = i;
    while(det_fja_ekg[i] >= prag_ucenje[i])
    {
     	if(det_fja_ekg[i] >= det_fja_ekg[tempPeakStart]) {tempPeakStart = i;}
	i++;
	if(i >= dolzina_det_fje) break;
    }
    
  if(tmp_st == 0) {tmp_zadnji = tempPeakStart; tmp_st++;}
  else
  { 
 // printf("%f \n", (double)(tempPeakStart - tmp_zadnji)/frekvenca);
    if(((double)(tempPeakStart - tmp_zadnji)/frekvenca < RRmax_uc) && 
      ((double)(tempPeakStart - tmp_zadnji)/frekvenca >= 0.18)
    )
    {	  	
      tmp_rr = tmp_rr + (tempPeakStart - tmp_zadnji);
      tmp_st++;
      if(predpr_stevec == 0) 
      {
	 predpr_idx[predpr_stevec] = tmp_zadnji; predpr_stevec++; 
	  predpr_idx[predpr_stevec] = tempPeakStart; predpr_stevec++;
      }
      else
      {
	  if(predpr_idx[predpr_stevec-1] == tmp_zadnji) 
	  {
	    predpr_idx[predpr_stevec] = tempPeakStart; predpr_stevec++; 
	    if(predpr_stevec >= VELIKOST) predpr_stevec = VELIKOST -1;
	  }
	  else if(predpr_idx[predpr_stevec-1] != tmp_zadnji)
	  {
//		      predpr_idx[predpr_stevec] = tmp_zadnji; predpr_stevec++; 
		      predpr_idx[predpr_stevec] = tempPeakStart; predpr_stevec++;
		      if(predpr_stevec >= VELIKOST) predpr_stevec = VELIKOST -1;
	  }
      }
    }	
      tmp_zadnji = tempPeakStart;

    
  }    
  }  
  i++;
}  


//ce rr < 0.45 && odst > 0.75
//stejem manjse in vecje


if(tmp_st > 2)
{
  rr1 = (tmp_rr/(tmp_st-1))/frekvenca;	
}
else rr1 = 1.0;

//printf("rr  %f %f \n",rr1, tmp_st/(dolzina_det_fje/(tmp_rr/(tmp_st-1))));
//printf("rr  %f   vsoota  %d \n",rr1, tmp_st);

if((rr1 < 0.41) && (fabs(1.0 - tmp_st/(dolzina_det_fje/(tmp_rr/(tmp_st-1)))) < 0.25))
{
  for(i = 0; i < predpr_stevec-1; i++)
  {
    rr_tmp = (double)(predpr_idx[i+1] - predpr_idx[i])/frekvenca;
    if(rr_tmp < 0.95*rr1)// &&  rr_tmp > 0.15)
    {
      manjsi++;
    }  
    if(rr_tmp > 1.05*rr1)// && rr_tmp < RRmax_uc)
    {
      vecji++;
      
    }
  } 

//printf("vecji manjsi      %d   %d\n", vecji, manjsi);
if((manjsi > 0) && (vecji > 0) && (fabs(1.0 - (double)(manjsi+vecji)/tmp_st) < 0.25)
//  && (double)fabs((manjsi/vecji)-1.0) < 0.25
) 
  odst = fabs(1.0 - (double)manjsi/vecji); 
else odst = 20;



if(odst < 0.25) //rezanje
{
IMAM_PM = 1;
  for(i = 0; i < predpr_stevec-1; i++)
  {
    rr_tmp = (double)(predpr_idx[i+1] - predpr_idx[i])/frekvenca;
 //   printf("rr %f     %f\n",rr_tmp,(rr_tmp/rr1-1.0));
 //   if(((rr_tmp/rr1-1.0) < 0.0) && ((rr_tmp/rr1-1.0) > -0.45))
if(rr_tmp < 0.95*rr1)
    {//brisem drugega
	kon = predpr_idx[i] + round(0.1*frekvenca);
	if(kon >= dolzina_det_fje) kon = dolzina_det_fje - 1;
	zac = predpr_idx[i] - round(0.1*frekvenca);
	if(zac < 0) zac = 0;
      	for(j = zac; j < kon; j++)
	{
	  det_fja_ekg[j] = l_intepolation(zac, det_fja_ekg[zac], kon, det_fja_ekg[kon], j);
	}
    }
  }
  
  
}  
//export(det_fja_ekg,dolzina_det_fje,"AAdet_ppo.txt");  


/*
if(IMAM_PM == 0)
{
  manjsi = 0;
  for(i = 0; i < predpr_stevec-1; i++)
  {
    rr_tmp = (double)(predpr_idx[i+1] - predpr_idx[i])/frekvenca;
    if(rr_tmp < 1.25*rr1 && rr_tmp > 0.75*rr1)
    {
      manjsi++;
    }    
  }
//  printf("manjsi  %d  %d\n", manjsi, tmp_st);
  if(fabs(1.0 - (double)(manjsi)/tmp_st) < 0.25)
    IMAM_PM2 = 1;
}*/
  
}


///******************++
///


//export(det_fja_ekg,dolzina_det_fje,"aa_d2.txt");


  
	for(i = 0; i < dolzina_det_fje; i++)
	{
		if((i+2*oknoGL-2) < dolzina_det_fje) tmp_ekg[(i+2*oknoGL-2)] = det_fja_ekg[i];
	}
		
	for(i = 0; i < (2*oknoGL-2); i++)
	{
		tmp_ekg[i] = tmp_ekg[(2*oknoGL-2)]; 
	}
	for(i = 0; i < (dolzina_det_fje); i++)
	{
		if((i+oknoGL) > (dolzina_det_fje)){ tmp_ekg[i] = 0;} 
		else
		{
			j = maksimum(tmp_ekg, (i+oknoGL), i);
			tmp_ekg[i] = tmp_ekg[j]; 
		}
	}
	for(i = 0; i < (dolzina_det_fje); i++)
	{	
		if((i+oknoGL) > (dolzina_det_fje)) tmp_ekg[i] =  0;
		else
		{
			j = minimum(tmp_ekg, (i+oknoGL), i);
			tmp_ekg[i] = tmp_ekg[j]; 
		}
	}
	for(i = 0; i < (dolzina_det_fje); i++)
	{
		if((i+oknoGL) > (dolzina_det_fje)) tmp_ekg[i] =  0;
		else
		{
			j = minimum(tmp_ekg, (i+oknoGL), i);
			tmp_ekg[i] = tmp_ekg[j]; 
		}
	}
	for(i = 0; i < (dolzina_det_fje); i++)
	{	
		if((i+oknoGL) > (dolzina_det_fje)) tmp_ekg[i] =  0;
		else
		{
			j = maksimum(tmp_ekg, (i+oknoGL), i);
			tmp_ekg[i] = tmp_ekg[j]; 
		}
	}

j = maksimum(tmp_ekg, (dolzina_det_fje -1), dolzina_det_fje - 1 - frekvenca*2);
  for(i = (dolzina_det_fje - 1 - frekvenca*2); i < dolzina_det_fje; i++)
  {
    tmp_ekg[i] = tmp_ekg[j];
  }		

    
  
	for(i = 0; i < dolzina_det_fje; i++)
	{	
		if((det_fja_ekg[i] - tmp_ekg[i]) < 0) det_fja_ekg[i] = 0;
		else det_fja_ekg[i] = det_fja_ekg[i] - tmp_ekg[i];
	}

	return (dolzina_det_fje);
}

int naredi_BP_det_fjo(void)
{
	int i, dolzina_det_fje, okno, j;
	okno = OKNO_BP*frekvenca;

	
	filtriranje(bbp, pritisk, fpritisk, nrSamps); 
	dolzina_det_fje = nrSamps-bbp.zamik;
				
	for(i = 0; i < dolzina_det_fje; i++)
	{
		if(fpritisk[i+bbp.zamik]>0)
		{fpritisk[i] = fpritisk[i+bbp.zamik]*fpritisk[i+bbp.zamik];}
		else fpritisk[i] = 0;
	}

	for(i = 0; i < dolzina_det_fje; i++)
	{
		if((i+2*okno-2) < dolzina_det_fje) tmp_bp[(i+2*okno-2)] = fpritisk[i];
	}
		
	for(i = 0; i < (2*okno-2); i++)
	{
		tmp_bp[i] = tmp_bp[(2*okno)]; 
	}
	for(i = 0; i < dolzina_det_fje; i++)
	{
		if((i+okno) > dolzina_det_fje) tmp_bp[i] = 0;
		else
		{
			j = maksimum(tmp_bp, (i+okno), i);
			tmp_bp[i] = tmp_bp[j]; 
		}
	}
	for(i = 0; i < dolzina_det_fje; i++)
	{	
		if((i+okno) > dolzina_det_fje) tmp_bp[i] = 0;
		else
		{
			j = minimum(tmp_bp, (i+okno), i);
			tmp_bp[i] = tmp_bp[j]; 
		}
	}
	for(i = 0; i < dolzina_det_fje; i++)
	{
		if((i+okno) > dolzina_det_fje) tmp_bp[i] = 0;
		else
		{
			j = minimum(tmp_bp, (i+okno), i);
			tmp_bp[i] = tmp_bp[j]; 
		}
	}
	for(i = 0; i < dolzina_det_fje; i++)
	{	
		if((i+okno) > dolzina_det_fje) tmp_bp[i] = 0;
		else
		{
			j = maksimum(tmp_bp, (i+okno), i);
			tmp_bp[i] = tmp_bp[j]; 
		}
	}	


	for(i = 0; i < dolzina_det_fje; i++)
	{	
		if((fpritisk[i] - tmp_bp[i]) < 0) fpritisk[i] = 0;
		else fpritisk[i] = fpritisk[i] - tmp_bp[i];
	}	
 

	return (dolzina_det_fje);
}

void preracunajRR(double* sig, double * RR, double rr_prvi, int dolzina)
{
	int i, prejsnji;
	int st = 0;
	
	st = 0;
	for(i = 0; i < dolzina; i++)
	{
		RR[i] = 0;
		if(sig[i] > 0 && st == 0)
		{ 
			prejsnji = i;
			st++;
		}
		else if(sig[i] > 0)
		{
			RR[i] = (i - prejsnji)/(double)frekvenca;
			if(st == 1)
			{  
				RR[prejsnji] = rr_prvi;
			} 
			prejsnji = i;
			st++;
		}
	}
}

int intervali_suma(double *signal, double *prag, int dolzina)
{
	int tmp_zac, tmp_konec, i;
	int k = 1;
	int noise = 0;
  

	while(k < dolzina-1)
	{
		if(signal[k] >= 1.0*prag[k])
		{
			if(k==1 && signal[0] > 1.0*prag[0]) tmp_zac = 0;
			else if(signal[k-1] < 1.0*prag[k-1]) tmp_zac = k;
			if(signal[k+1] < 1.0*prag[k+1] || k+1 == dolzina-1)
			{
				if(k+1 == dolzina-1) tmp_konec = k+1; 
				else tmp_konec = k;
				
				if((tmp_konec - tmp_zac) > SIRINA*frekvenca)
				{
						if(interval >= VELIKOST) interval = VELIKOST - 1;
						intervali[interval][0] = tmp_zac;
						intervali[interval][1] = tmp_konec;
						interval++;
				}
			}
		}
		k++;
	}
 
	for(i = 0; i < interval; i++)
	{
		noise = noise + (intervali[i][1] - intervali[i][0]);		
	}

	return noise;
}

void veckratno(double* sig, int sig_len, int zacetek, double konst08, double konst12, double konst08A, double konst12A,
double k_za_prag, double *nauceni, double *fja_za_prag, double *det_prag)
{
	int i, k, konec, zace;
	double s;
	double rr[3] = {0,0,0};
	double amp[4] = {0,0,0,0};
	double peak = 0.0;
	int idx[4] = {0,0,0,0};
	int id;
	int pk_n = 1;
	i = zacetek;
	
int zacetek1 = 0;
int konec1 = 0;	
int kandidat = 0;
int k1 = 0;
int meja1 = 1;//MEJA1*frekvenca;
int meja2 = 0.1*frekvenca;	//MEJA2*frekvenca;	
int imam_index = 1;

int up, kp;
	
	while(i < sig_len)
	{
		if(sig[i] > prag_ucenje[i])
		{
			peak = sig[i];
			while(sig[i] >= prag_ucenje[i])
			{
			  if(sig[i] >= peak) 
			  {
			    id = i;
			    peak = sig[id];
			  }
			  i++;
			  if(i >= (sig_len-1)) break;
			}
/*	up = i;
			while(sig[i] < prag_ucenje[i])
			{
			  i++;
			  if(i >= (sig_len-1)) break;
			 }
			 if((i - up) >= meja2)//200ms pod pragom
			  {
				if(kp == 1)
				{
				  kp = 0;
				  if(sig[id] > sig[kandidat])
				  {	
				    id = kandidat;
				    
				  }
				} 
*/

			if(pk_n == 0)
			{
				amp[0] = peak;
				idx[0] = id;		
				pk_n++;							
			}
			else if (pk_n == 1)
			{
				if(konst08A*amp[0] <= peak && konst12A*amp[0] >= peak)
				{
					rr[0] = id - idx[0];
					idx[1] = id;
					amp[1] = peak;
					pk_n++;
				}
				else
				{ 
				  pk_n = 0;
				}
			}
			else if (pk_n == 2)
			{
				if(konst08A*amp[1] <= peak && konst12A*amp[1] >= peak && 
				konst08A*aMean(amp, 2) <= peak && konst12A*aMean(amp, 2) >= peak && 
				konst08*rr[0] <= (id-idx[1]) && konst12*rr[0] >= (id-idx[1]) && 
				(id-idx[1]) <= round(RRmax_uc*frekvenca) && (id-idx[1]) >= round(RRmin_uc*frekvenca))
				{
					rr[1] = id - idx[1];
					idx[2] = id;
					amp[2] = peak;
					pk_n++;
				}
				else
				{
					idx[0] = id;
					amp[0] = peak;
					pk_n = 1;					
				}
			}
			else if (pk_n == 3)
			{
				if(konst08A*amp[2] <= peak && konst12A*amp[2] >= peak && 
				konst08A*aMean(amp, 3) <= peak && konst12A*aMean(amp, 3) >= peak && 
				konst08*rr[1] <= (id-idx[2]) && konst12*rr[1] >= (id-idx[2]) &&
				konst08*aMean(rr,2) <= (id-idx[2]) && konst12*aMean(rr,2) >= (id-idx[2]))
				{
					rr[2] = id - idx[2];
					idx[3] = id;
					amp[3] = peak;
					pk_n++;
				}
				else
				{
					idx[0] = id;
					amp[0] = peak;
					pk_n = 1;					
				}
			}
/*	}
	else
	{
	  if(kp == 1)
	  {
//	    kp = 0;
	    if(sig[id] > sig[kandidat])
	    {	
	    id = kandidat;
	    }
	  }
	  else kandidat = id;
	}  
*/			i++;
			
		}
		i++;
		if(pk_n == 4)
		{
			konec = idx[3]+ round(aMean(rr,3)/4);
			if(konec >= (sig_len - 1)) konec = sig_len;

			zace = idx[0] - round(aMean(rr,3)/4);
			if(zace < 0) zace = 0;
			
			for(k = zace; k < konec; k++)
			{
				RR_interpoliran[k] = aMean(rr,3)/frekvenca;
			}

			nauceni[idx[0]] = 5;
			nauceni[idx[1]] = 5;			
			nauceni[idx[2]] = 5;
			nauceni[idx[3]] = 5;
			
			if (stejemRR >= VELIKOST) stejemRR = (VELIKOST - 1);
			RRpovprUCENJE[stejemRR] = aMean(rr,3)/frekvenca;
			stejemRR++;

			s = (k_za_prag*aMean2(fja_za_prag, ((idx[3] - idx[0]) + round(aMean(rr,3)/4)), zace)); 
			for(k = zace; k <= konec; k++)
			{
				det_prag[k] = s;
			}		
			idx[0] = idx[3];
			amp[0] = amp[3];
			pk_n = 1;
		}
	}

}

int ekgUcenje(double* sig, int sig_len, int st_max, double *nauceni, double *fja_za_prag, double *det_prag)
{
	double s;
	double k_za_prag = 1.3;
	double k_ucenje = 1.0;
	double rr[3] = {0,0,0};
	double amp[4] = {0,0,0,0};
	double peak = 0.0;
	int idx[4] = {0,0,0,0};
	int i,id, l, t, startIdx, stopIdx;
	int pk_n = 0;
	int nic_nasel = 0;
	double konst08 = k08;
	double konst12 = k12;
	double konst08A = k07;
	double konst12A = k13;
	int stevec = 0;
	int kon = 0;
	int zacne;
	int end;
	int okno;
	//int vel = nrSamps-1;
//	double test[9*VELIKOST];
	//double test[sig_len];
	int u = 0;
int imam_index = 1;
int zacetek1 = 0;
int konec1 = 0;	
int kandidat = 0;
int k = 0;
int meja1 = 1;//MEJA1*frekvenca;
	int meja2 = 0.1*frekvenca;
	
int up, kp;	
/*	okno = oknoSrednjaV*frekvenca;
u = 0;
	for(i = 0; i < (sig_len - okno); i++) 
	{
		s = k_ucenje*aMean2(det_fja_ekg, okno, i);
		if(s <= KONST_NI_SIGNALA) s = k_ucenje*KONST_NI_SIGNALA;
		prag_ucenje[(i+frekvenca)] = s;
		MedianaEkg[u] = s;
		u++;
	//if(u >=9*VELIKOST) u = (9*VELIKOST) - 1;
	if(u >= sig_len) u = (sig_len) - 1;
	  
	}

		qsort(MedianaEkg, u, sizeof(double), cmpfunc);
		if(u % 2 == 1) s = MedianaEkg[((u+1)/2)];
		else s = (MedianaEkg[u/2]+MedianaEkg[(u/2)+1])/2;	
	
	for(i = 0; i < sig_len; i++) 
	{
		prag_ucenje[i] = s;
	}
*/		
	okno = oknoSrednjaV*frekvenca;
	for(i = 0; i < (sig_len - okno); i++) 
	{
		s = k_ucenje*aMean2(det_fja_ekg, okno, i);
		if(s <= KONST_NI_SIGNALA) s = k_ucenje*KONST_NI_SIGNALA;
		prag_ucenje[(i+frekvenca)] = s;
	}
	for(i = 0; i < frekvenca; i++) 
	{
		prag_ucenje[i] = prag_ucenje[frekvenca];
	}
	for(i = (sig_len - okno); i < sig_len; i++) 
	{
		prag_ucenje[i] = prag_ucenje[(sig_len - okno-1)];
//		printf("%f\n",prag_ucenje[(sig_len - okno-1)]);
	}

while (stevec < 3)
{
	i = 0;
	while(pk_n < 4 && i < sig_len)
	{
		if(sig[i] > prag_ucenje[i])
		{
			peak = sig[i];			
			while(sig[i] >= prag_ucenje[i])
			{
				if(sig[i] >= peak) 
				{
				  id = i;
				  peak = sig[id];
				}
				i++;
				if(i >= (sig_len-1)) break;
			}
/*	up = i;
			while(sig[i] < prag_ucenje[i])
			{
			  i++;
			  if(i >= (sig_len-1)) break;
			 }
			 if((i - up) >= meja2)//200ms pod pragom
			  {
				if(kp == 1)
				{
				  kp = 0;
				  if(sig[id] > sig[kandidat])
				  {	
				    id = kandidat;
				    
				  }
				} 			
*//*			peak = sig[i];
			zacetek1 = i;
			while(sig[i] >= prag_ucenje[i])
			{
				if(sig[i] >= peak) 
				{
				  id = i;
				  peak = sig[id];
				}
				i++;
				if(i >= (sig_len-1)) break;
			}
			if((i - zacetek1) >= meja1)
			{	
			  konec1 = i;
			  while(sig[i] >= prag_ucenje[i])
			  {	
				i++;
				if(i >= (sig_len-1)) break;
			  }
			  if((i - konec1) >= meja2)//200ms pod pragom
			  {
			    if(k == 1)
			    {
			      	if(sig[id] > sig[kandidat])
				id = kandidat;
				k = 0;
				imam_index = 0;
			    }
			    else imam_index = 0;
			  }
			  else
			  { 
			    if(k = 1)
			    {
   			      	if(sig[id] > sig[kandidat])
				id = kandidat;
				//k = 0;

			    }
			    else
			    {  
			      kandidat = id;
			      k = 1;
			    }
			  }  
			}  
	if(imam_index == 0)
	{  
*/			if(pk_n == 0)
			{
				amp[0] = peak;
				idx[0] = id;		
				pk_n++;				
			}
			else if (pk_n == 1)
			{
				if(konst08A*amp[0] <= peak && konst12A*amp[0] >= peak)
				{
					rr[0] = id - idx[0];
					idx[1] = id;
					amp[1] = peak;
					pk_n++;
				}
				else
				{ 
				   pk_n = 0;
				}			  
			}
			else if (pk_n == 2)
			{
				if(konst08A*amp[1] <= peak && konst12A*amp[1] >= peak && 
				konst08A*aMean(amp, 2) <= peak && konst12A*aMean(amp, 2) >= peak && 
				konst08*rr[0] <= (id-idx[1]) && konst12*rr[0] >= (id-idx[1]) && 
				(id-idx[1]) <= round(RRmax_uc*frekvenca) && (id-idx[1]) >= round(RRmin_uc*frekvenca))
				{
					rr[1] = id - idx[1];
					idx[2] = id;
					amp[2] = peak;
					pk_n++;
				}
				else
				{
					idx[0] = id;
					amp[0] = peak;
					pk_n = 1;					
				}				
			}
			else if (pk_n == 3)
			{
				if(konst08A*amp[2] <= peak && konst12A*amp[2] >= peak && 
				konst08A*aMean(amp, 3) <= peak && konst12A*aMean(amp, 3) >= peak && 
				konst08*rr[1] <= (id-idx[2]) && konst12*rr[1] >= (id-idx[2]) &&
				konst08*aMean(rr,2) <= (id-idx[2]) && konst12*aMean(rr,2) >= (id-idx[2]))
				{
					rr[2] = id - idx[2];
					idx[3] = id;
					amp[3] = peak;
					pk_n++;
				}
				else
				{
					idx[0] = id;
					amp[0] = peak;
					pk_n = 1;					
				}
			}
/*		    }
		    else
	{
	  if(kp == 1)
	  {
	//    kp = 0;
	    if(sig[id] > sig[kandidat])
	    {	
	    id = kandidat;
	    }
	  }
	  else kandidat = id;
	} 
*/			i++;
		}
		i++;
	}
	
	if(pk_n == 4) 
	{

		nauceni[idx[0]] = 5;
		nauceni[idx[1]] = 5;
		nauceni[idx[2]] = 5;
		nauceni[idx[3]] = 5;

		RRpovprUCENJE[stejemRR] = aMean(rr,3)/frekvenca;
		stejemRR++;

		zacne = (idx[0] - round(aMean(rr,3)/4));
		if(zacne < 0) zacne = 0;
		end = idx[3]+ round(aMean(rr,3)/4);
		if(end > (sig_len - 1)) end = sig_len; 

		for(l = zacne; l < end; l++)
		{
			RR_interpoliran[l] = aMean(rr,3)/frekvenca;
		}

//		s = (k_za_prag*aMean2(fja_za_prag, ((idx[3] - idx[0]) + round(aMean(rr,3)/4)), zacne)); 
		s = (k_za_prag*aMean2(fja_za_prag, ((idx[3] - idx[0]) + round(aMean(rr,3)/4)), zacne)); 

		for(l = zacne; l <= end; l++)
		{
			det_prag[l] = s;
		}
		
		idx[0] = idx[3];
		amp[0] = amp[3];
		pk_n = 1;	
	
		veckratno(sig, sig_len, i,  konst08, konst12, konst08A, konst12A, k_za_prag, nauceni, fja_za_prag, det_prag);	
		break;
	}
	else
	{	
		pk_n = 0;
	
		konst08 = konst08 - SPUSTIMmeje;
		konst12 = konst12 + SPUSTIMmeje;
		konst08A = konst08A - SPUSTIMmeje;
		konst12A = konst12A + SPUSTIMmeje;
		stevec ++;
		if(stevec == 3)
		{
			nic_nasel = 1;
			break;
		}
		
	}	
	
}	
	
	if (nic_nasel == 1)	
	{		
		for(i = 0; i < (sig_len - oknoSrednjaV*frekvenca); i++) 
		{
			s = k_za_prag*aMean2(fja_za_prag, oknoSrednjaV*frekvenca, i);
			if(s <= KONST_NI_SIGNALA) s = KONST_NI_SIGNALA;
			det_prag[(i+frekvenca)] = s;
		}
				
		for(i = 0; i < frekvenca; i++) 
		{
			det_prag[i] = det_prag[frekvenca];
		}
	
		for(i = (sig_len - frekvenca); i < sig_len; i++) 
		{
			det_prag[i] = det_prag[(sig_len - frekvenca -1)];
		}
		rr_naucen_EKG = RR75;
	}
	
	else
	{
		for(i = 0; i < sig_len; i++)
		{
			if(det_prag[i] != 0)
			{ 
				t = i;
				break;
			}
		}
		
		for(i = 0; i < t; i++)
		{
			det_prag[i] = det_prag[t];
		}
		
		for(i = sig_len; i >= 0; i--)
		{
			if(det_prag[i] != 0)
			{ 
				t = i;
				break;
			}
		}
		
		for(i = sig_len; i > t; i--)
		{
			det_prag[i] = det_prag[t];
		}		
		
		startIdx = 0;
		while(1)
		{
			while(det_prag[startIdx] != 0)
			{
				if(startIdx < sig_len) startIdx++;
				else
				{ 
					kon = 1;
					break;
				}	
			} 
			if(kon == 1) break;
			
			startIdx--;
			stopIdx = startIdx + 1;
			while(det_prag[stopIdx] == 0)
			{stopIdx++;} 
			for(i = (startIdx + 1); i < stopIdx; i++)
			{		
				det_prag[i] = l_intepolation(startIdx, det_prag[startIdx], stopIdx, det_prag[stopIdx], i);
			}
			startIdx = stopIdx;
		}
		rr_naucen_EKG = aMean(RRpovprUCENJE, stejemRR);
	}
	pricakovano_st_utripov = sig_len/(rr_naucen_EKG*frekvenca);
	
	return nic_nasel; 
}

void interpolacijaRR(int sig_len, double * RR_i, int nic)
{
	int i, t, startIdx, stopIdx, kon;

	if(nic == 0)
	{
		for(i = 0; i < sig_len; i++)
		{
			if(RR_i[i] != 0)
			{ 
				t = i;
				break;
			}
		}
		
		for(i = 0; i < t; i++)
		{
			RR_i[i] = RR_i[t];
		}
		
		for(i = sig_len; i >= 0; i--)
		{
			if(RR_i[i] != 0)
			{ 
				t = i;
				break;
			}
		}
		
		for(i = sig_len; i > t; i--)
		{
			RR_i[i] = RR_i[t];
		}		

		startIdx = 0;
		stopIdx = 0;
		kon = 0;

		while(1)
		{
			while(RR_i[startIdx] != 0)
			{
				if(startIdx < sig_len) startIdx++;
				else
				{ 
					kon = 1;
					break;
				}	
			} 

			if(kon == 1) break;
			
			startIdx--;
			stopIdx = startIdx + 1;

			while(RR_i[stopIdx] == 0)
			{stopIdx++;} 
			for(i = (startIdx + 1); i < stopIdx; i++)
			{		
				RR_i[i] = l_intepolation(startIdx, RR_i[startIdx], stopIdx, RR_i[stopIdx], i);
			}
			startIdx = stopIdx;
		}
	}
	else 
	{
		for(i = 0; i < sig_len; i++)
		{
			RR_i[i] = rr_naucen_EKG;
		}
	}
}


void nizki_BP(double *utripi, double* utripiBP, int dolzina, int dolzinaBP, double *RR, double *RRBP, double *fbp)
{	
	int tempPeakStart, l;
	int zacetek, konec;
	int meja1 = MEJA1*frekvenca;
	int meja2 = MEJA2*frekvenca;
	int kandidat;
	int k = 0;
	int startIdx = 0; 
	int stopIdx = 0;
	int zamik;

	
	while(stopIdx < dolzina)
	{
		while(utripi[stopIdx] == 0)
		{
			if(stopIdx < dolzina) stopIdx++;
			else 
			{	
				stopIdx = dolzina-1;
				break;	
			}
		}
		if(stopIdx-startIdx >= LUKNJA*RR[(int)((stopIdx+startIdx)/2)]*frekvenca)//LUKNJA*frekvenca)	
		{	
			l = startIdx + RR[startIdx]*frekvenca;//
			if(l >= (dolzinaBP - 1)) break;
			while(l < stopIdx)
			{
			  if((utripiBP[l] > 0) && (fbp[l] < 4*srednjiBP) && (fbp[l] > 0.25*srednjiBP))
			  {
			      zamik = round(koef*RRBP[l]*frekvenca+N);
			      if((l-zamik) > 0)
				utripi[(l-zamik)] = 1;
			  } 
			  l++;
			  if(l >= (dolzinaBP - 1)) break;
			}  
		
			
		}
		startIdx = stopIdx;
		stopIdx++;	
	}
}


void nizki_BP_korelacija(double *utripi, double* utripiBP, int dolzina, int dolzinaBP, double *RR, double *RRBP, double *fbp, int zamik, double srBP)
{	
	int tempPeakStart, l;
	int zacetek, konec;
	int meja1 = MEJA1*frekvenca;
	int meja2 = MEJA2*frekvenca;
	int kandidat;
	int k = 0;
	int startIdx = 0; 
	int stopIdx = 0;

	
	while(stopIdx < dolzina)
	{
		while(utripi[stopIdx] == 0)
		{
			if(stopIdx < dolzina) stopIdx++;
			else 
			{	
				stopIdx = dolzina-1;
				break;	
			}
		}
		if(stopIdx-startIdx >= LUKNJA*RR[(int)((stopIdx+startIdx)/2)]*frekvenca)//LUKNJA*frekvenca)	
		{	
			l = startIdx + RR[startIdx]*frekvenca;//
			if(l >= (dolzinaBP - 1)) break;
			while(l < stopIdx)
			{
			  if((utripiBP[l] > 0) && (fbp[l] < 4*srBP) && (fbp[l] > 0.25*srBP))
			  {
			      if((l-zamik) > 0)
				utripi[(l-zamik)] = 1;
			  } 
			  l++;
			  if(l >= (dolzinaBP - 1)) break;
			}  
		
			
		}
		startIdx = stopIdx;
		stopIdx++;	
	}
}






void nizki_nova2(double* utripi, double *utr_novi, int dolzina, double *RR, double luk, int premik)
{	
	int tempPeakStart, l;
	int zacetek, konec;
	int meja1 = MEJA1*frekvenca;
	int meja2 = MEJA2*frekvenca;
	int kandidat;
	int k = 0;
	int startIdx = 0; 
	int stopIdx = 0;
int ind;

	while(stopIdx < dolzina)
	{
		while(utripi[stopIdx] == 0)
		{
			if(stopIdx < dolzina) stopIdx++;
			else 
			{	
				stopIdx = dolzina-1;
				break;	
			}
		}
		ind = round((stopIdx+startIdx)/2);
		if(stopIdx-startIdx >= luk*RR[ind]*frekvenca)
		{	

			l = startIdx + RR[startIdx]*frekvenca/2;
			while(l < (stopIdx - RR[stopIdx]*frekvenca/2))
			{	  
			  if(utr_novi[l] > 0 && (l-premik) >= 0) utripi[l-premik] = 1;  
			  l++;
			}
			
		}
		startIdx = stopIdx;
		stopIdx++;	
	}
}








void nizki_nova_prej(double *signal, double* utripi, double *prag, int dolzina, double *RR)
{	
	int tempPeakStart, l;
	int zacetek, konec;
	int meja1 = MEJA1*frekvenca;
	int meja2 = MEJA2*frekvenca;
	int kandidat;
	int k = 0;
	int startIdx = 0; 
	int stopIdx = 0;

int u = 0;
double suma1, suma2;	
	
int zacetek_temp, konec_temp, zacetek_kand, konec_kand;
	
	while(stopIdx < dolzina)
	{
		while(utripi[stopIdx] == 0)
		{
			if(stopIdx < dolzina) stopIdx++;
			else 
			{	
				stopIdx = dolzina-1;
				break;	
			}
		}
		if(stopIdx-startIdx >= LUKNJA*RR[(int)((stopIdx+startIdx)/2)]*frekvenca)//LUKNJA*frekvenca)	
		{	
			l = startIdx + rr_naucen_EKG*frekvenca/4;
			while(l < (stopIdx - rr_naucen_EKG*frekvenca/4))
			{	  
			    if(signal[l] >= PRAGnizkiUTRIPI*prag[l])
			    {
			      zacetek = l;
			      tempPeakStart = l;
			      while(signal[l] >= PRAGnizkiUTRIPI*prag[l])
			      {
				 if(signal[l] >= signal[tempPeakStart]) {tempPeakStart = l;}
				l++;
				if(l >= dolzina) break;
			      }
			if((l - zacetek) >= meja1)
			{
			  zacetek_temp = zacetek;
			  konec_temp = l;
				konec = l;
				while(signal[l] <= PRAGnizkiUTRIPI*prag[l])
				{
					l++;
					if(l >= dolzina) break;
				}
				if((l - konec) >= meja2)
				{
					if(k == 1)
					{
					    suma1 = fja_suma[zacetek_temp];
					    for(u = zacetek_temp; u <= konec_temp; u++)
					    {
					      if(fja_suma[u] >= suma1) suma1 = fja_suma[u];
					    }
					    suma2 = fja_suma[zacetek_kand];
					    for(u = zacetek_kand; u <= konec_kand; u++)
					    {
					      if(fja_suma[u] >= suma2) suma2 = fja_suma[u];
					    }
						k = 0;
						if(suma1 < suma2)
							tempPeakStart = kandidat;

					}
					utripi[tempPeakStart] = 1;
	
				}
				else
				{				  
					if(l >= dolzina)
					{								
						utripi[tempPeakStart] = 1;
					}
					else if(k == 1)
					{
								    suma1 = fja_suma[zacetek_temp];
					    for(u = zacetek_temp; u <= konec_temp; u++)
					    {
					      if(fja_suma[u] >= suma1) suma1 = fja_suma[u];
					    }
					    suma2 = fja_suma[zacetek_kand];
					    for(u = zacetek_kand; u <= konec_kand; u++)
					    {
					      if(fja_suma[u] >= suma2) suma2 = fja_suma[u];
					    }				k = 0;
						if(suma1 < suma2)
							tempPeakStart = kandidat;
					}
					
					else
					{
						zacetek_kand = zacetek_temp;
						konec_kand = konec_temp;			  
						kandidat = tempPeakStart;
						k = 1;
					}	
				}
			}
			else 
			{
				if(l >= dolzina)
				{		
				    utripi[tempPeakStart] = 1;
					
				}			
			}
		}
		
				l++;
			}
			
		}
		startIdx = stopIdx;
		stopIdx++;	
	}
}






void nizki(double *signal, double* utripi, double *prag, int dolzina)
{	
	int tempPeakStart, l;
	int zacetek, konec;
	int meja1 = MEJA1*frekvenca;
	int meja2 = MEJA2*frekvenca;
//	int zadnji = 0;
	int kandidat;
	int k = 0;
	int startIdx = 0; 
	int stopIdx = 0;

int u = 0;
double suma1, suma2;	
	
int zacetek_temp, konec_temp, zacetek_kand, konec_kand;
	
	while(stopIdx < dolzina)
	{
		while(utripi[stopIdx] == 0)
		{
			if(stopIdx < dolzina) stopIdx++;
			else 
			{	
				stopIdx = dolzina-1;
				break;	
			}
		}
		if(stopIdx-startIdx >= LUKNJA*rr_naucen_EKG*frekvenca)
		{	
			l = startIdx + rr_naucen_EKG*frekvenca/4;
			while(l < (stopIdx - rr_naucen_EKG*frekvenca/4))
			{	  
			    if(signal[l] >= PRAGnizkiUTRIPI*prag[l])
			    {
			      zacetek = l;
			      tempPeakStart = l;
			      while(signal[l] >= PRAGnizkiUTRIPI*prag[l])
			      {
				 if(signal[l] >= signal[tempPeakStart]) {tempPeakStart = l;}
				l++;
				if(l >= dolzina) break;
			      }
			if((l - zacetek) >= meja1)
			{
			  zacetek_temp = zacetek;
			  konec_temp = l;
				konec = l;
				while(signal[l] <= PRAGnizkiUTRIPI*prag[l])
				{
					l++;
					if(l >= dolzina) break;
				}
				if((l - konec) >= meja2)
				{
					if(k == 1)
					{
					    suma1 = fja_suma[zacetek_temp];
					    for(u = zacetek_temp; u <= konec_temp; u++)
					    {
					      if(fja_suma[u] >= suma1) suma1 = fja_suma[u];
					    }
					    suma2 = fja_suma[zacetek_kand];
					    for(u = zacetek_kand; u <= konec_kand; u++)
					    {
					      if(fja_suma[u] >= suma2) suma2 = fja_suma[u];
					    }
						k = 0;
						if(suma1 < suma2)
							tempPeakStart = kandidat;

					}
					utripi[tempPeakStart] = 1;
	
				}
				else
				{				  
					if(l >= dolzina)
					{								
						utripi[tempPeakStart] = 1;
					}
					else if(k == 1)
					{
								    suma1 = fja_suma[zacetek_temp];
					    for(u = zacetek_temp; u <= konec_temp; u++)
					    {
					      if(fja_suma[u] >= suma1) suma1 = fja_suma[u];
					    }
					    suma2 = fja_suma[zacetek_kand];
					    for(u = zacetek_kand; u <= konec_kand; u++)
					    {
					      if(fja_suma[u] >= suma2) suma2 = fja_suma[u];
					    }				k = 0;
						if(suma1 < suma2)
							tempPeakStart = kandidat;
					}
					
					else
					{
						zacetek_kand = zacetek_temp;
						konec_kand = konec_temp;			  
						kandidat = tempPeakStart;
						k = 1;
					}	
				}
			}
			else 
			{
				if(l >= dolzina)
				{		
				    utripi[tempPeakStart] = 1;
					
				}			
			}
		}
		
				l++;
			}
			
		}
		startIdx = stopIdx;
		stopIdx++;	
	}
}

void nizki_nova(double *signal, double* utripi, double *prag, int dolzina, double *RR, double nizek, double luk)
{	
	int tempPeakStart, l;
	int zacetek, konec;
	int meja1 = MEJA1*frekvenca;
	int meja2 = MEJA2*frekvenca;
	int kandidat;
	int k = 0;
	int startIdx = 0; 
	int stopIdx = 0;

int u = 0;
double suma1, suma2;	

int ind;	
int zacetek_temp, konec_temp, zacetek_kand, konec_kand;
int tmp1, tmp2;
double cas = 0.0;
double cas_kand = 0.0;
int polovica;
int polovica_kand;

	while(stopIdx < dolzina)
	{
		while(utripi[stopIdx] == 0)
		{
			if(stopIdx < dolzina) stopIdx++;
			else 
			{	
				stopIdx = dolzina-1;
				break;	
			}
		}
		ind = round((stopIdx+startIdx)/2);
		if(stopIdx-startIdx >= luk*RR[ind]*frekvenca)
		{	

			l = startIdx + RR[startIdx]*frekvenca/2;
			while(l < (stopIdx - RR[stopIdx]*frekvenca/2))
			{	  
			    //if(signal[l] >= PRAGnizkiUTRIPI*prag[l])
if(signal[l] >= nizek*prag[l])
			    {
			      zacetek = l;
			      tempPeakStart = l;
while(signal[l] >= nizek*prag[l])
			      //			      while(signal[l] >= PRAGnizkiUTRIPI*prag[l])
			      {
				 if(signal[l] >= signal[tempPeakStart]) {tempPeakStart = l;}
				l++;
				if(l >= dolzina) break;
			      }

//printf("u  %d   %d  %f\n", tmp1, tmp2, cas);

			if((l - zacetek) >= meja1)
			{
u = tempPeakStart;			      
while(signal[u] > 0)			      
{
  u--;
  if(u < 0){u = 0; break;}
}			      
tmp1 = u;
u = tempPeakStart;			      
while(signal[u] > 0)			      
{
  u++;
  if(u >= dolzina - 1){u = dolzina - 1; break;}
}
tmp2 = u;
cas = (double)(tmp2-tmp1)/frekvenca;				  
polovica = (tmp2+tmp1)/2;


			  zacetek_temp = zacetek;
			  konec_temp = l;
				konec = l;
while(signal[l] <= nizek*prag[l])
				//				while(signal[l] <= PRAGnizkiUTRIPI*prag[l])
				{
					l++;
					if(l >= dolzina) break;
				}
				if((l - konec) >= meja2)
				{
					if(k == 1)
					{
/*					    suma1 = fja_suma[zacetek_temp];
					    for(u = zacetek_temp; u <= konec_temp; u++)
					    {
					      if(fja_suma[u] >= suma1) suma1 = fja_suma[u];
					    }
					    suma2 = fja_suma[zacetek_kand];
					    for(u = zacetek_kand; u <= konec_kand; u++)
					    {
					      if(fja_suma[u] >= suma2) suma2 = fja_suma[u];
					    }
*/						k = 0;
						if(signal[tempPeakStart] > signal[kandidat])
//if(cas_kand > cas)
						{	tempPeakStart = kandidat;
						cas = cas_kand;
						polovica = polovica_kand;
						}


//						if(suma1 < suma2)
//							tempPeakStart = kandidat;

					}
//if(cas < 0.08)
//printf("nizki  %d   %f\n",tempPeakStart, cas);
//					if(cas >= 0.05)
//if(cas >= 0.21)
//{//printf("%f\n", cas);
//	utripi[polovica] = 1;  
 // printf("%d	%d\n", tempPeakStart, polovica);
//}
//else 
  utripi[tempPeakStart] = 1;

				}
				else
				{				  
					if(l >= dolzina)
					{								
						utripi[tempPeakStart] = 1;
					}
					else if(k == 1)
					{
/*								    suma1 = fja_suma[zacetek_temp];
					    for(u = zacetek_temp; u <= konec_temp; u++)
					    {
					      if(fja_suma[u] >= suma1) suma1 = fja_suma[u];
					    }
					    suma2 = fja_suma[zacetek_kand];
					    for(u = zacetek_kand; u <= konec_kand; u++)
					    {
					      if(fja_suma[u] >= suma2) suma2 = fja_suma[u];
					    }				
					    
*/				///	    k = 0;
//if(cas_kand > cas)//
						if(signal[tempPeakStart] > signal[kandidat])
						{ 
							tempPeakStart = kandidat;
							cas = cas_kand;
						polovica = polovica_kand;							
						}
//						if(suma1 < suma2)
//							tempPeakStart = kandidat;
					}
					
					else
					{
//						zacetek_kand = zacetek_temp;
//						konec_kand = konec_temp;			  
						kandidat = tempPeakStart;
						cas_kand = cas;
						polovica_kand = polovica;
						k = 1;
					}	
				}
			}
			else 
			{
				if(l >= dolzina)
				{		
				    utripi[tempPeakStart] = 1;
					
				}			
			}
		}
		
				l++;
			}
			
		}
		startIdx = stopIdx;
		stopIdx++;	
	}
}


void detektiraj_utripe_ekg(double *signal, double *prag, double *utripi, double rr_naucen, int dolzina_signala)
{
	int tempPeakStart, i;
	int zacetek;
	int konec;
	int meja1 = MEJA1*frekvenca;
	int meja2 = MEJA2*frekvenca;
	int kandidat;
	int k = 0;
	i = 0;
	int l = 0;
	int start, end;
int u = 0;
double suma1, suma2;	
int zacetek_temp, konec_temp, zacetek_kand, konec_kand;
int tmp1, tmp2;
double cas = 0.0;
double cas_kand = 0.0;
int polovica;
int polovica_kand;

	start = 1;
	while(l <= inter)
	{
	  if(l < inter) end = NauceniInt[l][0];
	  if(l == inter) end = dolzina_signala-1;
	  i = start;
	
	while(i <= end)
	{
		if(signal[i] >= prag[i])
		{
			zacetek = i;
			tempPeakStart = i;
			while(signal[i] >= prag[i])
			{
				if(signal[i] >= signal[tempPeakStart])// && signal[i] < signal[i+1]) 
				  {tempPeakStart = i;}
				i++;
				if(i >= dolzina_signala) break;
			}
			if((i - zacetek) >= meja1)
			{
			  
			  u = tempPeakStart;			      
			  while(signal[u] > 0)			      
			  {
			    u--;
			    if(u < 0){u = 0; break;}
			  }			      
			  tmp1 = u;
			  u = tempPeakStart;			      
			  while(signal[u] > 0)			      
			  {
			    u++;
			    if(u >= dolzina_signala - 1){u = dolzina_signala - 1; break;}
			  }
			  tmp2 = u;
			  cas = (double)(tmp2-tmp1)/frekvenca;		
			  polovica = (tmp2+tmp1)/2;


			  zacetek_temp = zacetek;
			  konec_temp = i;
			  konec = i;
			  while(signal[i] <= prag[i])
			  {
				i++;
				if(i >= dolzina_signala) break;
			  }
			  if((i - konec) >= meja2)//200ms pod pragom
			  {
				if(k == 1)
				{
				  k = 0;
				  if(signal[tempPeakStart] > signal[kandidat])
				  {	
				    tempPeakStart = kandidat;
				    cas = cas_kand;
				    polovica = polovica_kand;
				  }
				} 
//				if(cas >= 0.22) printf("\n%f\n",cas);
//				  if(cas >= 0.21 &&  cas <= 0.22)
//				  {
//				    utripi[polovica] = 1;  
//				  }
//				  else if(cas < 0.21) 
				    utripi[tempPeakStart] = 1;

			  }
			  else
			  {				  
				  if(i >= dolzina_signala )
				  {								
					utripi[tempPeakStart] = 1;
				  }
				  else if(k == 1)
				  {
				      if(signal[tempPeakStart] > signal[kandidat])
				      {	
					tempPeakStart = kandidat;
					cas = cas_kand;
					polovica = polovica_kand;
				      }
				  }
				  else
				  {	
					kandidat = tempPeakStart;
			  		cas_kand = cas;
					polovica_kand = polovica;
					k = 1;
				  }	
			    }
			    }
			else 
			{
				if(i >= dolzina_signala)
				{		
				    utripi[tempPeakStart] = 1;
					
				}			
			}
		
		}
		i++;
	}	
	
	  start = NauceniInt[l][1];
	  l++;
	  if(l >= (inter+1)){break;}
	}
}





void veckratnoBP(double *bp, int bp_len, int zacetek, double konst08, double konst12, double konst08A, double konst12A,
double k_za_prag, double *nauceni, double *fja_za_prag, double *det_prag)
{
	int i, k, konec, zace;
	double s;
	double rr[3] = {0,0,0};
	double amp[4] = {0,0,0,0};
	double peak = 0.0;
	int idx[4] = {0,0,0,0};
	int id;//,j;
	int pk_n = 1;	
		
	i = zacetek;
	while(i < bp_len)
	{
		if(bp[i] > prag_ucenje_BP[i])
		{
			peak = 0;
			
			while(bp[i] >= prag_ucenje_BP[i])
			{
			  if(bp[i] >= peak) 
			  {
			    id = i;
			    peak = bp[id];
			  }
			  i++;
			  if(i >= (bp_len-1)) break;
			}			
			if(pk_n == 0)
			{
				amp[0] = peak;
				idx[0] = id;		
				pk_n++;							
			}
			else if (pk_n == 1)
			{
				if(konst08A*amp[0] <= peak && konst12A*amp[0] >= peak)
				{
					rr[0] = id - idx[0];
					idx[1] = id;
					amp[1] = peak;
					pk_n++;
				}
				else
				{ 
				  pk_n = 0;
				}
			}
			else if (pk_n == 2)
			{
				if(konst08A*amp[1] <= peak && konst12A*amp[1] >= peak && 
				konst08A*aMean(amp, 2) <= peak && konst12A*aMean(amp, 2) >= peak && 
				konst08*rr[0] <= (id-idx[1]) && konst12*rr[0] >= (id-idx[1]) && 
//				(id-idx[1]) <= (int)RRmax_uc*frekvenca && (id-idx[1]) >= (int)RRmin_uc*frekvenca)
				(id-idx[1]) <= RRmax_uc*frekvenca && (id-idx[1]) >= RRmin_uc*frekvenca)
				{
					rr[1] = id - idx[1];
					idx[2] = id;
					amp[2] = peak;
					pk_n++;
				}
				else
				{
					idx[0] = id;
					amp[0] = peak;
					pk_n = 1;					
				}
			}
			else if (pk_n == 3)
			{
				if(konst08A*amp[2] <= peak && konst12A*amp[2] >= peak && 
				konst08A*aMean(amp, 3) <= peak && konst12A*aMean(amp, 3) >= peak && 
				konst08*rr[1] <= (id-idx[2]) && konst12*rr[1] >= (id-idx[2]) &&
				konst08*aMean(rr,2) <= (id-idx[2]) && konst12*aMean(rr,2) >= (id-idx[2]))
				{
					rr[2] = id - idx[2];
					idx[3] = id;
					amp[3] = peak;
					pk_n++;
				}
				else
				{
					idx[0] = id;
					amp[0] = peak;
					pk_n = 1;					
				}
			}
			i++;
		}
		i++;
		if(pk_n == 4)
		{
			konec = idx[3]+ round(aMean(rr,3)/3);
			if(konec > (bp_len - 1)) konec = bp_len;
amplitudeBP[amplitudeBP_st] = aMean(amp,4);
amplitudeBP_st++;	
if(amplitudeBP_st > bp_len) amplitudeBP_st = bp_len - 1;
			zace = idx[0] - round(aMean(rr,3)/3);
			if(zace < 0) zace = 0;
			
			for(k = zace; k < konec; k++)
			{
				RR_interpoliran_BP[k] = aMean(rr,3)/frekvenca;
			}	
			nauceni[idx[0]] = 6;
			nauceni[idx[1]] = 6;			
			nauceni[idx[2]] = 6;
			nauceni[idx[3]] = 6;

			if (stejemRR_BP >= VELIKOST) stejemRR_BP = (VELIKOST - 1);
			RRpovprUCENJE_BP[stejemRR_BP] = aMean(rr,3)/frekvenca;
			stejemRR_BP++;

			s = (k_za_prag*aMean2(fja_za_prag, ((idx[3] - idx[0]) + round(aMean(rr,3))), (idx[0] - round(aMean(rr,3)/2)))); 
			for(k = zace; k <= konec; k++)
			{
				det_prag[k] = s;
			}
			idx[0] = idx[3];
			amp[0] = amp[3];
			pk_n = 1;	
		}
	}


qsort(amplitudeBP, amplitudeBP_st, sizeof(double), cmpfunc);
if(amplitudeBP_st % 2 == 1) srednjiBP = amplitudeBP[((amplitudeBP_st+1)/2)];
else srednjiBP = (amplitudeBP[amplitudeBP_st/2]+amplitudeBP[(amplitudeBP_st/2)+1])/2;		
	
//srednjiBP = aMean(amplitudeBP, amplitudeBP_st);
//printf("%f\n", srednjiBP);
}

int bpUcenje(double* bp, int bp_len, int st_max, double *nauceni, double *fja_za_prag, double *det_prag)
{
	int i, id, l, t, startIdx, stopIdx;// j,
	double s;  
	double k_za_prag = 0.75;
	double k_ucenje = 0.75;
	double amp[4] = {0,0,0,0};
	double peak = 0;
	int idx[4] = {0,0,0,0};
	double rr[3] = {0,0,0};
	int pk_n = 0;
	double konst08 = k08;
	double konst12 = k12;
	double konst08A = k07;
	double konst12A = k13;
	int stevec = 0;
	int nic_nasel = 0;
	int ni_naucil = 0;	
	int  zacne;
	int kon = 0;
	int end;
	double Vrez = 0.682; double Rez = 1.618;
	int okno;	

//	double test[9*VELIKOST];
	int u = 0;
	
/*	okno = oknoSrednjaV*frekvenca;

	for(i = 0; i < (bp_len - okno); i++) 
	{
		s = k_ucenje*aMean2(fpritisk, okno, i);
		if(s <= KONST_NI_SIGNALA) s = k_ucenje*KONST_NI_SIGNALA;
		prag_ucenje_BP[(i+frekvenca)] = s;
		test[u] = s;
		u++;
		if(u >= 9*VELIKOST) u = (9*VELIKOST) - 1;
	}

			
		qsort(test, u, sizeof(double), cmpfunc);
		if(u % 2 == 1) s = test[((u+1)/2)];
		else s = (test[u/2]+test[(u/2)+1])/2;	
	
	for(i = 0; i < bp_len; i++) 
	{
		prag_ucenje_BP[i] = s;
	}
		
	
*/	
/*
	okno = oknoSrednjaV*frekvenca;
u = 0;
	for(i = 0; i < (bp_len - okno); i++) 
	{
		s = k_ucenje*aMean2(fpritisk, okno, i);
		if(s <= KONST_NI_SIGNALA) s = k_ucenje*KONST_NI_SIGNALA;
		prag_ucenje_BP[(i+frekvenca)] = s;
		MedianaEkg[u] = s;
		u++;
	//if(u >=9*VELIKOST) u = (9*VELIKOST) - 1;
	if(u >= bp_len) u = (bp_len) - 1;
	  
	}

		qsort(MedianaEkg, u, sizeof(double), cmpfunc);
		if(u % 2 == 1) s = MedianaEkg[((u+1)/2)];
		else s = (MedianaEkg[u/2]+MedianaEkg[(u/2)+1])/2;	
	
	for(i = 0; i < bp_len; i++) 
	{
		prag_ucenje_BP[i] = s;
	}

*/



	okno = oknoSrednjaV*frekvenca;
	for(i = 0; i < (bp_len - okno); i++) 
	{
		s = k_ucenje*aMean2(fpritisk, okno, i);
		if(s <= KONST_NI_SIGNALA) s = k_ucenje*KONST_NI_SIGNALA;
		prag_ucenje_BP[(i+frekvenca)] = s;
	}
	for(i = 0; i < frekvenca; i++) 
	{
		prag_ucenje_BP[i] = prag_ucenje_BP[frekvenca];
	}
	for(i = (bp_len - okno); i < bp_len; i++) 
	{
		prag_ucenje_BP[i] = prag_ucenje_BP[(bp_len - okno-1)];
	}		
		
	
while (stevec < 3)
{	
	i = 0;
	while(pk_n < 4 && i < bp_len)
	{
		if(bp[i] > prag_ucenje_BP[i])
		{
			peak = 0;
			while(bp[i] >= prag_ucenje_BP[i])
			{
			  if(bp[i] >= peak) 
			  {
			    id = i;
			    peak = bp[id];
			  }
			  i++;
			  if(i >= (bp_len-1)) break;
			}						
			if(pk_n == 0)
			{
				amp[0] = peak;
				idx[0] = id;		
				pk_n++;			
			}
			else if (pk_n == 1)
			{
				if(konst08A*amp[0] <= peak && konst12A*amp[0] >= peak)
				{
					rr[0] = id - idx[0];
					idx[1] = id;
					amp[1] = peak;
					pk_n++;
				}
				else
				{ 
				  pk_n = 0;
				}
			}
			else if (pk_n == 2)
			{
				if(konst08A*amp[1] <= peak && konst12A*amp[1] >= peak && 
				konst08A*aMean(amp, 2) <= peak && konst12A*aMean(amp, 2) >= peak &&
				konst08*rr[0] <= (id-idx[1]) && konst12*rr[0] >= (id-idx[1]) && 
				//(id-idx[1]) <= (int)RRmax_uc*frekvenca && (id-idx[1]) >= (int)RRmin_uc*frekvenca)
  				(id-idx[1]) <= RRmax_uc*frekvenca && (id-idx[1]) >= RRmin_uc*frekvenca)
				{
					rr[1] = id - idx[1];
					idx[2] = id;
					amp[2] = peak;
					pk_n++;
				}
				else
				{
					idx[0] = id;
					amp[0] = peak;
					pk_n = 1;					
				}
			}
			else if (pk_n == 3)
			{
				if(konst08A*amp[2] <= peak && konst12A*amp[2] >= peak && 
				konst08A*aMean(amp, 3) <= peak && konst12A*aMean(amp, 3) >= peak && 
				konst08*rr[1] <= (id-idx[2]) && konst12*rr[1] >= (id-idx[2]) &&
				konst08*aMean(rr,2) <= (id-idx[2]) && konst12*aMean(rr,2) >= (id-idx[2]))
				{
					rr[2] = id - idx[2];
					idx[3] = id;
					amp[3] = peak;
					pk_n++;
								}
				else
				{
					idx[0] = id;
					amp[0] = peak;
					pk_n = 1;					
				}
			}
			i++;
		}
		i++;
	}
	if(pk_n == 4) 
	{
		nauceni[idx[0]] = 6;
		nauceni[idx[1]] = 6;
		nauceni[idx[2]] = 6;
		nauceni[idx[3]] = 6;		
		
		zacne = (idx[0] - round(aMean(rr,3)/3));
		if(zacne < 0) zacne = 0;
		end = idx[3]+ round(aMean(rr,3)/3);
		if(end > (bp_len - 1)) end = bp_len; 
amplitudeBP_st = 0;		
amplitudeBP[amplitudeBP_st] = aMean(amp,4);
amplitudeBP_st++;
		for(l = zacne; l < end; l++)
		{
			RR_interpoliran_BP[l] = aMean(rr,3)/frekvenca;
		}
//printf("%f  %f\n",aMean(rr,3)/frekvenca, aMean(rr,3));		
		RRpovprUCENJE_BP[stejemRR_BP] = aMean(rr,3)/frekvenca;
		stejemRR_BP++;		


		s = (k_za_prag*aMean2(fja_za_prag, ((idx[3] - idx[0]) + round(aMean(rr,3))), zacne)); 
		for(l = zacne; l <= end; l++)
		{
			det_prag[l] = s;
		}
		
		idx[0] = idx[3];
		amp[0] = amp[3];
		pk_n = 1;

		veckratnoBP(bp, bp_len, i,konst08, konst12, konst08A, konst12A, k_za_prag, nauceni, fja_za_prag, det_prag);
		break;
	}	
	else
	{
		pk_n = 0;
			
		konst08 = konst08 - SPUSTIMmeje;
		konst12 = konst12 + SPUSTIMmeje;
		konst08A = konst08A - SPUSTIMmeje;
		konst12A = konst12A + SPUSTIMmeje;
		stevec ++;
		if(stevec == 3)
		{
			nic_nasel = 1;
			break;
		}
	}		
 }	

		if(nic_nasel == 1)
		{	
			rr_naucen_BP = RR75;
			for(i = 0; i < bp_len; i++)
			{
				det_prag[i] = prag_ucenje_BP[i];
				RR_interpoliran_BP[i] = rr_naucen_BP;
		  
			}	  
			ni_naucil = 1;
		}
		else
		{			
			for(i = 0; i < bp_len; i++)
			{
				if(det_prag[i] != 0)
				{ 
					t = i;
					break;
				}
			}
		
			for(i = 0; i < t; i++)
			{
				det_prag[i] = det_prag[t];
			}
		
			for(i = bp_len; i >= 0; i--)
			{
				if(det_prag[i] != 0)
				{ 
					t = i;
					break;
				}
			}
		
			for(i = bp_len; i > t; i--)
			{
				det_prag[i] = det_prag[t];
			}		
		
			startIdx = 0;
			while(1)
			{
				while(det_prag[startIdx] != 0)
				{
					if(startIdx < bp_len) startIdx++;
					else
					{ 
						kon = 1;
						break;
					}	
				} 
				if(kon == 1)
			 break;
			
				startIdx--;
				stopIdx = startIdx + 1;
				while(det_prag[stopIdx] == 0)
				{stopIdx++;} 
				for(i = (startIdx + 1); i < stopIdx; i++)
				{		
					det_prag[i] = l_intepolation(startIdx, det_prag[startIdx], stopIdx, det_prag[stopIdx], i);
				}
				startIdx = stopIdx;
			}

			rr_naucen_BP = aMean(RRpovprUCENJE_BP, stejemRR_BP);
			
/*			if(st_ekg > 0)
			{  
			
			if((rr_naucen_BP < Vrez*rr_naucen_EKG) || (rr_naucen_BP > Rez*rr_naucen_EKG))
			{
				ni_naucil = 1;
			}
			}
*/		}	
		
	
		pricakovano_st_utripov_BP = bp_len/(rr_naucen_BP*frekvenca);
	
	return ni_naucil;
}


void detektiraj_utripe_bp(double *signal, double *prag, double *utripi, double rr_naucen, int dolzina_signala)
{
	int tempPeakStart, i;
	int zacetek;
	int konec;
	int meja1 = MEJA1BP*frekvenca;
	int meja2 = MEJA2BP*frekvenca;
	int zadnji = 0;
	int kandidat;
	int k = 0;
	i = 0;
	i = 0;
	int l = 0;
	int start, end;
	
	start = 0;
	while(l <= interBP)
	{
	  if(l < interBP) end = NauceniIntBP[l][0];
	  if(l == interBP) end = dolzina_signala-1;
	  i = start;	
	
	
	while(i <= end)
	{
		if(signal[i] >= prag[i])
		{
			zacetek = i;
			tempPeakStart = i;
			zadnji = 1;
			while(signal[i] >= prag[i])
			{
				if(signal[i] >= signal[tempPeakStart]) {tempPeakStart = i;}
				i++;
				if(i >= dolzina_signala) break;
			}
			if((i - zacetek) > meja1)
			{
				konec = i;
				while(signal[i] <= prag[i])
				{
					i++;
					if(i >= dolzina_signala) break;
				}
				if((i - konec) > meja2)
				{
					if(k == 1)
					{
						k = 0;
						if(signal[tempPeakStart] < signal[kandidat])
							tempPeakStart = kandidat;
					}
					utripi[tempPeakStart] = 3;

				}
				else 
				{
					if(i >= dolzina_signala)
					{		
						utripi[tempPeakStart] = 3;
					}
					else if(k == 1)
					{
					  if(signal[tempPeakStart] < signal[kandidat]) 
					    tempPeakStart = kandidat;
					}
					else
					{
						kandidat = tempPeakStart;
						k = 1;
					}	
				}
			}
			else 
			{
				if(i >= dolzina_signala && zadnji > 0)
				{		
					 utripi[tempPeakStart] = 3;
					
				}			
			}
		}
		i++;
	}	
	  start = NauceniIntBP[l][1];
	  l++;
	  if(l >= (interBP+1)){break;}
	}
}





void detektiraj_utripe_bp1(double *signal, double *prag, double *utripi, double rr_naucen, int dolzina_signala)
{
	int tempPeakStart, i;
	int zacetek;
	int konec;
	int meja1 = MEJA1BP*frekvenca;
	int meja2 = MEJA2BP*frekvenca;
	int zadnji = 0;
	int kandidat;
	int k = 0;
	i = 0;
	i = 0;
	int l = 0;
	int start, end;
	
	start = 0;
	while(l <= interBP)
	{
	  if(l < interBP) end = NauceniIntBP[l][0];
	  if(l == interBP) end = dolzina_signala-1;
	  i = start;	
	
	
	while(i <= end)
	{
		if(signal[i] >= prag[i])
		{
			zacetek = i;
			tempPeakStart = i;
			zadnji = 1;
			while(signal[i] >= prag[i])
			{
				if(signal[i] >= signal[tempPeakStart]) {tempPeakStart = i;}
				i++;
				if(i >= dolzina_signala) break;
			}
			if((i - zacetek) > meja1)
			{
				konec = i;
				while(signal[i] <= prag[i])
				{
					i++;
					if(i >= dolzina_signala) break;
				}
				if((i - konec) > meja2)
				{
					if(k == 1)
					{
						k = 0;
						if(signal[tempPeakStart] < signal[kandidat])
							tempPeakStart = kandidat;
					}
					if(utripi[tempPeakStart] == 0) utripi[tempPeakStart] = 3;

					detBP++;
					zadnji = 0;
				}
				else 
				{
					if(i >= dolzina_signala && zadnji > 0)
					{		
						if(k == 1)
						{
							k = 0;
							if(signal[tempPeakStart] < signal[kandidat]) tempPeakStart = kandidat;
						}
						
						if(utripi[tempPeakStart] == 0) utripi[tempPeakStart] = 3;
						detBP++;
					}
					else if(k == 1)
					{
							if(signal[tempPeakStart] < signal[kandidat]) tempPeakStart = kandidat;
					}
					else
					{
						kandidat = tempPeakStart;
						zadnji = 0;
						k = 1;
					}	
				}
			}
			else 
			{
				if(i >= dolzina_signala && zadnji > 0)
				{		
					if(k == 1)
					{
						k = 0;
						if(signal[tempPeakStart] < signal[kandidat])
							tempPeakStart = kandidat;
					}		
					if(utripi[tempPeakStart] == 0) utripi[tempPeakStart] = 3;
					detBP++;
				}			
				zadnji = 0;
			}
		}
		if(i >= dolzina_signala && zadnji > 0)
		{		
			if(k == 1)
			{
				k = 0;
				if(signal[tempPeakStart] < signal[kandidat])
					tempPeakStart = kandidat;
			}
			if(utripi[tempPeakStart] == 0) utripi[tempPeakStart] = 3;
			detBP++;
		}
		i++;
	}	
	  start = NauceniIntBP[l][1];
	  l++;
	  if(l >= (interBP+1)){break;}
	}
}





void nizki_bp(double *signal, double* utripi, double *prag, int dolzina, double *RR, double nizek, double luk)
{	
	int tempPeakStart, l;
	int zacetek, konec;
	int meja1 = MEJA1*frekvenca;
	int meja2 = MEJA2*frekvenca;
	int kandidat;
	int k = 0;
	int startIdx = 0; 
	int stopIdx = 0;

int u = 0;
double suma1, suma2;	

int ind;	
int zacetek_temp, konec_temp, zacetek_kand, konec_kand;
int tmp1, tmp2;
double cas = 0.0;
double cas_kand = 0.0;
int polovica;
int polovica_kand;

	while(stopIdx < dolzina)
	{
		while(utripi[stopIdx] == 0)
		{
			if(stopIdx < dolzina) stopIdx++;
			else 
			{	
				stopIdx = dolzina-1;
				break;	
			}
		}
		ind = round((stopIdx+startIdx)/2);
		if(stopIdx-startIdx >= luk*RR[ind]*frekvenca)
		{	

			l = startIdx + RR[startIdx]*frekvenca/2;
			while(l < (stopIdx - RR[stopIdx]*frekvenca/2))
			{	  
			    //if(signal[l] >= PRAGnizkiUTRIPI*prag[l])
if(signal[l] >= nizek*prag[l])
			    {
			      zacetek = l;
			      tempPeakStart = l;
while(signal[l] >= nizek*prag[l])
			      //			      while(signal[l] >= PRAGnizkiUTRIPI*prag[l])
			      {
				 if(signal[l] >= signal[tempPeakStart]) {tempPeakStart = l;}
				l++;
				if(l >= dolzina) break;
			      }

//printf("u  %d   %d  %f\n", tmp1, tmp2, cas);

			if((l - zacetek) >= meja1)
			{

			  zacetek_temp = zacetek;
			  konec_temp = l;
				konec = l;
while(signal[l] <= nizek*prag[l])
				//				while(signal[l] <= PRAGnizkiUTRIPI*prag[l])
				{
					l++;
					if(l >= dolzina) break;
				}
				if((l - konec) >= meja2)
				{
					if(k == 1)
					{
						k = 0;
						if(signal[tempPeakStart] > signal[kandidat])
							tempPeakStart = kandidat;
						}
  utripi[tempPeakStart] = 1;

				}
				else
				{				  
					if(l >= dolzina)
					{								
						utripi[tempPeakStart] = 1;
					}
					else if(k == 1)
					{

						if(signal[tempPeakStart] > signal[kandidat])
						{ 
							tempPeakStart = kandidat;
						}
					}
					
					else
					{
						kandidat = tempPeakStart;
						k = 1;
					}	
				}
			}
			else 
			{
				if(l >= dolzina)
				{		
				    utripi[tempPeakStart] = 1;
					
				}			
			}
		}
		
				l++;
			}
			
		}
		startIdx = stopIdx;
		stopIdx++;	
	}
}




/*

void detektiraj_utripe_bp(double *signal, double *prag, double *utripi, double rr_naucen, int dolzina_signala)
{
	int tempPeakStart, i;
	int zacetek;
	int konec;
	int meja1 = MEJA1BP*frekvenca;
	int meja2 = MEJA2BP*frekvenca;
	int zadnji = 0;
	int kandidat;
	int k = 0;
	i = 0;
	i = 0;
	int l = 0;
	int start, end;
	
	start = 0;
	while(l <= interBP)
	{
	  if(l < interBP) end = NauceniIntBP[l][0];
	  if(l == interBP) end = dolzina_signala-1;
	  i = start;	
	
	
	while(i <= end)
	{
		if(signal[i] >= prag[i])
		{
			zacetek = i;
			tempPeakStart = i;
			zadnji = 1;
			while(signal[i] >= prag[i])
			{
				if(signal[i] >= signal[tempPeakStart]) {tempPeakStart = i;}
				i++;
				if(i >= dolzina_signala) break;
			}
			if((i - zacetek) > meja1)
			{
				konec = i;
				while(signal[i] <= prag[i])
				{
					i++;
					if(i >= dolzina_signala) break;
				}
				if((i - konec) > meja2)
				{
					if(k == 1)
					{
					  k = 0;
					  if(signal[tempPeakStart] < signal[kandidat])
					  tempPeakStart = kandidat;
					}
//					if(utripi[tempPeakStart] == 0) 
					  utripi[tempPeakStart] = 3;

//					detBP++;
//					zadnji = 0;
				}
				else 
				{
					if(i >= dolzina_signala)// && zadnji > 0)
					{		
					  utripi[tempPeakStart] = 3;
					}
					else if(k == 1)
					{
					  if(signal[tempPeakStart] < signal[kandidat]) 
					    tempPeakStart = kandidat;
					}
					else
					{
						kandidat = tempPeakStart;
						zadnji = 0;
						k = 1;
					}	
				}
			}
			else 
			{
				if(i >= dolzina_signala)
				{		
//					if(k == 1)
//					{
//						k = 0;
//						if(signal[tempPeakStart] < signal[kandidat])
//							tempPeakStart = kandidat;
//					}		
//					if(utripi[tempPeakStart] == 0) 
					  utripi[tempPeakStart] = 3;
//					detBP++;
				}			
//				zadnji = 0;
			}
		}
*/	/*	if(i >= dolzina_signala && zadnji > 0)
		{		
			if(k == 1)
			{
				k = 0;
				if(signal[tempPeakStart] < signal[kandidat])
					tempPeakStart = kandidat;
			}
			if(utripi[tempPeakStart] == 0) utripi[tempPeakStart] = 3;
			detBP++;
		}
*//*		i++;
	}	
	  start = NauceniIntBP[l][1];
	  l++;
	  if(l >= (interBP+1)){break;}
	}
}
*/


int nastavitev_intervali_suma(int stevilo_sum, int stevilo_nauceni)
{
	int i, j;
	i = 0; j = 0;

	while(i < stevilo_nauceni && j < stevilo_sum)
	{
		if((NauceniInt[i][0] <= intervali[j][0]) && (NauceniInt[i][1] <= intervali[j][1]) && (NauceniInt[i][1] > intervali[j][0]))
		{
			intervali[j][0] = NauceniInt[i][1];
			if((intervali[j][1]-intervali[j][0]) <= SIRINA*frekvenca)
			{
				intervali[j][0] = 0;
				intervali[j][1] = 0;
			}			
			i++;
		}		
		else if((NauceniInt[i][0] >= intervali[j][0]) && (NauceniInt[i][1] >= intervali[j][1]) && (NauceniInt[i][0] <= intervali[j][1]))
		{
			intervali[j][1] = NauceniInt[i][0]; 
			if((intervali[j][1]-intervali[j][0]) <= SIRINA*frekvenca)
			{
				intervali[j][0] = 0;
				intervali[j][1] = 0;
			}			
			j++;
		}		
		else if(NauceniInt[i][0] < intervali[j][0] && NauceniInt[i][1] <= intervali[j][0])
		{ 
			i++;
		}
		else if(NauceniInt[i][0] >= intervali[j][1] && NauceniInt[i][1] >= intervali[j][1])
		{
			j++;
		}
		else if(NauceniInt[i][0] <= intervali[j][0] && NauceniInt[i][1] >= intervali[j][1])
		{
			intervali[j][0] = 0;
			intervali[j][1] = 0;
			j++;
		}		
		else if(NauceniInt[i][0] >= intervali[j][0] && NauceniInt[i][1] <= intervali[j][1])
		{
			if(interval >= VELIKOST) interval = VELIKOST - 1;
			intervali[interval][1] = intervali[j][1];
			intervali[j][1] = NauceniInt[i][0];
			intervali[interval][0] = NauceniInt[i][1];
			if((intervali[j][1]-intervali[j][0]) <= SIRINA*frekvenca)
			{
				intervali[j][0] = 0;
				intervali[j][1] = 0;
			}			
			if((intervali[interval][1]-intervali[interval][0]) <= SIRINA*frekvenca)
			{
				intervali[interval][0] = 0;
				intervali[interval][1] = 0;
			}			
			interval++;
			i++;
		}
	}
	
return 0;	
}


int zdruzevanje_nauceni_nauceni(double* nauceni1, double* nauceni2, int dolzina, int oznaka)
{
	int i, j, tmp, r, zacetek, konec, index;
	r = (int)round(frekvenca*INTERVALzdruzitevNAUC);
	
	
	for(i = 0; i < dolzina; i++)
	{
		if(nauceni1[i] > 0)
		{	
			tmp = i;
			if(i-r < 0) { zacetek = 0; } 
            else { zacetek = i - r; }
			if(i+r >= dolzina-1) { konec =  dolzina - 1; } 
            else { konec =  i + r;}
			for (j = zacetek; j < konec; j++) 
			{
				if(nauceni2[j] > 0)
				{
					index = (tmp + j)/2;
					nauceni1[tmp] = 10;
					nauceni2[j] = 0;
					nauceni2[index] = oznaka;
					break;
				}
			}
		}
	}
	for(i = 0; i < dolzina; i++)
	{
		if(nauceni1[i] == 5) {nauceni2[i] = nauceni1[i];}
	}
return 0;	
}


int zdruzevanje_nauceni_detektirani_nova(double* nauceni, double* detektirani)
{
	int i, l, zacetek, konec;
	
	l = 0;
	while(l < inter)
	{
	    zacetek = NauceniInt[l][0];
	    konec = NauceniInt[l][1];
	    for(i = zacetek; i <= konec; i++)
	    {
	      detektirani[i] = nauceni[i];
	    }
	    l++;
	}
	
return 0;	
}


int zdruzevanje_nauceni_detektirani(double* nauceni, double* detektirani, int dolzina, int oznaka, int nauceniALIdet)
{
	int i, j, tmp, r, zacetek, konec;
	if(nauceniALIdet == 1)
	  r = (int)round(frekvenca*INTERVALzdruzitevDET);
	else
	  r = (int)round(frekvenca*INTERVALzdruzitevNAUC);
	
	
	for(i = 0; i < dolzina; i++)
	{
		if(nauceni[i] > 0)
		{	
			tmp = i;
			if(i-r < 0) { zacetek = 0; } 
            else { zacetek = i - r; }
			if(i+r >= dolzina-1) { konec =  dolzina - 1; } 
            else { konec =  i + r;}
			for (j = zacetek; j < konec; j++) 
			{
				if(detektirani[j] > 0)
				{
					nauceni[tmp] = 10;
					detektirani[j] = 0;
					detektirani[tmp] = oznaka;
				}
			}
		}
	}
	for(i = 0; i < dolzina; i++)
	{
		if(nauceni[i] != 10) {detektirani[i] = detektirani[i] + nauceni[i];}
	}
return 0;	
}


int skupno_pretest(double *ecg, double *bp, int dolzina, int dolzinabp, double *RR_i, double *RR_i_BP)
{
	int i, j, k, l, zacetek, konec, idx;
	double Mrez = -0.35; double Vrez = -0.05;
	double maks = 0;
	double X, Y, Sy, Sx, Sxy;
	int st_ujemanj = 0;
	int v_sumu = 0;
	double tmp_rr = 0.0; int tmp_korak = 0; int stevec = 0; int odmikRR = 0;
	double RR[VELIKOST];
	double odmik[VELIKOST];
int min_razlika;
int meja = 5000;
	
	double odmikINrr_RR[VELIKOST];
	double odmikINrr_odmik[VELIKOST];
	st_odmikRR = 0;	
	
	koef = 1;
	N = 0.2*frekvenca;	


	for(i = 0; i < dolzina; i++)
	{
		if(ecg[i] == 5 || ecg[i] == 1)
		{
			zacetek = (i + round(RR_i[i]*frekvenca*Mrez)-0.14*frekvenca);
			konec = (i + round(RR_i[i]*frekvenca*Vrez)+0.14*frekvenca);
//printf("%d %d %f %f\n", zacetek, konec,zacetek-0.14*frekvenca, konec+0.14*frekvenca);			
			if(zacetek < 0) zacetek = 0;
			if (konec >= dolzinabp) konec = dolzinabp - 1;
			maks = 0;
			for(j = konec; j >= zacetek; j--)
			{

				if(bp[j] > 0)
				{
 maks = 1;
				  break;				 
/*					if(fpritisk[j] > maks)
					{
					 
						maks = fpritisk[j];
						idx = j;
					}					
*/				}
			}

			if(maks != 0)
			{
				st_ujemanj++;
				odmikINrr_RR[st_odmikRR] = RR_i_BP[idx];
				odmikINrr_odmik[st_odmikRR] = (idx-i);
				st_odmikRR++;
				if(st_odmikRR >= VELIKOST) st_odmikRR = VELIKOST - 1;
			}
			
		}
		
		
	}


	for(i = 0; i < st_odmikRR; i++)
	{
		if(odmikINrr_RR[i] != -1) tmp_rr = odmikINrr_RR[i];
		tmp_korak = 0;
		stevec = 0;
		for(j = i; j < st_odmikRR; j++)
		{
			if(tmp_rr == odmikINrr_RR[j])
			{
				tmp_korak = tmp_korak + odmikINrr_odmik[j]; 
				stevec++;
				odmikINrr_RR[j] = -1;
			}	
				
		}
		if(tmp_korak != 0)
		{
			RR[odmikRR] = tmp_rr*frekvenca;
			odmik[odmikRR] = round(tmp_korak/stevec);
			odmikRR++;
			if(odmikRR >= VELIKOST) odmikRR = VELIKOST - 1;
		}
	}
	
	X = aMean(RR, odmikRR);
	Y = aMean(odmik, odmikRR);
	for(i = 0; i < odmikRR;i++)
	{
		Sx = Sx + ((RR[i] - X)*(RR[i] - X));
		Sy = Sy + ((odmik[i] - Y)*(odmik[i] - Y));
		Sxy = Sxy + ((RR[i] - X)*(odmik[i] - Y));
	}

	if((st_ujemanj > 4) && (fabs(Sx) > 0.00001) &&((RR[maksimum(RR, odmikRR, 0)] - RR[minimum(RR, odmikRR, 0)]) > 0.1))
	{
		koef = Sxy/Sx;
		N = Y-koef*X;	
	}
		
	return st_ujemanj;
}




int skupno(double *ecg, double *bp, int dolzina, int dolzinabp, double *RR_i, double *RR_i_BP)
{
	int i, j, k, l, zacetek, konec, idx;
	double Mrez = 0.1; double Vrez = 0.5;
	double maks = 0;
	double X, Y, Sy, Sx, Sxy;
	int st_ujemanj = 0;
	int v_sumu = 0;
	double tmp_rr = 0.0; int tmp_korak = 0; int stevec = 0; int odmikRR = 0;
	double RR[VELIKOST];
	double odmik[VELIKOST];
int min_razlika;
int meja = 5000;
	
	double odmikINrr_RR[VELIKOST];
	double odmikINrr_odmik[VELIKOST];
	st_odmikRR = 0;	
	
	koef = 1;
	N = 0.2*frekvenca;	

	
	for(i = 0; i < dolzina; i++)
	{
		if(ecg[i] == 5 || ecg[i] == 1)
		{
			zacetek = (i - round(RR_i[i]*frekvenca*Mrez)-0.14*frekvenca);
			konec = (i + round(RR_i[i]*frekvenca*Vrez)+0.14*frekvenca);
			if(zacetek < 0) zacetek = 0;
			if (konec >= dolzinabp) konec = dolzinabp - 1;
			maks = 0;
			for(j = zacetek; j <= konec; j++)
			{
				if(bp[j] > 0)
				{
				  maks = 1;
				  break;
/*					if(fpritisk[j] > maks)
					{
						maks = fpritisk[j];
						idx = j;
					}					
*/				}
			}
/*			if(maks == 0)
			{
				for(j = zacetek; j < konec; j++)
				{
					if(bp[j] == 3)
					{
					  maks = 1;
				  break;
*//*						if(fpritisk[j] > maks)
						{
							maks = fpritisk[j];
							idx = j;
						}					
*//*					}
				}
			}
*/			if(maks != 0)
			{
				st_ujemanj++;
				odmikINrr_RR[st_odmikRR] = RR_i_BP[idx];
				odmikINrr_odmik[st_odmikRR] = (idx-i);
				st_odmikRR++;
				if(st_odmikRR >= VELIKOST) st_odmikRR = VELIKOST - 1;
			}
			
		}
/*		else if((ecg[i] == 1))
		{
				zacetek = (i - round(RR_i[i]*frekvenca*Mrez)-0.14*frekvenca);
				konec = (i + round(RR_i[i]*frekvenca*Vrez)+0.14*frekvenca);
				if(zacetek < 0) zacetek = 0;
				if (konec >= dolzinabp) konec = dolzinabp - 1;
				maks = 0;
				for(j = zacetek; j < konec; j++)
				{
					if(bp[j] == 6)
					{
						if(fpritisk[j] > maks)
						{
							maks = fpritisk[j];
							idx = j;
						}					
					}
				}
				if(maks == 0)
				{
					for(j = zacetek; j < konec; j++)
					{
						if(bp[j] == 3)
						{
							if(fpritisk[j] > maks)
							{
								maks = fpritisk[j];
								idx = j;
							}					
						}
					}
				}
				else if(maks != 0)
				{
					st_ujemanj++;
					odmikINrr_RR[st_odmikRR] = RR_i_BP[idx];
					odmikINrr_odmik[st_odmikRR] = (idx-i);
					st_odmikRR++;
					if(st_odmikRR >= VELIKOST) st_odmikRR = VELIKOST - 1;
				}
			
		}
	*/	
	}


	for(i = 0; i < st_odmikRR; i++)
	{
		if(odmikINrr_RR[i] != -1) tmp_rr = odmikINrr_RR[i];
		tmp_korak = 0;
		stevec = 0;
		for(j = i; j < st_odmikRR; j++)
		{
			if(tmp_rr == odmikINrr_RR[j])
			{
				tmp_korak = tmp_korak + odmikINrr_odmik[j]; 
				stevec++;
				odmikINrr_RR[j] = -1;
			}	
				
		}
		if(tmp_korak != 0)
		{
			RR[odmikRR] = tmp_rr*frekvenca;
			odmik[odmikRR] = round(tmp_korak/stevec);
			odmikRR++;
			if(odmikRR >= VELIKOST) odmikRR = VELIKOST - 1;
		}
	}
	
	X = aMean(RR, odmikRR);
	Y = aMean(odmik, odmikRR);
	for(i = 0; i < odmikRR;i++)
	{
		Sx = Sx + ((RR[i] - X)*(RR[i] - X));
		Sy = Sy + ((odmik[i] - Y)*(odmik[i] - Y));
		Sxy = Sxy + ((RR[i] - X)*(odmik[i] - Y));
	}

	if((st_ujemanj > 4) && (fabs(Sx) > 0.00001) &&((RR[maksimum(RR, odmikRR, 0)] - RR[minimum(RR, odmikRR, 0)]) > 0.1))
	{
		koef = Sxy/Sx;
		N = Y-koef*X;	
	}
	
	return st_ujemanj;
}



int preslikava_nova(double *ecg, double *bp, int dolzina, int dolzinabp, double *RR_i_BP, double *RR_i, double *fbp)
{
	int i, j, zacetek, konec, k, start, end, r;
	int min_razlika, idx;
	double okno = 0.14;	
	double rez = 0.2;
	int ujemanje = 0;
	int zamik = 0;
	int meja;
	

			k = 0;
			while(k < interval) 
			{
				for(j = intervali[k][0]; j < intervali[k][1]; j++)
				{
					if((bp[j] == 6 && fbp[j] < 4*srednjiBP && fbp[j] > 0.25*srednjiBP) ||
					  (bp[j] == 3 && fbp[j] < 4*srednjiBP && fbp[j] > 0.25*srednjiBP))
					{
					    zamik = round(koef*RR_i_BP[j]*frekvenca+N);
					    meja = abs(2*zamik);
		
					    zacetek = (j - zamik - round(frekvenca*okno*RR_i_BP[j]));
					    konec = (j - zamik + round(frekvenca*okno*RR_i_BP[j]));
					    if(zacetek < 0) zacetek = 0;
					    if(zacetek >= dolzina) zacetek = dolzina - 1;
					    if(konec >= dolzina) konec = dolzina - 1;
					    if(konec < 0) konec = 0;
					    min_razlika = meja;	
					    
					    for(i = zacetek; i <= konec; i++)
					    {
						if((ecg[i] > 0))
						{
						  r = abs(j-i-zamik);
						  if(r < min_razlika)
						  {
							min_razlika = r;
							idx = i;
						  }
						}						
					    }
					    if(min_razlika != meja)
					    {
					      ecg[idx] = 4;
					    }  
					    if(min_razlika == meja)
					    {
				if(((j - zamik) >= 0) && ((j - zamik) < dolzina))
				{
					ecg[(j - zamik)] = 4;
					start = (j - zamik) - round(rez*RR_i_BP[(j - zamik)]*frekvenca);
					end = (j - zamik) + round(2*rez*RR_i_BP[(j - zamik)]*frekvenca);
					if(start < 0) start = 0;
					if(end < 0) end = 0;
					if(start >= dolzina) start = dolzina - 1;
					if(end >= dolzina) end =  dolzina - 1;					
					
					for(i = start; i < (j - zamik); i++)
					{
						ecg[i] = 0;
					} 
					for(i = ((j - zamik) + 1); i <= end; i++)
					{
						ecg[i] = 0;
					}				
				}						      
					      

					   
					}
					}	
				}
				k++;
			}	
			
	return ujemanje;	
}	

int ali_nova_prej(double *ecg, double *bp, int dolzina, int dolzinabp, int zamik, double *RR_i_BP, double *RR_i, double *fbp)
{
	int i, j, zacetek, konec, k, start, end, r;
	int min_razlika, idx;
	double okno = 0.14;	
	double rez = 0.2;
	int ujemanje = 0;
	int meja = abs(2*zamik);
	

			k = 0;
			while(k < interval) 
			{
				for(j = intervali[k][0]; j < intervali[k][1]; j++)
				{
					if((bp[j] == 6 && fbp[j] < 4*srednjiBP && fbp[j] > 0.25*srednjiBP) ||
					  (bp[j] == 3 && fbp[j] < 4*srednjiBP && fbp[j] > 0.25*srednjiBP))
					{
					    zacetek = (j - zamik - round(frekvenca*okno*RR_i_BP[j]));
					    konec = (j - zamik + round(frekvenca*okno*RR_i_BP[j]));
					    if(zacetek < 0) zacetek = 0;
					    if(zacetek >= dolzina) zacetek = dolzina - 1;
					    if(konec >= dolzina) konec = dolzina - 1;
					    if(konec < 0) konec = 0;
					    min_razlika = meja;	
					    
					    for(i = zacetek; i <= konec; i++)
					    {
						if((ecg[i] > 0))
						{
						  r = abs(j-i-zamik);
						  if(r < min_razlika)
						  {
							min_razlika = r;
							idx = i;
						  }
						}						
					    }
					    if(min_razlika != meja)
					    {
					      ecg[idx] = 4;
					    }  
					    if(min_razlika == meja)
					    {
				if(((j - zamik) >= 0) && ((j - zamik) < dolzina))
				{
					ecg[(j - zamik)] = 4;
					start = (j - zamik) - round(rez*RR_i_BP[(j - zamik)]*frekvenca);
					end = (j - zamik) + round(2*rez*RR_i_BP[(j - zamik)]*frekvenca);
					if(start < 0) start = 0;
					if(end < 0) end = 0;
					if(start >= dolzina) start = dolzina - 1;
					if(end >= dolzina) end =  dolzina - 1;					
					
					for(i = start; i < (j - zamik); i++)
					{
						ecg[i] = 0;
					} 
					for(i = ((j - zamik) + 1); i <= end; i++)
					{
						ecg[i] = 0;
					}				
				}						      
					      

					   
					}
					}	
				}
				k++;
			}	
			
	return ujemanje;	
}	


int ali_nova(double *ecg, double *bp, int dolzina, int dolzinabp, int zamik, double *RR_i_BP, double *RR_i, double *fbp)
{
	int i, j, zacetek, konec, k, start, end, r;
	int min_razlika, idx;
	double okno = 0.14;	
	double rez = 0.2;
	int ujemanje = 0;
	int meja = abs(2*zamik);
	

			k = 0;
			while(k < interval) 
			{	ujemanje = 0;
				for(j = intervali[k][0]; j < intervali[k][1]; j++)
				{	
					if((bp[j] == 6 && fbp[j] < 4*srednjiBP && fbp[j] > 0.25*srednjiBP) ||
					  (bp[j] == 3 && fbp[j] < 4*srednjiBP && fbp[j] > 0.25*srednjiBP))
					{
					    zacetek = (j - zamik - round(frekvenca*okno*RR_i_BP[j]));
					    konec = (j - zamik + round(frekvenca*okno*RR_i_BP[j]));
					    if(zacetek < 0) zacetek = 0;
					    if(zacetek >= dolzina) zacetek = dolzina - 1;
					    if(konec >= dolzina) konec = dolzina - 1;
					    if(konec < 0) konec = 0;
					    min_razlika = meja;	
					    
					    for(i = zacetek; i <= konec; i++)
					    {
						if((ecg[i] > 0))
						{
						  r = abs(j-i-zamik);
						  if(r < min_razlika)
						  {
							min_razlika = r;
							idx = i;
						  }
						}						
					    }
					    if(min_razlika != meja)
					    {
					      ecg[idx] = 4;
					      ujemanje++;
					    }  
					    if(min_razlika == meja)
					    {
					      ujemanje++;
				if(((j - zamik) >= 0) && ((j - zamik) < dolzina))
				{
					ecg[(j - zamik)] = 4;
					start = (j - zamik) - round(rez*RR_i_BP[(j - zamik)]*frekvenca);
					end = (j - zamik) + round(2*rez*RR_i_BP[(j - zamik)]*frekvenca);
					if(start < 0) start = 0;
					if(end < 0) end = 0;
					if(start >= dolzina) start = dolzina - 1;
					if(end >= dolzina) end =  dolzina - 1;					
					
					for(i = start; i < (j - zamik); i++)
					{
						ecg[i] = 0;
					} 
					for(i = ((j - zamik) + 1); i <= end; i++)
					{
						ecg[i] = 0;
					}				
				}						      
					      

					   
					}
					
					}	
				}
//				printf("uj  %d   %f\n", ujemanje, (intervali[k][1]-intervali[k][0])/(((RR_i_BP[intervali[k][1]]+RR_i_BP[intervali[k][0]])/2)*frekvenca));
				if(fabs(1.0-ujemanje/round((intervali[k][1]-intervali[k][0])/(((RR_i_BP[intervali[k][1]]+RR_i_BP[intervali[k][0]])/2)*frekvenca))) < 0.25)
				{
				  for(j = intervali[k][0]; j < intervali[k][1]; j++)
				  {
				    if(ecg[j] == 1) ecg[j] = 0;
 				  }
//				  printf("		here\n");
				}
				k++;
			}	
			
	return ujemanje;	
}






int preslikava(double *ecg, double *bp, int dolzina, int dolzinabp, double *RR_i_BP, double *RR_i, double *fbp)
{
		
	int i, j, zacetek, konec, k, start, end, v_sumu, l, odmik;
	int min_razlika, idx;
	double okno = 0.14;	
	double rez = 0.2;
	double Mrez = 0.15;
	double Vrez = 0.75;
	int ujemanje = 0;
	int zamik = 0;
	int meja;
	

	for(i = 0; i < dolzina; i++)
	{
		if(ecg[i] == 5)
		{
zamik = round(koef*RR_i[i]*frekvenca+N);
meja = abs(2*zamik);
			zacetek = i - round(Mrez*frekvenca*RR_i[i]) + zamik;
			konec = i +  round(Vrez*frekvenca*RR_i[i]) + zamik;	
			if(zacetek < 0) zacetek = 0;
			if(zacetek >= dolzinabp) zacetek = (dolzinabp - 1);
			if(konec < 0) konec = 0;
			if(konec >= dolzinabp) konec = (dolzinabp - 1);
			min_razlika = meja;
			
			for(j = zacetek; j <= konec; j++)
			{
				if(bp[j] == 6)
				{
					if(abs(i-j) < min_razlika)
					{
						min_razlika = abs(i-j);
						idx = j;
					}
				}
			}
			if(min_razlika == meja)
			{
				for(j = zacetek; j <= konec; j++)
				{
					if(bp[j] == 3)
					{
						if(abs(i-j) < min_razlika)
						{
							min_razlika = abs(i-j);
							idx = j;
						}
					}
				}				
			}
			if(min_razlika != meja)
			{
				zacetek = (idx - round(RR_i[i]*frekvenca*rez));
				konec = (idx + round(RR_i[i]*frekvenca*rez*2));
				if(zacetek < 0) zacetek = 0;
				if(zacetek >= dolzinabp) zacetek = (dolzinabp - 1);
				if(konec < 0) konec = 0;
				if(konec >= dolzinabp) konec = (dolzinabp - 1);
				for(j = zacetek; j <= konec; j++)
				{
					bp[j] = 0;
				}
				ujemanje++;
			}				
		}
	}	
	for(i = 0; i < dolzinabp; i++)
	{
		if(bp[j] == 6)  
		{
zamik = round(koef*RR_i_BP[i]*frekvenca+N);
meja = abs(2*zamik);
		  odmik = zamik;
			zacetek = (i - odmik - round(frekvenca*okno*RR_i_BP[i]));
			konec = (i - odmik + round(frekvenca*okno*RR_i_BP[i]));
			if(zacetek < 0) zacetek = 0;
			if(zacetek >= dolzina) zacetek = dolzina - 1;
			if(konec >= dolzina) konec = dolzina - 1;
			if(konec < 0) konec = 0;
			min_razlika = meja;		
			for(j = zacetek; j < konec; j++)
			{
				if(ecg[j] == 5)
				{
					if(abs(i - j) < min_razlika)
					{
						min_razlika = abs(i -j);
						idx = j;
					}		
				}
			}
			if(min_razlika == meja)
			{
				for(j = zacetek; j < konec; j++)
				{
					if(ecg[j] == 1)
					{
						if(abs(i - j) < min_razlika)
						{
							min_razlika = abs(i -j);
							idx = j;
						}		
					}
				}
			}
			if(min_razlika != meja)
			{
				ecg[idx] = 4;
				start = idx - round(rez*RR_i_BP[idx]*frekvenca);
				end = idx + round(2*rez*RR_i_BP[idx]*frekvenca);
				if(start < 0) start = 0;
				if(end < 0) end = 0;
				if(start >= dolzina) start = dolzina - 1;
				if(end >= dolzina) end =  dolzina - 1;
				for(j = start; j < idx; j++)
				{
					ecg[j] = 0;
				} 
				for(j = (idx + 1); j <= end; j++)
				{
					ecg[j] = 0;
				}
				ujemanje++;				
			}
			else if(min_razlika == meja)
			{
				if(((i - odmik) >= 0) && ((i - odmik) < dolzina))
				{
					ecg[(i - odmik)] = 6;
					start = (i - odmik) - round(rez*RR_i_BP[(i - odmik)]*frekvenca);
					end = (i - odmik) + round(2*rez*RR_i_BP[(i - odmik)]*frekvenca);
					if(start < 0) start = 0;
					if(end < 0) end = 0;
					if(start >= dolzina) start = dolzina - 1;
					if(end >= dolzina) end =  dolzina - 1;					
					
					for(j = start; j < (i - odmik); j++)
					{
						ecg[j] = 0;
					} 
					for(j = ((i - odmik) + 1); j <= end; j++)
					{
						ecg[j] = 0;
					}				
				}	
			}
		}	
	}
	for(i = 0; i < dolzina; i++)
	{		
		if(ecg[i] == 1)
		{
			k = 0;
			v_sumu = 0; 
			while(k < interval) 
			{
				for(l = intervali[k][0]; l < intervali[k][1]; l++)
				{
					if(l == i)
					{
						v_sumu = 1;
					}
				}
				k++;
				if(v_sumu == 1) break;
			}	
			if(v_sumu == 0)
			{
			  zamik = round(koef*RR_i[i]*frekvenca+N);
meja = abs(2*zamik);
				
				zacetek = i - round(Mrez*frekvenca*RR_i[i]) + zamik;
				konec = i +  round(Vrez*frekvenca*RR_i[i]) + zamik;			
				if(zacetek < 0) zacetek = 0;
				if(zacetek >= dolzinabp) zacetek = (dolzinabp - 1);
				if(konec < 0) konec = 0;
				if(konec >= dolzinabp) konec = (dolzinabp - 1);
				min_razlika = meja;
				
				for(j = zacetek; j <= konec; j++)
				{
					if(bp[j] == 6)  
					{
						if(abs(i-j) < min_razlika)
						{
							min_razlika = abs(i-j);
							idx = j;
						}
					}						
				}
				if(min_razlika == meja)
				{
					for(j = zacetek; j <= konec; j++)
					{
						if(bp[j] == 3)  
						{
							if(abs(i-j) < min_razlika)
							{
								min_razlika = abs(i-j);
								idx = j;
							}
						}
					}				
				}
				if(min_razlika != meja)
				{
					ecg[i] = 4;
					zacetek = (idx - round(RR_i[i]*frekvenca*rez));
					konec = (idx + round(2*RR_i[i]*frekvenca*rez));
					if(zacetek < 0) zacetek = 0;
					if(zacetek >= dolzinabp) zacetek = (dolzinabp - 1);
					if(konec < 0) konec = 0;
					if(konec >= dolzinabp) konec = (dolzinabp - 1);
					for(j = zacetek; j <= konec; j++)
					{
						bp[j] = 0;
					}
					ujemanje++;
				}
				if(min_razlika == meja)
				{
					ecg[i] = 4;
				}										
			}	
		}
	}	
	for(i = 0; i < dolzinabp; i++)
	{
		if(bp[i] == 3)
		{
		  zamik = round(koef*RR_i_BP[i]*frekvenca+N);
meja = abs(2*zamik);
			odmik = zamik;
			zacetek = (i - odmik - round(frekvenca*okno*RR_i_BP[i]));
			konec = (i - odmik + round(frekvenca*okno*RR_i_BP[i]));
			if(zacetek < 0) zacetek = 0;
			if(zacetek >= dolzina) zacetek = dolzina - 1;
			if(konec >= dolzina) konec = dolzina - 1;
			if(konec < 0) konec = 0;
			min_razlika = meja;
			
			for(j = zacetek; j < konec; j++)
			{
				if(ecg[j] == 5)
				{
					if(abs(i - j) < min_razlika)
					{
						min_razlika = abs(i -j);
						idx = j;
					}		
				}
			}
			if(min_razlika == meja)
			{
				for(j = zacetek; j < konec; j++)
				{
					if(ecg[j] == 1)
					{
						if(abs(i - j) < min_razlika)
						{
							min_razlika = abs(i -j);
							idx = j;
						}		
					}
				}
			}			
			if(min_razlika != meja)
			{
				ecg[idx] = 4;
				start = idx - round(rez*RR_i_BP[idx]*frekvenca);
				end = idx + round(2*rez*RR_i_BP[idx]*frekvenca);
				if(start < 0) start = 0;
				if(end < 0) end = 0;
				if(start >= dolzina) start = dolzina - 1;
				if(end >= dolzina) end =  dolzina - 1;
				for(j = start; j < idx; j++)
				{
					ecg[j] = 0;
				} 
				for(j = (idx + 1); j <= end; j++)
				{
					ecg[j] = 0;
				}
				ujemanje++;				
			}
			else if(min_razlika == meja)
			{
				if((i - odmik) >= 0)
				{
					ecg[(i - odmik)] = 3;
				}	
			}
		}	
	}	
	
	
	
	return ujemanje;	
}




void pregled_suma(double *utripi, double *RR_i, int dolzina)
{
	int i, j, utrip1, utrip2, prvi, drugi;
	
	i = 0; 
	while(i < interval) 
	{

		if(intervali[i][0] != intervali[i][1])
		{		
			prvi = intervali[i][0];
			if(prvi != 0)
			{	
				while(prvi >= 0)
				{
					if(utripi[prvi] > 0) break;
					else prvi--;
				}
		
			}	
			drugi = intervali[i][1];
			if(drugi != dolzina -1)
			{	
				while(drugi < (dolzina-1))
				{
					if(utripi[drugi] > 0) break;
					else drugi++;
				}
		
			}	
			utrip1 = prvi;
			utrip2 = drugi;

			for(j = (utrip1+1); j < utrip2; j++)
			{
				if(utripi[j] == 2) utripi[j] = 0;
			}	
		}			
		i++;
	}		
}

void pregled_suma_ekg(double *utripi, double *RR_i, int dolzina)
{
	int i, j, k, l, utrip1, utrip2, prvi, drugi, tmp_zunanji, utrip;
	int zacetek, konec, center, idx;
	int min_razlika;
	int nazaj = 0;
	double mean_rr_noise;
	double Mrez = 0.382;
	
	i = 0; 
	while(i < interval) 
	{
		if(intervali[i][0] != intervali[i][1])
		{		
			prvi = intervali[i][0];
			if(prvi != 0)
			{	
				while(prvi >= 0)
				{
					if(utripi[prvi] > 0) break;
					else prvi--;
				}	
			}	
			drugi = intervali[i][1];
			if(drugi != dolzina -1)
			{	
				while(drugi < dolzina)
				{
					if(utripi[drugi] > 0) break;
					else drugi++;
				}
		
			}	
			utrip1 = prvi;
			utrip2 = drugi;

			nazaj = 0;
			if(utrip1 == 0)
			{
				mean_rr_noise = RR_i[utrip2];
				nazaj = 1;
			}
			else if(utrip2 == (dolzina - 1)) 
			{
				mean_rr_noise = RR_i[utrip1];
			}
			else
			{
				mean_rr_noise = (RR_i[utrip1] + RR_i[utrip2])/2;
			}
		
			if(((round((utrip2-utrip1)/(mean_rr_noise*frekvenca)) - (utrip2-utrip1)/(mean_rr_noise*frekvenca)) >= 0) && 
			((round((utrip2-utrip1)/(mean_rr_noise*frekvenca)) - (utrip2-utrip1)/(mean_rr_noise*frekvenca)) <= 0.2))
			{tmp_zunanji = round((utrip2-utrip1)/(mean_rr_noise*frekvenca));}
			else {tmp_zunanji = floor((utrip2-utrip1)/(mean_rr_noise*frekvenca));}
				

			if((nazaj == 1) && (tmp_zunanji > 1))
			{
				utrip = utrip2;
				for(l = 1; l < tmp_zunanji; l++)
				{
					zacetek = utrip - round(mean_rr_noise*frekvenca) - round(Mrez*mean_rr_noise*frekvenca);
					konec = utrip - round(mean_rr_noise*frekvenca) + round(Mrez*mean_rr_noise*frekvenca);
					center = utrip - round(mean_rr_noise*frekvenca);
					//zacetek = utrip - round(mean_rr_noise*frekvenca*l) - round(Mrez*mean_rr_noise*frekvenca);
					//konec = utrip - round(mean_rr_noise*frekvenca*l) + round(Mrez*mean_rr_noise*frekvenca);
					//center = utrip - round(mean_rr_noise*frekvenca*l);
					if(zacetek < 0) zacetek = 0;
					if(center < 0) center = 0;
					if(konec >= dolzina) konec = dolzina;
					if(konec < 0) konec = 0;
					min_razlika = konec + 1;
					for(k = zacetek; k < konec; k++)
					{		
						if(utripi[k] == 1)
						{
							if(abs(center - k) < min_razlika)
							{
								min_razlika = abs(center - k);
								idx = k;
							}		
						}			
						utripi[k] = 0;
					}
					if(min_razlika != (konec + 1))
					{
						utripi[idx] = 2;
						utrip = idx;
					}
					else if(min_razlika == (konec + 1))
					{
						utripi[center] = 2;
						utrip = center;
					}						
				}						
				for(j = (utrip1 + 1); j < utrip2; j++)
				{
					if((utripi[j] != 3) && (utripi[j] != 5) && (utripi[j] != 2) && (utripi[j] != 4) && (utripi[j] != 6)) utripi[j] = 0;
				}
			}	
			else if((nazaj == 0) && (tmp_zunanji > 1))
			{
				utrip = utrip1;
				for(l = 1; l < tmp_zunanji; l++)
				{
					zacetek = utrip + round(mean_rr_noise*frekvenca) - round(Mrez*mean_rr_noise*frekvenca);
					konec = utrip + round(mean_rr_noise*frekvenca) + round(Mrez*mean_rr_noise*frekvenca);
					center = utrip + round(mean_rr_noise*frekvenca);
					if(zacetek < 0) zacetek = 0;
					if(zacetek >= dolzina) zacetek = dolzina - 1;
					if(center < 0) center = 0;
					if(center >= dolzina) center = dolzina - 1;
					if(konec >= dolzina) konec = dolzina - 1;
					min_razlika = konec + 1;
							
					for(k = zacetek; k < konec; k++)
					{
						if(utripi[k] == 1)
						{
							if(abs(center - k) < min_razlika)
							{
								min_razlika = abs(center - k);
								idx = k;
							}		
						}			
						utripi[k] = 0;
					}
					if(min_razlika != (konec + 1))
					{
						utripi[idx] = 2;
						utrip = idx;
					}
					else if(min_razlika == (konec + 1))
					{
						utripi[center] = 2;
						utrip = center;
					}				
				}	
				for(j = (utrip1 + 1); j < utrip2; j++)
				{
					if((utripi[j] != 3) && (utripi[j] != 5) && (utripi[j] != 2) && (utripi[j] != 4) && (utripi[j] != 6)) utripi[j] = 0;
				}
			}
		
			else if(((nazaj == 1) && (tmp_zunanji == 1)) || ((nazaj == 0) && (tmp_zunanji == 1)))
			{
				for(j = (utrip1 + 1); j < utrip2; j++)
				{
					if((utripi[j] != 3) && (utripi[j] != 5) && (utripi[j] != 2) && (utripi[j] != 4) && (utripi[j] != 6)) utripi[j] = 0;
				}		
			}
		}			
		i++;
	}
}

int ujemanja(double *ecg, double *bp, int dolzina, int dolzinabp, int zamik)
{
	int i, j, zacetek, konec, k, l;
	int u = 0; int v_sumu = 0;
	double okno = 0.14;
	
	
	for(i = 0; i < dolzina; i++)
	{
		if(ecg[i] == 5)
		{
			zacetek = i - round(okno*frekvenca) + zamik;
			konec = i +  round(okno*frekvenca) + zamik;
			if(zacetek < 0) zacetek = 0;
			if(zacetek >= dolzinabp) zacetek = (dolzinabp - 1);
			if(konec < 0) konec = 0;
			if(konec >= dolzinabp) konec = (dolzinabp - 1);
			for(j = zacetek; j <= konec; j++)
			{
				if(bp[j] > 0) {u++; break;}
			}
		}
		
		else if((ecg[i] == 1))
		{
	/*		k = 0;
			v_sumu = 0; 
			while(k < interval) 
			{
				for(l = intervali[k][0]; l < intervali[k][1]; l++)
				{
					if(l == i)
					{
						v_sumu = 1;
					}
				}
				k++;
				if(v_sumu == 1) break;
			}	
			if(v_sumu == 0)
			{
	*/			zacetek = i - round(okno*frekvenca) + zamik;
				konec = i +  round(okno*frekvenca) + zamik;
				
				if(zacetek < 0) zacetek = 0;
				if(zacetek >= dolzinabp) zacetek = (dolzinabp - 1);
				if(konec < 0) konec = 0;
				if(konec >= dolzinabp) konec = (dolzinabp - 1);
				for(j = zacetek; j <= konec; j++)
				{
					if(bp[j] > 0) {u++; break;}
				}
			}	
	//	}
	}
	
	return u;
}


void dolocitev_utripov_EKG(double * ecg)
{
  int k,l; 
  	k = 0;
	while(k < interval) 
	{
	  for(l = intervali[k][0]; l < intervali[k][1]; l++)
	  {
	    if(ecg[l] == 1)
	    {
	      ecg[l] = 2;
	    }
	  }
	  k++;
	}  
}
			
	


int korelacija_pretest(double *ecg_n, double *bp_n, double *ecg, double *bp, int dolzina, int dolzinabp)
{
	int u, i, st_e, st_b, maks, st, idx_maks, nov_maks;
	double rr;
	double zamik[VELIKOST];
	double st_parov[VELIKOST];
	int zam = 0;
	double Mrez = -0.35; double Vrez = -0.05;	
	Korak = 0;
	int index = 0;
	
	st_e = 0;
	for(i = 0; i < dolzina; i++)
	{
		if(ecg_n[i] > 0) st_e++; 
	}
	
	st_b = 0;
	for(i = 0; i < dolzinabp; i++)
	{
		if(bp_n[i] > 0) st_b++; 
	}
	
	if(st_e >= st_b) rr = rr_naucen_EKG;
	else rr = rr_naucen_BP;

		
	for(i = round(Vrez*rr*frekvenca); i >= round(Mrez*rr*frekvenca); i--)
	{
		u = ujemanja(ecg, bp, dolzina, dolzinabp, i);
		zamik[zam] = i;
		st_parov[zam] = u;

		zam++;

		if(zam >= VELIKOST) zam = VELIKOST - 1;
	}

	maks = 0;
	st = 0;
	idx_maks = 0;
	for(i = 0; i < zam; i++)
	{
		if(st_parov[i] > maks)
		{
			maks = st_parov[i];
			idx_maks = i;
			nov_maks = 1;
		}
		else if(st_parov[i] == maks && maks != 0)
		{
			if(nov_maks == 1) {st = 1; nov_maks = 0;}
			else st++;
		}
		
	}
	index = idx_maks + floor(st/2);
	if(index >= zam && zam > 0) Korak = zamik[zam-1];
	else if ((zam == 0) || (index < 0)) Korak = 0;
	else Korak = zamik[index]; 

	
	return st_parov[idx_maks];	 
}





int korelacija(double *ecg_n, double *bp_n, double *ecg, double *bp, int dolzina, int dolzinabp)
{
	int u, i, st_e, st_b, maks, st, idx_maks, nov_maks;
	double rr;
	double zamik[VELIKOST];
	double st_parov[VELIKOST];
	int zam = 0;
	double Mrez = 0.1; double Vrez = 0.5;
	int index = 0;
	Korak = 0;
	idx_maks = 0;

	st_e = 0;
	for(i = 0; i < dolzina; i++)
	{
		if(ecg_n[i] > 0) st_e++; 
	}
	
	st_b = 0;
	for(i = 0; i < dolzinabp; i++)
	{
		if(bp_n[i] > 0) st_b++; 
	}
	
	if(st_e >= st_b) rr = rr_naucen_EKG;
	else rr = rr_naucen_BP;
	
	for(i = round(Mrez*rr*frekvenca); i <= round(Vrez*rr*frekvenca); i++)
	{
		u = ujemanja(ecg, bp, dolzina, dolzinabp, i);
		zamik[zam] = i;
		st_parov[zam] = u;
		zam++;
		if(zam >= VELIKOST) zam = VELIKOST - 1;
	}

	maks = 0;
	st = 0;
	for(i = 0; i < zam; i++)
	{
		if(st_parov[i] > maks)
		{
			maks = st_parov[i];
			idx_maks = i;
			nov_maks = 1;
					}
		else if(st_parov[i] == maks)
		{
			if(nov_maks == 1) {st = 1; nov_maks = 0;}
			else st++;
		}
		
	}	
	index = idx_maks + floor(st/2);
	if(index >= zam && zam > 0) Korak = zamik[zam-1];
	else if ((zam == 0) || (index < 0)) Korak = 0;
	else Korak = zamik[index]; 

	if(Korak > 0.27*frekvenca) Korak = DEFAULT*frekvenca;
	
	return st_parov[idx_maks];	 
}



long ReadBuffer(long annot)
{
	long i,j;
	st_ekg = 0;
	st_bp = 0;
//	int ekg_index[3] = {-1,-1,-1}; /
//	int bp_indexi[3] = {-1,-1,-1}; 
	WFDB_Sample vec[MAX_LEADS];
     
	for(j = 0; j < openLeads; j++)
	{  
		if((   strstr(s[j].desc,"ECG") != NULL) || (strstr(s[j].desc,"ecg") != NULL)
		   || (strstr(s[j].desc,"V1") != NULL) || (strstr(s[j].desc,"V2") != NULL)
		    || (strstr(s[j].desc,"V3") != NULL) || (strstr(s[j].desc,"V4") != NULL)
		  || (strstr(s[j].desc,"V5") != NULL) || (strstr(s[j].desc,"V6") != NULL)
		  || (strstr(s[j].desc,"MLII") != NULL) || (strstr(s[j].desc,"MLIII") != NULL)
		  || (strstr(s[j].desc,"MLV2") != NULL) || (strstr(s[j].desc,"ML2") != NULL)
		  || (strstr(s[j].desc,"aVF") != NULL) || (strstr(s[j].desc,"II") != NULL)
		  
/*		  || (strstr(s[j].desc,"I") != NULL) || (strstr(s[j].desc,"III") != NULL)
		  || (strstr(s[j].desc,"aVR") != NULL) || (strstr(s[j].desc,"aVL") != NULL)
		  || (strstr(s[j].desc,"AVR") != NULL) || (strstr(s[j].desc,"AVL") != NULL)		  
		  || (strstr(s[j].desc,"AVF") != NULL)
*/		  
//		  || (strstr(s[j].desc,"E-S") != NULL) || (strstr(s[j].desc,"A-S") != NULL)
//		  || (strstr(s[j].desc,"A-I") != NULL) || (strstr(s[j].desc,"ML2") != NULL)
//		  || (strstr(s[j].desc,"MV2") != NULL) || (strstr(s[j].desc,"VII") != NULL)
//		  || (strstr(s[j].desc,"II") != NULL) || (strstr(s[j].desc,"aVF") != NULL)
//		  || (strstr(s[j].desc,"0") != NULL) || (strstr(s[j].desc,"1") != NULL)  
		)
		{
			if(st_ekg < 3)
			{
				ekg_index[st_ekg] = j;
				st_ekg++;
			}      
		}
	}
if(st_ekg > 0)
{ 	
    for(j = 1; j < openLeads; j++)
    {  
		if((strstr(s[j].desc,"BP") != NULL) || (strstr(s[j].desc,"bp") != NULL))
		{
			if(st_bp < 3)
			{
				bp_indexi[st_bp] = j;
				st_bp++;
			}	      
		}
     }
     for(j = 1; j < openLeads; j++)
     {  

       if(//(strstr(s[j].desc,"ABP")   != NULL) || (strstr(s[j].desc,"abp")   != NULL) ||
		  (strstr(s[j].desc,"ART")   != NULL) || (strstr(s[j].desc,"art")   != NULL) ||
		  (strstr(s[j].desc,"PAP")   != NULL) || (strstr(s[j].desc,"pap")   != NULL) 
		||  (strstr(s[j].desc,"Pressure") != NULL) //
//          (strstr(s[j].desc,"PLETH") != NULL) || (strstr(s[j].desc,"pleth") != NULL) ||
//          (strstr(s[j].desc,"PPG")   != NULL) || (strstr(s[j].desc,"ppg")   != NULL) ||
      //    (strstr(s[j].desc,"CVP")   != NULL) || (strstr(s[j].desc,"cvp")   != NULL) || 
     //     (strstr(s[j].desc,"SV")   != NULL) || (strstr(s[j].desc,"sv")   != NULL) 
      //    (strstr(s[j].desc,"ICP")   != NULL) || (strstr(s[j].desc,"icp")   != NULL) 
          )
		{
			if(st_bp < 3)
			{
				bp_indexi[st_bp] = j;
				if(strstr(s[j].desc,"Pressure") != NULL) bp_indexi_imena[st_bp] = 1;
				st_bp++;
			}	      
		}
     }
}
if(st_ekg == 0)
{  
   for(j = 1; j < openLeads; j++)
    {  
		if((strstr(s[j].desc,"BP") != NULL) || (strstr(s[j].desc,"bp") != NULL))
		{
			if(st_bp < 3)
			{
				bp_indexi[st_bp] = j;
				st_bp++;
			}	      
		}
     }
     for(j = 1; j < openLeads; j++)
     {  

       if(//(strstr(s[j].desc,"ABP")   != NULL) || (strstr(s[j].desc,"abp")   != NULL) ||
		  (strstr(s[j].desc,"ART")   != NULL) || (strstr(s[j].desc,"art")   != NULL) ||
		  (strstr(s[j].desc,"PAP")   != NULL) || (strstr(s[j].desc,"pap")   != NULL) ||
          (strstr(s[j].desc,"Pressure") != NULL) //|| (strstr(s[j].desc,"pleth") != NULL) ||
//          (strstr(s[j].desc,"PPG")   != NULL) || (strstr(s[j].desc,"ppg")   != NULL) ||
      //    (strstr(s[j].desc,"CVP")   != NULL) || (strstr(s[j].desc,"cvp")   != NULL) || 
     //     (strstr(s[j].desc,"SV")   != NULL) || (strstr(s[j].desc,"sv")   != NULL) 
      //    (strstr(s[j].desc,"ICP")   != NULL) || (strstr(s[j].desc,"icp")   != NULL) 
          )
		{
			if(st_bp < 3)
			{
				bp_indexi[st_bp] = j;
				st_bp++;
			}	      
		}
     }     
     
}	

i = 0;
// 	for(i = 0; i < nrSamps; i++)
while(1)
    {

		if(getvec(vec) <= 0) break;

		if(st_ekg >= 1){ ekg0[i] = vec[ekg_index[0]];}
		if(st_ekg >= 2){ ekg1[i] = vec[ekg_index[1]];}
		if(st_ekg >= 3){ ekg2[i] = vec[ekg_index[2]];}
	
		if(st_bp >= 1){ bp0[i] = vec[bp_indexi[0]];}
		if(st_bp >= 2){ bp1[i] = vec[bp_indexi[1]];}  
		if(st_bp >= 3){ bp2[i] = vec[bp_indexi[2]];} 
		i++;
	}

		return(i);
//		return(nrSamps);
}



int export(double* array, int length, char* name)
{
	FILE *fr;
	int i;

	fr = fopen (name, "w");		
	
	for(i=0; i<length; i++)
	//for(i=300000; i<length; i++)
	{
		fprintf(fr, "%lf\n", array[i]);
	}
	fclose(fr);

	return i;
}


int export2(double* orig , double* orig_p, double* fja_suma, int length, char* name)
{
	FILE *fr;
	int i;

	fr = fopen (name, "w");		
	
	for(i=0; i<length; i++)
	{
		fprintf(fr, "%lf\t%lf\t%lf\n", orig[i],orig_p[i],fja_suma[i]);
	}
	fclose(fr);

	return i;
}







///*********************+
///MAIN
int main(int argc, char *argv[])
{
	long i, j, dolzina, dolzinabp, d;
	char *record = NULL;
	char *annotator = NULL;
	int st_max, k_suma;
	int stopIdx = 0;
	int startIdx = 0;
	int nauceni = 0; 
	int indexEKG = 0;
	int e = 0; int b = 0;
	int kon = 0;
	int ni_naucil = 0;
	int ni_naucil0 = 0; int ni_naucil1 = 0;	int ni_naucil2 = 0;
	int pr_st0 = 0; int pr_st1 = 0; int pr_st2 = 0;
  	int i0 = 0; int i1 = 0; int i2 = 0;
	int nic = 0;
	int ujemanj = 0; int ujemanj2 = 0;
	double idx_ujemanja2 = 0.0;
	int detEKG0 = 1; int detEKG1 = 1; int detEKG2 = 1;
	int detektiraniEKG = 0;
	double idx_ujemanja2_0; double idx_ujemanja2_1; double idx_ujemanja2_2;
	int kolicina_suma0 = nrSamps;
	int kolicina_suma1 = nrSamps;
	int kolicina_suma2 = nrSamps;
	int N0 = 0;
	int N1 = 0;
	int N2 = 0;

	
int premik = round(DEFAULT*frekvenca);	
int k = 0;
int v_sumu = 0;
int imam_pm = 0;
int moj_index = 0;

int N_BP0 = 1;
int N_BP1 = 1;
int N_BP2 = 1;
int K_BP0 = 0;
int K_BP1 = 0;
int K_BP2 = 0;

double sum_std = 0;    
double average = 0;
double sum1_std = 0;    
double variance = 0;
double std_deviation = 0;

int st_pricakovanih_BP;

double odstotek_BP; 

double odstotek_BP0 = 2.0;
double odstotek_BP1 = 2.0;
double odstotek_BP2 = 2.0;
  

double rr_naucen_BP0 = 0.0;
double rr_naucen_BP1 = 0.0;
double rr_naucen_BP2 = 0.0;



double srednjiBP0 = 0.0;
double srednjiBP1 = 0.0;
double srednjiBP2 = 0.0;
dolzina = 0;
dolzinabp = 0;


int premik0 = 0;
int premik1 = 0;
int premik2 = 0;
long st_vzr = 1500000;

int kk = 0;
int ll = 0;

int bp_ni_OK = 0;
int bp_ni_OK0 = 0;
int bp_ni_OK1 = 0;
int bp_ni_OK2 = 0;

double RR0 = 0.1;
double RR1 = 0.1;
double RR2 = 0.1;
int Nauceni_EKG = 0;
int IMAM_PM0 = 0;
int IMAM_PM1 = 0;
int IMAM_PM2 = 0;

double koef0 = 0; 
double NNN0 = 0;
double koef1 = 0; 
double NNN1 = 0;
double koef2 = 0; 
double NNN2 = 0;
int zamik = 0;

	for(i = 1; i < argc; i++)
	{
		if(argv[i][0] != '-')
		{
			fprintf(stderr,"Error parsing command line\n");
			exit(1);
		}
		switch(argv[i][1])
		{
			case 'r':
				i++;
				record = (char *)malloc(sizeof(char)*(strlen(argv[i])+2));
				strcpy(record,argv[i]);
				break;
			case 'a': 
				i++;
				annotator = (char *) malloc(sizeof(char)*(strlen(argv[i])+2));
				strcpy(annotator, argv[i]);
				break;
			case 'n': 
				i++;
				normCnst = atof(argv[i]);
				break;
			case 'k': 
				i++;
				Korelacija = 0;
//				printf("fja\n");
				break;
			default:
				fprintf(stderr,"Wrong switch\n");
				exit(2);
		}
	}
	if(record == NULL)
	{
		fprintf(stderr,"No record was specified, exiting\n");
		exit(2);
	}
	if((openLeads = openRecord(record)) < 0)
	{
		fprintf(stderr,"Error opening record, exiting\n");
		exit(3);
	}

	frekvenca = (int)sampfreq(record);
//	nrSamps = s->nsamp;	


	
	
	ekg0 = (double *)malloc(sizeof(double ) * st_vzr);
	ekg1 = (double *)malloc(sizeof(double ) * st_vzr);
	ekg2 = (double *)malloc(sizeof(double ) * st_vzr);
	bp0 = (double *)malloc(sizeof(double ) * st_vzr);
	bp1 = (double *)malloc(sizeof(double ) * st_vzr);
	bp2 = (double *)malloc(sizeof(double ) * st_vzr);	
	

//		if((samples = ReadBuffer(0)) <= 0)
		if((nrSamps = ReadBuffer(0)) <= 0)
      {
		fprintf(stderr,"Error reading data, exiting\n");
		exit (3);
	}
//	if(samples != nrSamps) fprintf(stderr,"Sample count differs\n");



	if(nrSamps > st_vzr)
	  nrSamps = st_vzr;

	samples = nrSamps;
	

	ekgh1 = (double *)malloc(sizeof(double ) * nrSamps);
	ekgh2 = (double *)malloc(sizeof(double ) * nrSamps);
	z = (double *)malloc(sizeof(double ) * nrSamps);
	det_fja_ekg = (double *)malloc(sizeof(double ) * nrSamps);
	utripi_ekg = (double *)malloc(sizeof(double ) * nrSamps);
	utripi_ekg_bp = (double *)malloc(sizeof(double ) * nrSamps);
	utripi = (double *)malloc(sizeof(double ) * nrSamps);
	fpritisk = (double *)malloc(sizeof(double ) * nrSamps);  
	utripi_bp = (double *)malloc(sizeof(double ) * nrSamps);
	sum1 = (double *)malloc(sizeof(double ) * nrSamps);
sum1_bp = (double *)malloc(sizeof(double ) * nrSamps);
fja_suma_bp = (double *)malloc(sizeof(double ) * nrSamps);

	sum2 = (double *)malloc(sizeof(double ) * nrSamps);  
	fja_suma = (double *)malloc(sizeof(double ) * nrSamps);
	tmp = (double *)malloc(sizeof(double ) * nrSamps);
	tmp_ekg = (double *)malloc(sizeof(double ) * nrSamps);
	tmp_bp = (double *)malloc(sizeof(double ) * nrSamps);
//	ekg0 = (double *)malloc(sizeof(double ) * nrSamps);
//	ekg1 = (double *)malloc(sizeof(double ) * nrSamps);
//	ekg2 = (double *)malloc(sizeof(double ) * nrSamps);
//	bp0 = (double *)malloc(sizeof(double ) * nrSamps);
//	bp1 = (double *)malloc(sizeof(double ) * nrSamps);
//	bp2 = (double *)malloc(sizeof(double ) * nrSamps);
	detekcijski_prag = (double *)malloc(sizeof(double ) * nrSamps);
	detekcijski_pragBP = (double *)malloc(sizeof(double ) * nrSamps);
	tmp_pritisk = (double *)malloc(sizeof(double ) * nrSamps);
	zaINT = (double *)malloc(sizeof(double ) * nrSamps);
	utripi_ekg_nauceni = (double *)malloc(sizeof(double ) * nrSamps);
	utripi_bp_nauceni = (double *)malloc(sizeof(double ) * nrSamps);
	RR_interpoliran = (double *)malloc(sizeof(double ) * nrSamps);
	RR_interpoliran_BP = (double *)malloc(sizeof(double ) * nrSamps);
	nauceniVSI = (double *)malloc(sizeof(double ) * nrSamps);
	zaINTnaucene = (double *)malloc(sizeof(double ) * nrSamps);
	RR_i_vsi = (double *)malloc(sizeof(double ) * nrSamps);
	utripi_ekg0 = (double *)malloc(sizeof(double ) * nrSamps);
	utripi_ekg1 = (double *)malloc(sizeof(double ) * nrSamps);
	utripi_ekg2 = (double *)malloc(sizeof(double ) * nrSamps);
	utripi_skupni = (double *)malloc(sizeof(double ) * nrSamps);
	utripi0 = (double *)malloc(sizeof(double ) * nrSamps);
	utripi1 = (double *)malloc(sizeof(double ) * nrSamps);
	utripi2 = (double *)malloc(sizeof(double ) * nrSamps);
	prag_ucenje = (double *)malloc(sizeof(double ) * nrSamps);
	prag_ucenje_BP = (double *)malloc(sizeof(double ) * nrSamps);
	d_prag0 = (double *)malloc(sizeof(double ) * nrSamps);
	d_prag1 = (double *)malloc(sizeof(double ) * nrSamps);
	d_prag2 = (double *)malloc(sizeof(double ) * nrSamps);
	d_fja0 = (double *)malloc(sizeof(double ) * nrSamps);
	d_fja1 = (double *)malloc(sizeof(double ) * nrSamps);
	d_fja2 = (double *)malloc(sizeof(double ) * nrSamps);
	
MedianaEkg = (double *)malloc(sizeof(double ) * nrSamps);
amplitudeBP = (double *)malloc(sizeof(double ) * nrSamps);


utripi_bp0 = (double *)malloc(sizeof(double ) * nrSamps);
utripi_bp1 = (double *)malloc(sizeof(double ) * nrSamps);
utripi_bp2 = (double *)malloc(sizeof(double ) * nrSamps);


RR_interpoliran_BP0 = (double *)malloc(sizeof(double ) * nrSamps);
RR_interpoliran_BP1 = (double *)malloc(sizeof(double ) * nrSamps);
RR_interpoliran_BP2 = (double *)malloc(sizeof(double ) * nrSamps);
fpritisk0 = (double *)malloc(sizeof(double ) * nrSamps); 
fpritisk1 = (double *)malloc(sizeof(double ) * nrSamps); 
fpritisk2 = (double *)malloc(sizeof(double ) * nrSamps); 



ekg_brisi = (double *)malloc(sizeof(double ) * nrSamps);



	for(i = 0; i < nrSamps; i++) 
	{ utripi[i] = 0;  utripi_ekg[i] = 0; utripi_bp[i] = 0;}


	

///***************
///***************
///***************
	izracunaj_filter(frekvenca);
	st_max = round(nrSamps/(DOLZINAintervala*frekvenca));

//st_bp = 0;
//printf("e  %d b  %d \n", st_ekg, st_bp);

 	if(st_ekg == 1)
	{
		ekg = ekg0;
		ekg_G = ekg0_G;
		d = naredi_fjo_suma();
		dolzina = naredi_ECG_det_fjo();
		nic = ekgUcenje(det_fja_ekg, dolzina, st_max, utripi_ekg_nauceni, fja_suma, detekcijski_prag);
/*
export(prag_ucenje,dolzina,"aa_pu.txt");		
export(detekcijski_prag,dolzina,"aa_p.txt");
export(ekg,dolzina,"aa_or.txt");
export(det_fja_ekg,dolzina,"aa_d.txt");
*/
		for(j = 0; j < dolzina; j++)
		{
			if((RR_i_vsi[j] == 0) && (RR_interpoliran[j] != 0)) RR_i_vsi[j] = RR_interpoliran[j]; 
			utripi_ekg[j] = utripi_ekg_nauceni[j];
		}
		startIdx = 0;
		stopIdx = 0;
		while(startIdx <= (dolzina-1))
		{
			while(RR_interpoliran[startIdx] == 0)
			{
				if(startIdx < dolzina) startIdx++;
				else
				{	 
					kon = 1;
					break;
				}		
			} 
			if(kon == 1) break;
			
			stopIdx = startIdx + 1;
			while(RR_interpoliran[stopIdx] != 0)
			{
				if(stopIdx < dolzina) stopIdx++;
				else break;
			} 

			NauceniInt[inter][0] = startIdx;
			NauceniInt[inter][1] = stopIdx;
			inter++;		
			if(inter >= VELIKOST) inter = VELIKOST - 1;
			startIdx = stopIdx++;
			if(startIdx >= (dolzina-1)) break;
		}

		interpolacijaRR(dolzina, RR_i_vsi, nic);
			
		
		detektiraj_utripe_ekg(det_fja_ekg, detekcijski_prag, utripi_ekg, rr_naucen_EKG, dolzina);
		k_suma = intervali_suma(sum1, detekcijski_prag, d);

//export(det_fja_ekg,300000,"aa_d.txt");		
//export(detekcijski_prag,300000,"aa_p.txt");

		if(interval > 0 && inter > 0) nastavitev_intervali_suma(interval, inter);
		dolocitev_utripov_EKG(utripi_ekg);

		
		detEKG = 0;
		for(j = 0;j < dolzina; j++)
		{
		  if(utripi_ekg[j] > 0) detEKG++;
		}
		detektiraniEKG = detEKG;

nauceni = 0;		
for(j = 0;j < dolzina; j++)
{
  if(utripi_ekg_nauceni[j] > 0) nauceni++;
}
Nauceni_EKG = nauceni;
nauceni = 0;		

	}
		
	if(st_ekg > 1)
	{
		for(e = 0; e < st_ekg; e++)
		{
			switch(e)
			{
				case 0: ekg = ekg0; ekg_G = ekg0_G; break;
				case 1: ekg = ekg1; ekg_G = ekg1_G; break;
				case 2: ekg = ekg2; ekg_G = ekg2_G; break;
			}
			for(j = 0; j < nrSamps; j++)
			{
				utripi_ekg[j] = 0;
				utripi_ekg_nauceni[j] = 0;
				detekcijski_prag[j] = 0;
				prag_ucenje[j] = 0;
				zaINTnaucene[j] = 0;
				RR_interpoliran[j] = 0;
			}
			
			detEKG = 0;
			stejemRR = 0;
			interval = 0;
			nic = 0;
IMAM_PM = 0;
			
			d = naredi_fjo_suma();
			dolzina = naredi_ECG_det_fjo();
			nic = ekgUcenje(det_fja_ekg, dolzina, st_max, utripi_ekg_nauceni, fja_suma, detekcijski_prag);


if(e == 0) IMAM_PM0 = IMAM_PM; 
if(e == 1) IMAM_PM1 = IMAM_PM;
if(e == 2) IMAM_PM2 = IMAM_PM; 
  
  
///zaINT poisci intervale naucenih
		startIdx = 0;
		stopIdx = 0;
		inter = 0;
		kon = 0;
		while(startIdx <= (dolzina-1))
		{
			while(RR_interpoliran[startIdx] == 0)
			{
				if(startIdx < dolzina) startIdx++;
				else
				{	 
					kon = 1;
					break;
				}		
			} 
			if(kon == 1) break;
			
			stopIdx = startIdx + 1;
			while(RR_interpoliran[stopIdx] != 0)
			{
				if(stopIdx < dolzina) stopIdx++;
				else break;
			} 

			NauceniInt[inter][0] = startIdx;
			NauceniInt[inter][1] = stopIdx;
			inter++;		
			if(inter >= VELIKOST) inter = VELIKOST - 1;
			startIdx = stopIdx++;
			if(startIdx >= (dolzina-1)) break;
		}

		for(j = 0; j < dolzina; j++)
		{
			utripi_ekg[j] = utripi_ekg_nauceni[j];
		}


			detektiraj_utripe_ekg(det_fja_ekg, detekcijski_prag, utripi_ekg, rr_naucen_EKG, dolzina);
			k_suma = intervali_suma(sum1, detekcijski_prag, d);
			
			detEKG = 0;
for(j = 0;j < dolzina; j++)
{
  if(utripi_ekg[j] > 0) detEKG++;
}
detektiraniEKG = detEKG;
			
		
			for(j = 0; j < dolzina; j++)
			{
				if((RR_i_vsi[j] == 0) && (RR_interpoliran[j] != 0)) RR_i_vsi[j] = RR_interpoliran[j]; 				
			}

///***************************+
			if(e == 0)
			{  
			  for(j = 0; j < dolzina; j++)
			  {
				nauceniVSI[j] = utripi_ekg_nauceni[j];
			  }
			}
			if(e == 1 || e == 2)
			{
			  zdruzevanje_nauceni_nauceni(utripi_ekg_nauceni, nauceniVSI, dolzina, 5);			
			}


			nauceni = 0;
			for(j = 0; j < dolzina; j++)
			{
				if(utripi_ekg_nauceni[j] > 0) nauceni++;
			}

/*

			if (e == 0)
			{
				najvec_naucenih = nauceni;
				indexEKG = e;
			}
			if(e > 0 && nauceni > najvec_naucenih)
			{
				najvec_naucenih = nauceni;
				indexEKG = e;
			}
*/

if(e == 0) RR0 = rr_naucen_EKG; 
if(e == 1) RR1 = rr_naucen_EKG;
if(e == 2) RR2 = rr_naucen_EKG;


			if (e == 0){ N0 = nauceni;}
			if (e == 1){ N1 = nauceni;}
			if (e == 2){ N2 = nauceni;}			
			
			
			for(j = 0; j < dolzina; j++)
			{
				if(e == 0) {utripi_ekg0[j] = utripi_ekg[j]; d_prag0[j] = detekcijski_prag[j]; d_fja0[j] = det_fja_ekg[j];}
				if(e == 1) {utripi_ekg1[j] = utripi_ekg[j]; d_prag1[j] = detekcijski_prag[j]; d_fja1[j] = det_fja_ekg[j];}
				if(e == 2) {utripi_ekg2[j] = utripi_ekg[j]; d_prag2[j] = detekcijski_prag[j]; d_fja2[j] = det_fja_ekg[j];}
			}			
			for(j = 0; j < interval; j++)
			{
				if(e == 0) {sumI0[j][0] = intervali[j][0]; sumI0[j][1] = intervali[j][1]; i0 = interval;} 
				if(e == 1) {sumI1[j][0] = intervali[j][0]; sumI2[j][1] = intervali[j][1]; i1 = interval;}
				if(e == 2) {sumI2[j][0] = intervali[j][0]; sumI2[j][1] = intervali[j][1]; i2 = interval;}
			}			
			if(e == 0) {pr_st0 = pricakovano_st_utripov; detEKG0 = detEKG; kolicina_suma0 = k_suma;}
			if(e == 1) {pr_st1 = pricakovano_st_utripov; detEKG1 = detEKG; kolicina_suma1 = k_suma;}
			if(e == 2) {pr_st2 = pricakovano_st_utripov; detEKG2 = detEKG; kolicina_suma2 = k_suma;}		
		}
		
if(st_ekg == 2)
{
  if(kolicina_suma0 < kolicina_suma1){indexEKG = 0;}  
  else if(kolicina_suma1 < kolicina_suma0){indexEKG = 1;}  
  else if(kolicina_suma0 == kolicina_suma1)
  {
    if(N0 >= N1) indexEKG = 0;
    else indexEKG = 1;
  }  
}

if(st_ekg == 3)
{		
  if((kolicina_suma0 < kolicina_suma1) && (kolicina_suma0 < kolicina_suma2)){indexEKG = 0;}  
  else if((kolicina_suma1 < kolicina_suma0) && (kolicina_suma1 < kolicina_suma2)){indexEKG = 1;}  
  else if((kolicina_suma2 < kolicina_suma1) && (kolicina_suma2 < kolicina_suma0)){indexEKG = 2;}  
///----
  else if((kolicina_suma0 == kolicina_suma1) && (kolicina_suma1 == kolicina_suma2))
  {
    if((N0 >= N1) && (N0 >= N2)) indexEKG = 0;
    else if((N1 >= N0) && (N1 >= N2)) indexEKG = 1;
    if((N2 >= N1) && (N2 >= N0)) indexEKG = 2;
  }  
///----
  else if((kolicina_suma0 <= kolicina_suma1) && (kolicina_suma0 <= kolicina_suma2) && 
  (kolicina_suma0 == kolicina_suma1) && (kolicina_suma0 != kolicina_suma2))
  {
    if(N0 >= N1) indexEKG = 0;
    else indexEKG = 1;
  }  
  else if((kolicina_suma0 <= kolicina_suma1) && (kolicina_suma0 <= kolicina_suma2) && 
    (kolicina_suma0 != kolicina_suma1) && (kolicina_suma0 == kolicina_suma2))
  {
    if(N0 >= N2) indexEKG = 0;
    else indexEKG = 2;
  }
  
  else if((kolicina_suma1 <= kolicina_suma0) && (kolicina_suma1 <= kolicina_suma2) && 
    (kolicina_suma1 == kolicina_suma0) && (kolicina_suma1 != kolicina_suma2))
  {
    if(N0 >= N1) indexEKG = 0;
    else indexEKG = 1;
  }
  else if((kolicina_suma1 <= kolicina_suma0) && (kolicina_suma1 <= kolicina_suma2) && 
    (kolicina_suma1 != kolicina_suma0) && (kolicina_suma1 == kolicina_suma2))
  {
    if(N1 >= N2) indexEKG = 1;
    else indexEKG = 2;
  }
  
  else if((kolicina_suma2 <= kolicina_suma1) && (kolicina_suma2 <= kolicina_suma0) && 
    (kolicina_suma2 == kolicina_suma1) && (kolicina_suma2 != kolicina_suma0))
  {
    if(N1 >= N2) indexEKG = 1;
    else indexEKG = 2;
  }
  else if((kolicina_suma2 <= kolicina_suma1) && (kolicina_suma2 <= kolicina_suma0) && 
    (kolicina_suma2 != kolicina_suma1) && (kolicina_suma2 == kolicina_suma0))
  {
    if(N0 >= N2) indexEKG = 0;
    else indexEKG = 2;
  }
///----  
}


		nic = 1;
		for(j = 0; j < dolzina; j++)
		{
			if(RR_i_vsi[j] != 0)
			{
				nic = 0;
				break;
			}
		}
		
///zaINT poisci intervale naucenih
		startIdx = 0;
		stopIdx = 0;
		inter = 0;
		kon = 0;
		while(startIdx <= (dolzina-1))
		{
			while(RR_i_vsi[startIdx] == 0)
			{
				if(startIdx < dolzina) startIdx++;
				else
				{	 
					kon = 1;
					break;
				}		
			} 
			if(kon == 1) break;
			
			stopIdx = startIdx + 1;
			while(RR_i_vsi[stopIdx] != 0)
			{
				if(stopIdx < dolzina) stopIdx++;
				else break;
			} 

			NauceniInt[inter][0] = startIdx;
			NauceniInt[inter][1] = stopIdx;
			inter++;		
			
			startIdx = stopIdx++;
			if(startIdx >= (dolzina-1)) break;
		}
		
		
		
		interpolacijaRR(dolzina, RR_i_vsi, nic);
//printf("index  %d\n", indexEKG);		
		
		
		for(j = 0; j < dolzina; j++)
		{
			if(indexEKG == 0) {utripi_ekg[j] = utripi_ekg0[j]; detekcijski_prag[j] = d_prag0[j]; det_fja_ekg[j] = d_fja0[j];}
			if(indexEKG == 1) {utripi_ekg[j] = utripi_ekg1[j]; detekcijski_prag[j] = d_prag1[j]; det_fja_ekg[j] = d_fja1[j];}
			if(indexEKG == 2) {utripi_ekg[j] = utripi_ekg2[j]; detekcijski_prag[j] = d_prag2[j]; det_fja_ekg[j] = d_fja2[j];}
		}			
		if(indexEKG == 0) 
		{
		  IMAM_PM = IMAM_PM0;
		  Nauceni_EKG = N0,
			zdruzevanje_nauceni_detektirani_nova(nauceniVSI, utripi_ekg);
			pricakovano_st_utripov = pr_st0;
			for(j = 0; j < i0; j++)
			{
				intervali[j][0] = sumI0[j][0]; intervali[j][1] = sumI0[j][1];
			}
			interval = i0;
			detektiraniEKG = detEKG0;
			rr_naucen_EKG = RR0;
		}
		if(indexEKG == 1) 
		{
		  IMAM_PM = IMAM_PM1;
		  Nauceni_EKG = N1,
			zdruzevanje_nauceni_detektirani_nova(nauceniVSI, utripi_ekg);	
			pricakovano_st_utripov = pr_st1;
			for(j = 0; j < i1; j++)
			{
				intervali[j][0] = sumI1[j][0]; intervali[j][1] = sumI1[j][1];
			}
			interval = i1;
			detektiraniEKG = detEKG1;
			rr_naucen_EKG = RR1;
		}
		if(indexEKG == 2) 
		{
		  IMAM_PM = IMAM_PM2;
		  Nauceni_EKG = N2,
			zdruzevanje_nauceni_detektirani_nova(nauceniVSI, utripi_ekg);
			pricakovano_st_utripov = pr_st2;
			for(j = 0; j < i2; j++)
			{
				intervali[j][0] = sumI2[j][0]; intervali[j][1] = sumI2[j][1];
			}
			interval = i2;
			detektiraniEKG = detEKG2;
			rr_naucen_EKG = RR2;
		}		

		if(interval > 0 && inter > 0) nastavitev_intervali_suma(interval, inter);
		dolocitev_utripov_EKG(utripi_ekg);

	}

//printf("bp %d\n",st_bp);	

	if(st_bp == 1)
	{
		pritisk = bp0;
		dolzinabp = naredi_BP_det_fjo();
		ni_naucil = bpUcenje(fpritisk, dolzinabp, st_max, utripi_bp_nauceni, fpritisk, detekcijski_pragBP);

		
		

///zaINT poisci intervale naucenih
		startIdx = 0;
		stopIdx = 0;
		kon = 0;
		while(startIdx <= (dolzinabp-1))
		{
			while(RR_interpoliran_BP[startIdx] == 0)
			{
				if(startIdx < dolzinabp) startIdx++;
				else
				{	 
					kon = 1;
					break;
				}		
			} 
			if(kon == 1) break;
			
			stopIdx = startIdx + 1;
			while(RR_interpoliran_BP[stopIdx] != 0)
			{
				if(stopIdx < dolzinabp) stopIdx++;
				else break;
			} 

			NauceniIntBP[interBP][0] = startIdx;
			NauceniIntBP[interBP][1] = stopIdx;
			interBP++;		
			if(interBP >= VELIKOST) interBP = VELIKOST - 1;
			
			startIdx = stopIdx++;
			if(startIdx >= (dolzinabp-1)) break;
		}
		
		
		    for(j = 0; j < dolzinabp; j++)
		    {
			utripi_bp[j] = utripi_bp_nauceni[j];
		    }	
		    
		    
	detektiraj_utripe_bp(fpritisk, detekcijski_pragBP, utripi_bp, rr_naucen_BP, dolzinabp);	    
		    
	
	if(ni_naucil == 0)
	{
  
  
N0 = 0;
for(j = 0; j < dolzinabp; j++)
{
    if(utripi_bp_nauceni[j] > 0) N0++;
}	
N_BP0 = N0;


if(st_ekg > 0)
{  
k = 0;
v_sumu = 0; 
while(k < interval) 
{
  for(j = intervali[k][0]; j < intervali[k][1]; j++)
  {
    if(utripi_ekg[j] > 0)
    {
	v_sumu++;
    }
  }
  k++;
}	
}

			
			interpolacijaRR(dolzinabp, RR_interpoliran_BP, 0);

				
N0 = 0;
for(j = 0; j < dolzinabp; j++)
{
    if(utripi_bp[j] > 0) N0++;
}	
	
    
st_pricakovanih_BP = dolzinabp/(rr_naucen_BP*frekvenca);

odstotek_BP0 = odstotek_BP;


if(Nauceni_EKG == 0){st_ekg = 0;}
if(st_ekg > 0 && bp_indexi_imena[0] == 0)
{ 
if(Korelacija == 1)
{
  
    ujemanj = skupno_pretest(utripi_ekg, utripi_bp, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP);	
    idx_ujemanja2 = (double)ujemanj/(detektiraniEKG-v_sumu);
  
if(imam_pm == 0 && (Korak < round((-1)*0.05*frekvenca)) && (idx_ujemanja2 >= IDXuj))
{
  imam_pm = 1;
  if(IMAM_PM == 1) ni_naucil = 1;
}
if(imam_pm == 0 && (2*rr_naucen_EKG/rr_naucen_BP) > 0.75 && (2*rr_naucen_EKG/rr_naucen_BP) < 1.25)
{
  imam_pm = 1;
  if(IMAM_PM == 1) ni_naucil = 1;
  else st_ekg = 0;
}
  
if(imam_pm == 0)
{ 
    ujemanj = skupno(utripi_ekg, utripi_bp, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP);	
    idx_ujemanja2 = (double)ujemanj/(detektiraniEKG-v_sumu);			
			
			for(j = 0; j < dolzina; j++)
			{
				utripi_ekg_bp[j] = utripi_ekg[j];
			}
			if(idx_ujemanja2 >= IDXuj)
			{
			    ujemanj2 = preslikava_nova(utripi_ekg_bp, utripi_bp, dolzina, dolzinabp, RR_interpoliran_BP, RR_i_vsi,fpritisk);
			    pregled_suma(utripi_ekg_bp, RR_i_vsi, dolzina);
			    nizki_nova(det_fja_ekg, utripi_ekg_bp, detekcijski_prag, dolzina, RR_i_vsi,PRAGnizkiUTRIPI,LUKNJA);
			    nizki_BP(utripi_ekg_bp, utripi_bp, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP, fpritisk);
			}
			else ni_naucil = 1;
		}	
}			
else
{
  
ujemanj = korelacija_pretest(nauceniVSI, utripi_bp_nauceni, utripi_ekg, utripi_bp, dolzina, dolzinabp);			  

idx_ujemanja2 = (double)ujemanj/(detektiraniEKG-v_sumu);			
//if(imam_pm == 0 && (Korak < round((-1)*0.05*frekvenca)) && (idx_ujemanja2 >= IDXuj))
if(imam_pm == 0 && (idx_ujemanja2 >= IDXuj))
{
  imam_pm = 1;
  if(IMAM_PM == 1) ni_naucil = 1;
}
if(imam_pm == 0 && (2*rr_naucen_EKG/rr_naucen_BP) > 0.75 && (2*rr_naucen_EKG/rr_naucen_BP) < 1.25)
{
  imam_pm = 1;
  if(IMAM_PM == 1) ni_naucil = 1;
  else st_ekg = 0;
}
if(imam_pm == 0)
{
	ujemanj = korelacija(nauceniVSI, utripi_bp_nauceni, utripi_ekg, utripi_bp, dolzina, dolzinabp);			
	///idx_ujemanja2 = (double)ujemanj/detektiraniEKG;

idx_ujemanja2 = (double)ujemanj/(detektiraniEKG-v_sumu);			

			for(j = 0; j < dolzina; j++)
			{
				utripi_ekg_bp[j] = utripi_ekg[j];
			}

			if((idx_ujemanja2 >= IDXuj))// && (idx_ujemanja2 <= 1.0))
			{
			ujemanj2 = ali_nova(utripi_ekg_bp, utripi_bp, dolzina, dolzinabp, Korak, RR_i_vsi, RR_interpoliran_BP, fpritisk);	
			    pregled_suma(utripi_ekg_bp, RR_i_vsi, dolzina);

			    nizki_nova(det_fja_ekg, utripi_ekg_bp, detekcijski_prag, dolzina, RR_i_vsi,PRAGnizkiUTRIPI,LUKNJA);
			    nizki_BP_korelacija(utripi_ekg_bp, utripi_bp, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP, fpritisk, Korak, srednjiBP);
			}   
			else ni_naucil = 1;
		}
  
}
}		
else ni_naucil = 1;
		  
		}
		
		if(imena == 1)
		{  
		  if(strstr(s[bp_indexi[0]].desc,"ART")   != NULL) {premik = round(ART*frekvenca);}
		  else if(strstr(s[bp_indexi[0]].desc,"PAP")   != NULL) {premik = round(PAP*frekvenca);}
		  else if(strstr(s[bp_indexi[0]].desc,"BP")   != NULL) {premik = round(BP*frekvenca);}
		  else if(strstr(s[bp_indexi[0]].desc,"Pressure")   != NULL) {premik = round(Pressure*frekvenca);}
		  else {premik = round(DEFAULT*frekvenca);}
		}
		else if(imena == 0) {premik = round(DEFAULT*frekvenca);}
		
		if(st_ekg > 0 && imam_pm == 0)
		{  

		if(ni_naucil == 1)
		{
			nizki_nova(det_fja_ekg, utripi_ekg, detekcijski_prag, dolzina, RR_i_vsi,PRAGnizkiUTRIPI,LUKNJA);


		if(Korelacija == 0 || Korelacija == 1)
		{  	

		  if(N_BP0 > 0 && bp_indexi_imena[0] == 0 && odstotek_BP0 < 0.25 && odstotek_BP0 > -0.35)  
		  {
		      ali_nova(utripi_ekg, utripi_bp, dolzina, dolzinabp, premik, RR_i_vsi, RR_interpoliran_BP, fpritisk);	
		      nizki_BP_korelacija(utripi_ekg, utripi_bp, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP, fpritisk, DEFAULT*frekvenca,srednjiBP);
		  }
		  else if(N_BP0 > 0 && bp_indexi_imena[0] == 1 && odstotek_BP0 < 0.25 && odstotek_BP0 > -0.35 && 
		    rr_naucen_EKG*0.75 < rr_naucen_BP && rr_naucen_BP < rr_naucen_EKG*1.25)  
		  {
		      ali_nova(utripi_ekg, utripi_bp, dolzina, dolzinabp, premik, RR_i_vsi, RR_interpoliran_BP, fpritisk);	
		      nizki_BP_korelacija(utripi_ekg, utripi_bp, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP, fpritisk, DEFAULT*frekvenca,srednjiBP);
		  }
		}  
			
				
			for(j = 0; j < dolzina; j++)
			{
				utripi[j] = utripi_ekg[j];	
			}		
		}
		
		if(ni_naucil == 0)
		{	
			for(j = 0; j < dolzina; j++)
			{
				utripi[j] = utripi_ekg_bp[j];	
			}		
		}
		}
		else
		{	
		  for(j = premik; j < dolzinabp; j++)
		  {
		    utripi[j-premik] = utripi_bp[j];	
		  }
		  
	
		}
	}
///*************
///*************
///*************
///*************
	if(st_bp > 1)
	{
		ni_naucil0 = 1;
		ni_naucil1 = 1;
		ni_naucil2 = 1;
		for(b = 0; b < st_bp; b++)
		{
			for(j = 0; j < nrSamps; j++)
			{ 
				utripi_bp[j] = 0;
				utripi_bp_nauceni[j] = 0;
				detekcijski_pragBP[j] = 0;
				prag_ucenje_BP[j] = 0;
				RR_interpoliran_BP[j] = 0;
				utripi_skupni[j] = utripi_ekg[j];
			}
			
			detBP = 0;
			stejemRR_BP = 0;
			if(b == 0) pritisk = bp0;
			if(b == 1) pritisk = bp1;
			if(b == 2) pritisk = bp2;
imam_pm = 0;

			dolzinabp = naredi_BP_det_fjo();
			ni_naucil = bpUcenje(fpritisk, dolzinabp, st_max, utripi_bp_nauceni, fpritisk, detekcijski_pragBP);
			if(b == 0) ni_naucil0 = ni_naucil;
			if(b == 1) ni_naucil1 = ni_naucil;
			if(b == 2) ni_naucil2 = ni_naucil;
			
			if(b == 0) rr_naucen_BP0 = rr_naucen_BP;  
			if(b == 1) rr_naucen_BP1 = rr_naucen_BP;  
			if(b == 2) rr_naucen_BP2 = rr_naucen_BP;  

			
			if(b == 0) srednjiBP0 = srednjiBP;  
			if(b == 1) srednjiBP1 = srednjiBP;  
			if(b == 2) srednjiBP2 = srednjiBP;  			
			
		
			  
///zaINT poisci intervale naucenih
		startIdx = 0;
		stopIdx = 0;
		interBP = 0;
		kon = 0;
		while(startIdx <= (dolzinabp-1))
		{
			while(RR_interpoliran_BP[startIdx] == 0)
			{
				if(startIdx < dolzinabp) startIdx++;
				else
				{	 
					kon = 1;
					break;
				}		
			} 
			if(kon == 1) break;
			
			stopIdx = startIdx + 1;
			while(RR_interpoliran_BP[stopIdx] != 0)
			{
				if(stopIdx < dolzinabp) stopIdx++;
				else break;
			} 

			NauceniIntBP[interBP][0] = startIdx;
			NauceniIntBP[interBP][1] = stopIdx;
			interBP++;		
			if(interBP >= VELIKOST) interBP = VELIKOST - 1;
			
			startIdx = stopIdx++;
			if(startIdx >= (dolzinabp-1)) break;
		}
			  
			  
			  for(j = 0; j < dolzinabp; j++)
			  {
			    utripi_bp[j] = utripi_bp_nauceni[j];
			  }
			  
				detektiraj_utripe_bp(fpritisk, detekcijski_pragBP, utripi_bp, rr_naucen_BP, dolzinabp);
	
		if(ni_naucil != 1)
			{		

				
				
				interpolacijaRR(dolzinabp, RR_interpoliran_BP, 0);

N0 = 0;
for(j = 0; j < dolzinabp; j++)
{
    if(utripi_bp_nauceni[j] > 0) N0++;
}	

 if(b == 0) N_BP0 = N0;
 if(b == 1) N_BP1 = N0;
 if(b == 2) N_BP2 = N0;
 

if(st_ekg > 0) 
{
k = 0;
v_sumu = 0; 
while(k < interval) 
{
  for(j = intervali[k][0]; j < intervali[k][1]; j++)
  {
    if(utripi_ekg[j] > 0)
    {
	v_sumu++;
    }
  }
  k++;
}	
}

     
N1 = 0;
for(j = 0; j < dolzinabp; j++)
{
    if(utripi_bp[j] > 0) N1++;
}	    
st_pricakovanih_BP = dolzinabp/(rr_naucen_BP*frekvenca);

odstotek_BP = (double)N1/st_pricakovanih_BP-1.0;

if(b == 0) odstotek_BP0 = odstotek_BP;  
if(b == 1) odstotek_BP1 = odstotek_BP;  
if(b == 2) odstotek_BP2 = odstotek_BP;  



if(Nauceni_EKG == 0){st_ekg = 0; }
if(st_ekg > 0 && bp_indexi_imena[b] == 0)
{ 				
if(Korelacija == 1)
{	
  
    ujemanj = skupno_pretest(utripi_ekg, utripi_bp, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP);	
    idx_ujemanja2 = (double)ujemanj/(detektiraniEKG-v_sumu);
   
  
//if(imam_pm == 0 && (Korak < round((-1)*0.05*frekvenca)) && (idx_ujemanja2 >= IDXuj))
if(imam_pm == 0 && idx_ujemanja2 >= IDXuj)
{
  imam_pm = 1;
  if(b == 0 && IMAM_PM == 1) ni_naucil0 = 1;
  if(b == 1 && IMAM_PM == 1) ni_naucil1 = 1;
  if(b == 2 && IMAM_PM == 1) ni_naucil2 = 1;
  if(b == 0) K_BP0 = -0.1*frekvenca;
  if(b == 1) K_BP1 = -0.1*frekvenca;
  if(b == 2) K_BP2 = -0.1*frekvenca;
}
if(imam_pm == 0 && (2*rr_naucen_EKG/rr_naucen_BP) > 0.75 && (2*rr_naucen_EKG/rr_naucen_BP) < 1.25)
{
   imam_pm = 1;

  if(b == 0 && IMAM_PM == 1) ni_naucil0 = 1;
  else  st_ekg = 0;
  if(b == 1 && IMAM_PM == 1) ni_naucil1 = 1;
 else  st_ekg = 0;
  if(b == 2 && IMAM_PM == 1) ni_naucil2 = 1;
else  st_ekg = 0;
}
  
if(imam_pm == 0)
{   
  
			ujemanj = skupno(utripi_ekg, utripi_bp, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP);	//idx_ujemanja1 = (double)ujemanj/detektiraniEKG;
			idx_ujemanja2 = (double)ujemanj/(detektiraniEKG-v_sumu);

			
if(b == 0) K_BP0 = 1;
if(b == 1) K_BP1 = 1;
if(b == 2) K_BP2 = 1;
if(b == 0) {koef0 = koef; NNN0 = N;}
if(b == 1) {koef1 = koef; NNN1 = N;}
if(b == 2) {koef2 = koef; NNN2 = N;}

			      if((idx_ujemanja2 >= IDXuj))
			      {
				  ujemanj2 = preslikava_nova(utripi_skupni, utripi_bp, dolzina, dolzinabp, RR_interpoliran_BP, RR_i_vsi,fpritisk);  
				  pregled_suma(utripi_skupni, RR_i_vsi, dolzina);

				nizki_nova(det_fja_ekg, utripi_skupni, detekcijski_prag, dolzina, RR_i_vsi,PRAGnizkiUTRIPI,LUKNJA);
nizki_BP(utripi_skupni, utripi_bp, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP, fpritisk);
				
			      } 

				else
				{
					if(b == 0) ni_naucil0 = 1;
					if(b == 1) ni_naucil1 = 1;
					if(b == 2) ni_naucil2 = 1;
				}
}				
}				
else
{
  
 ujemanj = korelacija_pretest(nauceniVSI, utripi_bp_nauceni, utripi_ekg, utripi_bp, dolzina, dolzinabp); 			  	

 idx_ujemanja2 = (double)ujemanj/(detektiraniEKG-v_sumu);			

//printf("1  %f  %f   %d    %f    %f\n",idx_ujemanja2, odstotek_BP, Korak, rr_naucen_BP, rr_naucen_EKG);
  
 
  
//  if(((Korak < round((-1)*0.05*frekvenca)) && (idx_ujemanja2 >= 0.75) && (idx_ujemanja2 <= 1.0))
//    || ((Korak < round((-1)*0.05*frekvenca)) && (idx_ujemanja2 >= 2.0))
//  )

/* if(IMAM_PM2 == 1)
{
  imam_pm = 1;
  st_ekg = 0;
}*/
if(imam_pm == 0 && Korak < round((-1)*0.05*frekvenca) && (idx_ujemanja2 >= IDXuj))
{
  imam_pm = 1;
  if(b == 0 && IMAM_PM == 1) ni_naucil0 = 1;
  if(b == 1 && IMAM_PM == 1) ni_naucil1 = 1;
  if(b == 2 && IMAM_PM == 1) ni_naucil2 = 1;
  if(b == 0) K_BP0 = Korak;
  if(b == 1) K_BP1 = Korak;
  if(b == 2) K_BP2 = Korak;
}
if(imam_pm == 0 && (2*rr_naucen_EKG/rr_naucen_BP) > 0.75 && (2*rr_naucen_EKG/rr_naucen_BP) < 1.25)
{
 imam_pm = 1;

  if(b == 0 && IMAM_PM == 1) ni_naucil0 = 1;
  else  st_ekg = 0;
  if(b == 1 && IMAM_PM == 1) ni_naucil1 = 1;
 else  st_ekg = 0;
  if(b == 2 && IMAM_PM == 1) ni_naucil2 = 1;
else  st_ekg = 0;
}

  if(imam_pm == 0)
  { 
	ujemanj = korelacija(nauceniVSI, utripi_bp_nauceni, utripi_ekg, utripi_bp, dolzina, dolzinabp); 
	idx_ujemanja2 = (double)ujemanj/(detektiraniEKG-v_sumu);

 if(b == 0) K_BP0 = Korak;
  if(b == 1) K_BP1 = Korak;
  if(b == 2) K_BP2 = Korak;
			if((idx_ujemanja2 >= IDXuj))// && (idx_ujemanja2 <= 1.0))
			{
			  
			ujemanj2 = ali_nova(utripi_skupni, utripi_bp, dolzina, dolzinabp, Korak, RR_i_vsi, RR_interpoliran_BP, fpritisk);	
			    pregled_suma(utripi_skupni, RR_i_vsi, dolzina);
			    nizki_nova(det_fja_ekg, utripi_skupni, detekcijski_prag, dolzina, RR_i_vsi,PRAGnizkiUTRIPI,LUKNJA);
			    nizki_BP_korelacija(utripi_skupni, utripi_bp, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP, fpritisk, Korak,srednjiBP);
			}   
			else
			{
				if(b == 0) ni_naucil0 = 1;
				if(b == 1) ni_naucil1 = 1;
				if(b == 2) ni_naucil2 = 1;
			}
  }
    
  }
}
else 
{  
  if(b == 0) ni_naucil0 = 1;
  if(b == 1) ni_naucil1 = 1;
  if(b == 2) ni_naucil2 = 1;
}  
				for(j = 0; j < dolzinabp; j++)
				{
					if(b == 0) {utripi0[j] = utripi_skupni[j]; utripi_bp0[j] = utripi_bp[j]; 
						    RR_interpoliran_BP0[j] = RR_interpoliran_BP[j]; fpritisk0[j] = fpritisk[j];} 
					if(b == 1) {utripi1[j] = utripi_skupni[j]; utripi_bp1[j] = utripi_bp[j];
						    RR_interpoliran_BP1[j] = RR_interpoliran_BP[j]; fpritisk1[j] = fpritisk[j];}
					if(b == 2) {utripi2[j] = utripi_skupni[j]; utripi_bp2[j] = utripi_bp[j];
						    RR_interpoliran_BP2[j] = RR_interpoliran_BP[j]; fpritisk2[j] = fpritisk[j];}
				}		
				if(b == 0) {idx_ujemanja2_0 = idx_ujemanja2;}
				if(b == 1) {idx_ujemanja2_1 = idx_ujemanja2;}
				if(b == 2) {idx_ujemanja2_2 = idx_ujemanja2;}
			}
		}

if(imena == 1)
{
  if(st_bp == 3)
  {  
		  if(strstr(s[bp_indexi[0]].desc,"ART")   != NULL) premik0 = round(ART*frekvenca);
		  else if(strstr(s[bp_indexi[0]].desc,"PAP")   != NULL) premik0 = round(PAP*frekvenca);
		  else if(strstr(s[bp_indexi[0]].desc,"BP")   != NULL) premik0 = round(BP*frekvenca);
		  else if(strstr(s[bp_indexi[0]].desc,"Pressure")   != NULL) premik0 = round(Pressure*frekvenca);
		  else premik0 = round(DEFAULT*frekvenca);
  		  if(strstr(s[bp_indexi[1]].desc,"ART")   != NULL) premik1 = round(ART*frekvenca);
		  else if(strstr(s[bp_indexi[1]].desc,"PAP")   != NULL) premik1 = round(PAP*frekvenca);
		  else if(strstr(s[bp_indexi[1]].desc,"BP")   != NULL) premik1 = round(BP*frekvenca);
		  else if(strstr(s[bp_indexi[1]].desc,"Pressure")   != NULL) premik1 = round(Pressure*frekvenca);
		  else premik1 = round(DEFAULT*frekvenca);
		  if(strstr(s[bp_indexi[2]].desc,"ART")   != NULL) premik2 = round(ART*frekvenca);
		  else if(strstr(s[bp_indexi[2]].desc,"PAP")   != NULL) premik2 = round(PAP*frekvenca);
		  else if(strstr(s[bp_indexi[2]].desc,"BP")   != NULL) premik2 = round(BP*frekvenca);
		  else if(strstr(s[bp_indexi[2]].desc,"Pressure")   != NULL) premik2 = round(Pressure*frekvenca);
		  else premik2 = round(DEFAULT*frekvenca);
  }
  if(st_bp == 2)
  {  
		  if(strstr(s[bp_indexi[0]].desc,"ART")   != NULL) premik0 = round(ART*frekvenca);
		  else if(strstr(s[bp_indexi[0]].desc,"PAP")   != NULL) premik0 = round(PAP*frekvenca);
		  else if(strstr(s[bp_indexi[0]].desc,"BP")   != NULL) premik0 = round(BP*frekvenca);
		  else if(strstr(s[bp_indexi[0]].desc,"Pressure")   != NULL) premik0 = round(Pressure*frekvenca);
		  else premik0 = round(DEFAULT*frekvenca);
  		  if(strstr(s[bp_indexi[1]].desc,"ART")   != NULL) premik1 = round(ART*frekvenca);
		  else if(strstr(s[bp_indexi[1]].desc,"PAP")   != NULL) premik1 = round(PAP*frekvenca);
		  else if(strstr(s[bp_indexi[1]].desc,"BP")   != NULL) premik1 = round(BP*frekvenca);
		  else if(strstr(s[bp_indexi[1]].desc,"Pressure")   != NULL) premik1 = round(Pressure*frekvenca);
		  else premik1 = round(DEFAULT*frekvenca);
  }
  
  
}  
else if(imena == 0)
{
premik0 = round(DEFAULT*frekvenca);
premik1 = round(DEFAULT*frekvenca);
premik2 = round(DEFAULT*frekvenca);
}  
  

//printf("ekg  %d\n", st_ekg);

if(st_ekg == 0)
{
//  printf("\n\nhere\n");
  
//  printf("\n%f %f %f\n",fabs(odstotek_BP0),fabs(odstotek_BP1),fabs(odstotek_BP2));
  if((fabs(odstotek_BP0) <= fabs(odstotek_BP1)) && (fabs(odstotek_BP0) <= fabs(odstotek_BP2)))
  {  
    
    for(j = premik0; j < dolzinabp; j++)
    {
	utripi[j-premik0] = utripi_bp0[j];	
    }    
    if(fabs(odstotek_BP1) <= fabs(odstotek_BP2) && odstotek_BP1 != 2.0)
    {nizki_nova2(utripi, utripi1, dolzinabp, RR_interpoliran_BP0, LUKNJA, premik1);}
    else if(fabs(odstotek_BP2) <= fabs(odstotek_BP1) && odstotek_BP2 != 2.0)
    {nizki_nova2(utripi, utripi2, dolzinabp, RR_interpoliran_BP0, LUKNJA, premik2);}

    
  }
  else if((fabs(odstotek_BP1) <= fabs(odstotek_BP0)) && (fabs(odstotek_BP1) <= fabs(odstotek_BP2)))
  {
    
    for(j = premik1; j < dolzinabp; j++)
    {
	utripi[j-premik1] = utripi_bp1[j];	
    }       
    if(fabs(odstotek_BP0) <= fabs(odstotek_BP2) && odstotek_BP0 != 2.0)
    {nizki_nova2(utripi, utripi0, dolzinabp, RR_interpoliran_BP1, LUKNJA, premik0);}
    else if(fabs(odstotek_BP2) <= fabs(odstotek_BP0) && odstotek_BP2 != 2.0)
    {nizki_nova2(utripi, utripi2, dolzinabp, RR_interpoliran_BP1, LUKNJA, premik2);}  

    
    
  }
  else if((fabs(odstotek_BP2) <= fabs(odstotek_BP0)) && (fabs(odstotek_BP2) <= fabs(odstotek_BP1)))
  {
    for(j = premik2; j < dolzinabp; j++)
    {
	utripi[j-premik2] = utripi_bp2[j];	
    }    
    
    if(fabs(odstotek_BP0) <= fabs(odstotek_BP1) && odstotek_BP0 != 2.0)
    {nizki_nova2(utripi, utripi0, dolzinabp, RR_interpoliran_BP2, LUKNJA, premik0);}
    else if(fabs(odstotek_BP1) <= fabs(odstotek_BP0) && odstotek_BP1 != 2.0)
    {nizki_nova2(utripi, utripi1, dolzinabp, RR_interpoliran_BP2, LUKNJA, premik1);}      
    
    

  }
}
else
{
		if((ni_naucil0 != 1) && (ni_naucil1 != 1) && (ni_naucil2 != 1))
		{
		  
			if(K_BP0 < -0.05*frekvenca &&  K_BP1 < -0.05*frekvenca &&  K_BP2 < -0.05*frekvenca
			  && (fabs(odstotek_BP0) <= fabs(odstotek_BP1)) && (fabs(odstotek_BP0) <= fabs(odstotek_BP2))) 
			{		   
			  for(j = premik0; j < dolzinabp; j++)
			  {
			      utripi[j-premik0] = utripi_bp0[j];	
			   }
		    
			}
			else if(K_BP0 < -0.05*frekvenca &&  K_BP1 < -0.05*frekvenca &&  K_BP2 < -0.05*frekvenca
			  && (fabs(odstotek_BP1) <= fabs(odstotek_BP0)) && (fabs(odstotek_BP1) <= fabs(odstotek_BP2))) 			
			{

			  for(j = premik1; j < dolzinabp; j++)
			  {
			      utripi[j-premik1] = utripi_bp1[j];	
			   }

			}
			else if(K_BP0 < -0.05*frekvenca &&  K_BP1 < -0.05*frekvenca &&  K_BP2 < -0.05*frekvenca
			  && (fabs(odstotek_BP2) <= fabs(odstotek_BP1)) && (fabs(odstotek_BP2) <= fabs(odstotek_BP0))) 			
			{
			  
			  for(j = premik2; j < dolzinabp; j++)
			  {
			      utripi[j-premik2] = utripi_bp2[j];	
			   }
			
			}
			 else if((idx_ujemanja2_0 >= idx_ujemanja2_1) && (idx_ujemanja2_0 >= idx_ujemanja2_2) && (K_BP0 > 0) && (K_BP1 > 0) && (K_BP2 > 0))
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi0[j];
				}
			}
			else if((idx_ujemanja2_1 >= idx_ujemanja2_0) && (idx_ujemanja2_1 >= idx_ujemanja2_2) && (K_BP0 > 0) && (K_BP1 > 0) && (K_BP2 > 0))
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi1[j];
				}		
			}
			else if((idx_ujemanja2_2 >= idx_ujemanja2_1) && (idx_ujemanja2_2 >= idx_ujemanja2_0) && (K_BP0 > 0) && (K_BP1 > 0) && (K_BP2 > 0))
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi2[j];
				}	
			}
			else if((idx_ujemanja2_0 >= idx_ujemanja2_1)  && (K_BP0 > 0) && (K_BP1 > 0) && (K_BP2 < 0))
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi0[j];
				}
			}
			else if((idx_ujemanja2_1 >= idx_ujemanja2_0)  && (K_BP0 > 0) && (K_BP1 > 0) && (K_BP2 < 0))
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi1[j];
				}
			}
			else if((idx_ujemanja2_0 >= idx_ujemanja2_2)  && (K_BP0 > 0) && (K_BP1 < 0) && (K_BP2 > 0))
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi0[j];
				}
			}
			else if((idx_ujemanja2_2 >= idx_ujemanja2_0)  && (K_BP0 > 0) && (K_BP1 < 0) && (K_BP2 > 0))
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi2[j];
				}
			}			
			else if((idx_ujemanja2_1 >= idx_ujemanja2_2)  && (K_BP0 < 0) && (K_BP1 > 0) && (K_BP2 > 0))
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi1[j];
				}
			}
			else if((idx_ujemanja2_2 >= idx_ujemanja2_1)  && (K_BP0 < 0) && (K_BP1 > 0) && (K_BP2 > 0))
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi2[j];
				}
			}						
			else if((K_BP0 > 0) && (K_BP1 < 0) && (K_BP2 < 0))
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi0[j];
				}
			}			
			else if((K_BP0 < 0) && (K_BP1 > 0) && (K_BP2 < 0))
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi1[j];
				}
			}
			else if((K_BP0 < 0) && (K_BP1 < 0) && (K_BP2 > 0))
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi2[j];
				}
			}									
			else 
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi_ekg[j];
				}	
			}			
			
		}
		if((ni_naucil0 != 1) && (ni_naucil1 != 1) && (ni_naucil2 != 0))
		{	
		  
			if(K_BP0 < -0.05*frekvenca &&  K_BP1 < -0.05*frekvenca && fabs(odstotek_BP0) <= fabs(odstotek_BP1))
			{
			  
			  for(j = premik0; j < dolzinabp; j++)
			  {
			      utripi[j-premik0] = utripi_bp0[j];	
			   }

			}
			else if(K_BP0 < -0.05*frekvenca &&  K_BP1 < -0.05*frekvenca && fabs(odstotek_BP1) <= fabs(odstotek_BP0))
			{
			  for(j = premik1; j < dolzinabp; j++)
			  {
			      utripi[j-premik1] = utripi_bp1[j];	
			   }
			}

			else if(idx_ujemanja2_0 >= idx_ujemanja2_1 && K_BP0 > 0 && K_BP1 > 0)
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi0[j];
				}
			}
			else if(idx_ujemanja2_1 >= idx_ujemanja2_0 && K_BP0 > 0 && K_BP1 > 0)
			{	
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi1[j];
				}
			}
			
			else if(K_BP0 > 0 && K_BP1 < 0)
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi0[j];
				}
			}
			else if(K_BP0 < 0 && K_BP1 > 0)
			{	
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi1[j];
				}
			}	
			else
			{	
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi_ekg[j];
				}
			}			
			
		}	
		if((ni_naucil0 != 1) && (ni_naucil1 != 0) && (ni_naucil2 != 1))
		{
		  		  
			if(K_BP0 < -0.05*frekvenca &&  K_BP2 < -0.05*frekvenca && fabs(odstotek_BP0) <= fabs(odstotek_BP2)) 
			{
			 
			  for(j = premik0; j < dolzinabp; j++)
			  {
			      utripi[j-premik0] = utripi_bp0[j];	
			   }

			}
			else if(K_BP0 < -0.05*frekvenca &&  K_BP1 < -0.05*frekvenca && fabs(odstotek_BP2) <= fabs(odstotek_BP0))
			{
			 
			  for(j = premik2; j < dolzinabp; j++)
			  {
			      utripi[j-premik2] = utripi_bp2[j];	
			   }
			 
			}
			else if(idx_ujemanja2_0 >= idx_ujemanja2_2 && K_BP0 > 0 && K_BP2 > 0)
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi0[j];
				}
			}
			else if(idx_ujemanja2_2 >= idx_ujemanja2_0 && K_BP0 > 0 && K_BP2 > 0)
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi2[j];
				}
			}
			else if(K_BP0 > 0 && K_BP2 < 0)
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi0[j];
				}
			}
			else if(K_BP0 < 0 && K_BP2 > 0)
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi2[j];
				}
			}
			else
			{	
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi_ekg[j];
				}
			}				
		}	
		if((ni_naucil0 != 0) && (ni_naucil1 != 1) && (ni_naucil2 != 1))
		{
		  		  
			if(K_BP2 < -0.05*frekvenca &&  K_BP1 < -0.05*frekvenca && fabs(odstotek_BP2) <= fabs(odstotek_BP1)) 
			{
			 
			  for(j = premik2; j < dolzinabp; j++)
			  {
			      utripi[j-premik2] = utripi_bp2[j];	
			   }
			  
			}
			else if(K_BP2 < -0.05*frekvenca &&  K_BP1 < -0.05*frekvenca && fabs(odstotek_BP1) <= fabs(odstotek_BP2))
			{
			 
			  for(j = premik1; j < dolzinabp; j++)
			  {
			      utripi[j-premik1] = utripi_bp1[j];	
			   }
			 
			}
			else if(idx_ujemanja2_1 >= idx_ujemanja2_2 && K_BP1 > 0 && K_BP2 > 0)
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi1[j];
				}
			}
			else if(idx_ujemanja2_2 >= idx_ujemanja2_1 && K_BP1 > 0 && K_BP2 > 0)
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi2[j];
				}
			}			
			else if(K_BP1 > 0 && K_BP2 < 0)
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi1[j];
				}
			}
			else if(K_BP1 < 0 && K_BP2 > 0)
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi2[j];
				}
			}			
			else 
			{
				for(j = 0; j < dolzina; j++)
				{
					utripi[j] = utripi_ekg[j];
				}
			}					  
		}	
		if((ni_naucil0 != 1) && (ni_naucil1 != 0) && (ni_naucil2 != 0))
		{
			if(K_BP0 < -0.05*frekvenca)
			{
	
			  for(j = premik0; j < dolzinabp; j++)
			  {
			      utripi[j-premik0] = utripi_bp0[j];	
			   }
			  
			}
			else
			{  
			  for(j = 0; j < dolzina; j++)
			  {
				  utripi[j] = utripi0[j];
			  }
			}  
		}
		if((ni_naucil0 != 0) && (ni_naucil1 != 1) && (ni_naucil2 != 0))
		{
			if(K_BP1 < -0.05*frekvenca)
			{
			  
			  for(j = premik1; j < dolzinabp; j++)
			  {
			      utripi[j-premik1] = utripi_bp1[j];	
			   }
			  
			}
			else
			{  
			  for(j = 0; j < dolzina; j++)
			  {
				  utripi[j] = utripi1[j];
			  }
			}  
		}
		if((ni_naucil0 != 0) && (ni_naucil1 != 0) && (ni_naucil2 != 1))
		{
			if(K_BP2 < -0.05*frekvenca)
			{
			  
			  for(j = premik2; j < dolzinabp; j++)
			  {
			      utripi[j-premik2] = utripi_bp2[j];	
			   }
			 
			}
			else
			{  
			  for(j = 0; j < dolzina; j++)
			  {
				utripi[j] = utripi2[j];
			  }
			}  
		}

		if((ni_naucil0 != 0) && (ni_naucil1 != 0) && (ni_naucil2 != 0))
		{	
		  nizki_nova(det_fja_ekg, utripi_ekg, detekcijski_prag, dolzina, RR_i_vsi,PRAGnizkiUTRIPI,LUKNJA);
		
		  
		if(Korelacija == 0 || Korelacija == 1)
		{  
		  
		if(N_BP0 > 0 && bp_indexi_imena[0] == 0 && odstotek_BP0 < 0.25 && odstotek_BP0 > -0.35)  
		{
		  	
		  ali_nova(utripi_ekg, utripi_bp0, dolzina, dolzinabp, premik0, RR_i_vsi, RR_interpoliran_BP0, fpritisk0);	
		
		      nizki_BP_korelacija(utripi_ekg, utripi_bp0, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP0, fpritisk0, premik0, srednjiBP0);

		}  
		else if(N_BP1 > 0 && bp_indexi_imena[1] == 0 && odstotek_BP1 < 0.25 && odstotek_BP1 > -0.35)  
		{
		    ali_nova(utripi_ekg, utripi_bp1, dolzina, dolzinabp, premik1, RR_i_vsi, RR_interpoliran_BP1, fpritisk1);

		   nizki_BP_korelacija(utripi_ekg, utripi_bp1, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP1, fpritisk1, premik1,srednjiBP1);

		  
		}  
		else if(N_BP2 > 0 && bp_indexi_imena[2] == 0 && odstotek_BP2 < 0.25 && odstotek_BP2 > -0.35)  
		  {
		  ali_nova(utripi_ekg, utripi_bp2, dolzina, dolzinabp, premik2, RR_i_vsi, RR_interpoliran_BP2, fpritisk2);	

		  nizki_BP_korelacija(utripi_ekg, utripi_bp2, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP2, fpritisk2, premik2,srednjiBP2);
		  
		}
		else if(N_BP0 > 0 && bp_indexi_imena[0] == 1 && odstotek_BP0 < 0.25 && odstotek_BP0 > -0.35
		 && rr_naucen_EKG*0.75 < rr_naucen_BP0 && rr_naucen_BP0 < rr_naucen_EKG*1.25
 
		)  
		{
		  ali_nova(utripi_ekg, utripi_bp0, dolzina, dolzinabp, premik0, RR_i_vsi, RR_interpoliran_BP0, fpritisk0);	
		
		      nizki_BP_korelacija(utripi_ekg, utripi_bp0, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP0, fpritisk0, premik0,srednjiBP0);
		      
		}  
		else if(N_BP1 > 0 && bp_indexi_imena[1] == 1 && odstotek_BP1 < 0.25 && odstotek_BP1 > -0.35
		  		 && rr_naucen_EKG*0.75 < rr_naucen_BP1 && rr_naucen_BP1 < rr_naucen_EKG*1.25
		)  
		{
		    ali_nova(utripi_ekg, utripi_bp1, dolzina, dolzinabp, premik1, RR_i_vsi, RR_interpoliran_BP1, fpritisk1);

		   nizki_BP_korelacija(utripi_ekg, utripi_bp1, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP1, fpritisk1, premik1,srednjiBP1);


		  
		}  
		else if(N_BP2 > 0 && bp_indexi_imena[2] == 1 && odstotek_BP2 < 0.25 && odstotek_BP2 > -0.35
		  		 && rr_naucen_EKG*0.75 < rr_naucen_BP2 && rr_naucen_BP2 < rr_naucen_EKG*1.25

		)  
		{
		  ali_nova(utripi_ekg, utripi_bp2, dolzina, dolzinabp, premik2, RR_i_vsi, RR_interpoliran_BP2, fpritisk2);	

		  nizki_BP_korelacija(utripi_ekg, utripi_bp2, dolzina, dolzinabp, RR_i_vsi, RR_interpoliran_BP2, fpritisk2, premik2,srednjiBP2);

		  
		}  		
		
		
		
		}   
		  
		  
		for(j = 0; j < dolzina; j++)
			{
				utripi[j] = utripi_ekg[j];
			}
		}
}		
	}	
		
	if(st_ekg > 0 && st_bp == 0)
	{
		nizki_nova(det_fja_ekg, utripi_ekg, detekcijski_prag, dolzina, RR_i_vsi,PRAGnizkiUTRIPI,LUKNJA);
		

	
		for(j = 0; j < dolzina; j++)
		{
			utripi[j] = utripi_ekg[j];
		}
      }

	if(st_ekg == 0 && st_bp == 0)
	{
		for(j = 0; j < dolzina; j++)
		{
			utripi[j] = 0;
		}
      }

///*****************
	writeQRS(record, 1);
	wfdbquit();

	free(ekgh1);
	free(ekgh2);
	free(z);
	free(det_fja_ekg);
	free(utripi_ekg);
	free(utripi_ekg_bp);
	free(utripi_bp);
	free(utripi);
	free(fpritisk);
	free(sum1);
free(sum1_bp);
free(fja_suma_bp);
	free(sum2);
	free(fja_suma);
	free(tmp);
	free(tmp_ekg);
	free(tmp_bp);
	free(ekg0);
	free(ekg1);
	free(ekg2);
	free(bp0);
	free(bp1);	
	free(bp2);	
	free(detekcijski_prag);
	free(detekcijski_pragBP);
	free(tmp_pritisk);
	free(utripi_ekg_nauceni);
	free(utripi_bp_nauceni);
	free(RR_interpoliran);
	free(RR_interpoliran_BP);
	free(zaINTnaucene);
	free(nauceniVSI);
	free(zaINT);
	free(RR_i_vsi);
	free(utripi_ekg0);
	free(utripi_ekg1);
	free(utripi_ekg2);
	free(utripi_skupni);
	free(utripi0);
	free(utripi1);
	free(utripi2);
	free(prag_ucenje);
	free(prag_ucenje_BP);
	free(d_prag0);
	free(d_prag1);
	free(d_prag2);
	free(d_fja0);
	free(d_fja1);
	free(d_fja2);
free(MedianaEkg);
free(amplitudeBP);
	

free(utripi_bp0);
free(utripi_bp1);
free(utripi_bp2);


free(RR_interpoliran_BP0);
free(RR_interpoliran_BP1);
free(RR_interpoliran_BP2);
free(fpritisk0);
free(fpritisk1);
free(fpritisk2);

free(ekg0_G);
free(ekg1_G);
free(ekg2_G);

free(ekg_brisi);
  return 0;
}
